import Color from "colorjs.io";
import { z } from "zod";
export const CamperHandleSchema = z
    .string()
    .min(3, {
    message: "Handle must be at least 3 characters",
})
    .max(32, {
    message: "Handle must be at most 32 characters",
})
    .regex(/^[a-zA-Z0-9_-]+$/, {
    message: "Handle may only contain letters, numbers, hyphens, and underscores",
})
    .brand("CamperHandle");
export const CamperDisplayNameSchema = z
    .string()
    .min(1, {
    message: "Display name must be at least 1 character",
})
    .max(32, {
    message: "Display name must be at most 32 characters",
})
    .trim()
    .brand("CamperDisplayName");
export const PronounStringSchema = z
    .string()
    .max(20, {
    message: "Pronouns must be at most 20 characters",
})
    .regex(/^[a-zA-Z\/]+$/)
    .brand("PronounString");
export const ColorStringSchema = z
    .string()
    .superRefine((val, ctx) => {
    try {
        new Color(val);
    }
    catch (error) {
        ctx.addIssue({
            code: z.ZodIssueCode.custom,
            message: `Invalid color: ${error}`,
        });
    }
})
    .transform((val) => {
    return new Color(val).to("hsl").toString({ format: "hsl" });
})
    .brand("ColorString");
export const TimestampStringSchema = z
    .string()
    .datetime({ offset: true, message: "Failed to parse timestamp" })
    .brand("TimestampString");
export const URLStringSchema = z.string().trim().url().brand("URLString");
export const TaglineStringSchema = z
    .string()
    .max(120, {
    message: "Tagline must be at most 120 characters",
})
    .brand("TaglineString");
