import { z } from "zod";
export declare const DEFAULT_AVATAR_URL: string & z.BRAND<"URLString">;
export declare enum CamperAccessLevel {
    Banned = -1,
    Normal = 0,
    Firewatch = 1,
    Moderator = 2,
    Admin = 3
}
export declare const CamperAccessLevelSchema: z.ZodUnion<[z.ZodLiteral<CamperAccessLevel.Banned>, z.ZodLiteral<CamperAccessLevel.Normal>, z.ZodLiteral<CamperAccessLevel.Firewatch>, z.ZodLiteral<CamperAccessLevel.Moderator>, z.ZodLiteral<CamperAccessLevel.Admin>]>;
export declare const CamperPreferencesSchema: z.ZodObject<{
    allowPings: z.ZodBoolean;
    syncDiscordDisplayName: z.ZodBoolean;
    tagline: z.ZodNullable<z.ZodBranded<z.ZodString, "TaglineString">>;
    handle: z.ZodBranded<z.ZodString, "CamperHandle">;
    displayName: z.ZodBranded<z.ZodString, "CamperDisplayName">;
    color: z.ZodNullable<z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">>;
    pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
}, "strip", z.ZodTypeAny, {
    color: (string & z.BRAND<"ColorString">) | null;
    allowPings: boolean;
    syncDiscordDisplayName: boolean;
    tagline: (string & z.BRAND<"TaglineString">) | null;
    handle: string & z.BRAND<"CamperHandle">;
    displayName: string & z.BRAND<"CamperDisplayName">;
    pronouns: (string & z.BRAND<"PronounString">) | null;
}, {
    color: string | null;
    allowPings: boolean;
    syncDiscordDisplayName: boolean;
    tagline: string | null;
    handle: string;
    displayName: string;
    pronouns: string | null;
}>;
export type CamperPreferences = z.infer<typeof CamperPreferencesSchema>;
export declare const CamperChipSchema: z.ZodObject<{
    id: z.ZodNumber;
    name: z.ZodBranded<z.ZodString, "CamperDisplayName">;
    handle: z.ZodBranded<z.ZodString, "CamperHandle">;
    color: z.ZodNullable<z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">>;
    pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
    avatarUrl: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
}, "strip", z.ZodTypeAny, {
    color: (string & z.BRAND<"ColorString">) | null;
    handle: string & z.BRAND<"CamperHandle">;
    pronouns: (string & z.BRAND<"PronounString">) | null;
    id: number;
    name: string & z.BRAND<"CamperDisplayName">;
    avatarUrl: (string & z.BRAND<"URLString">) | null;
}, {
    color: string | null;
    handle: string;
    pronouns: string | null;
    id: number;
    name: string;
    avatarUrl: string | null;
}>;
export type CamperChip = z.infer<typeof CamperChipSchema>;
export declare const CamperSchema: z.ZodReadonly<z.ZodObject<z.objectUtil.extendShape<{
    id: z.ZodNumber;
    name: z.ZodBranded<z.ZodString, "CamperDisplayName">;
    handle: z.ZodBranded<z.ZodString, "CamperHandle">;
    color: z.ZodNullable<z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">>;
    pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
    avatarUrl: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
}, {
    id: z.ZodNumber;
    handle: z.ZodBranded<z.ZodString, "CamperHandle">;
    name: z.ZodBranded<z.ZodString, "CamperDisplayName">;
    avatarUrl: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
    tagline: z.ZodNullable<z.ZodBranded<z.ZodString, "TaglineString">>;
    websiteUrl: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
    color: z.ZodNullable<z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">>;
    pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
    allowPings: z.ZodBoolean;
    syncDiscordDisplayName: z.ZodBoolean;
    createdAt: z.ZodBranded<z.ZodString, "TimestampString">;
    lastInteraction: z.ZodBranded<z.ZodString, "TimestampString">;
    role: z.ZodUnion<[z.ZodLiteral<CamperAccessLevel.Banned>, z.ZodLiteral<CamperAccessLevel.Normal>, z.ZodLiteral<CamperAccessLevel.Firewatch>, z.ZodLiteral<CamperAccessLevel.Moderator>, z.ZodLiteral<CamperAccessLevel.Admin>]>;
}>, "strip", z.ZodTypeAny, {
    color: (string & z.BRAND<"ColorString">) | null;
    allowPings: boolean;
    syncDiscordDisplayName: boolean;
    tagline: (string & z.BRAND<"TaglineString">) | null;
    handle: string & z.BRAND<"CamperHandle">;
    pronouns: (string & z.BRAND<"PronounString">) | null;
    id: number;
    name: string & z.BRAND<"CamperDisplayName">;
    avatarUrl: (string & z.BRAND<"URLString">) | null;
    websiteUrl: (string & z.BRAND<"URLString">) | null;
    createdAt: string & z.BRAND<"TimestampString">;
    lastInteraction: string & z.BRAND<"TimestampString">;
    role: CamperAccessLevel;
}, {
    color: string | null;
    allowPings: boolean;
    syncDiscordDisplayName: boolean;
    tagline: string | null;
    handle: string;
    pronouns: string | null;
    id: number;
    name: string;
    avatarUrl: string | null;
    websiteUrl: string | null;
    createdAt: string;
    lastInteraction: string;
    role: CamperAccessLevel;
}>>;
export type Camper = z.infer<typeof CamperSchema>;
export declare const EventScopeSchema: z.ZodUnion<[z.ZodArray<z.ZodNumber, "many">, z.ZodNumber, z.ZodLiteral<"public">, z.ZodDefault<z.ZodLiteral<"private">>]>;
export declare const GenericRelayEvent: z.ZodObject<{
    eventName: z.ZodString;
    scope: z.ZodUnion<[z.ZodArray<z.ZodNumber, "many">, z.ZodNumber, z.ZodLiteral<"public">, z.ZodDefault<z.ZodLiteral<"private">>]>;
    payload: z.ZodUnknown;
}, "strip", z.ZodTypeAny, {
    eventName: string;
    scope: number | number[] | "public" | "private";
    payload?: unknown;
}, {
    eventName: string;
    scope?: number | number[] | "public" | "private" | undefined;
    payload?: unknown;
}>;
export type GenericRelayEvent = z.infer<typeof GenericRelayEvent>;
export declare const MAX_TAGLINE_LENGTH = 120;
