import { z } from "zod";
export declare const DiscordIdentitySchema: z.ZodObject<{
    camper: z.ZodObject<{
        id: z.ZodNumber;
        name: z.ZodBranded<z.ZodString, "CamperDisplayName">;
        handle: z.ZodBranded<z.ZodString, "CamperHandle">;
        color: z.ZodNullable<z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">>;
        pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
        avatarUrl: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
    }, "strip", z.ZodTypeAny, {
        color: (string & z.BRAND<"ColorString">) | null;
        handle: string & z.BRAND<"CamperHandle">;
        pronouns: (string & z.BRAND<"PronounString">) | null;
        id: number;
        name: string & z.BRAND<"CamperDisplayName">;
        avatarUrl: (string & z.BRAND<"URLString">) | null;
    }, {
        color: string | null;
        handle: string;
        pronouns: string | null;
        id: number;
        name: string;
        avatarUrl: string | null;
    }>;
    discordId: z.ZodString;
    discordUsername: z.ZodString;
    discordDisplayName: z.ZodString;
    discordAvatar: z.ZodBranded<z.ZodString, "URLString">;
}, "strip", z.ZodTypeAny, {
    camper: {
        color: (string & z.BRAND<"ColorString">) | null;
        handle: string & z.BRAND<"CamperHandle">;
        pronouns: (string & z.BRAND<"PronounString">) | null;
        id: number;
        name: string & z.BRAND<"CamperDisplayName">;
        avatarUrl: (string & z.BRAND<"URLString">) | null;
    };
    discordId: string;
    discordUsername: string;
    discordDisplayName: string;
    discordAvatar: string & z.BRAND<"URLString">;
}, {
    camper: {
        color: string | null;
        handle: string;
        pronouns: string | null;
        id: number;
        name: string;
        avatarUrl: string | null;
    };
    discordId: string;
    discordUsername: string;
    discordDisplayName: string;
    discordAvatar: string;
}>;
export type DiscordIdentity = z.infer<typeof DiscordIdentitySchema>;
export declare const DiscordMessageSchema: z.ZodObject<{
    id: z.ZodNumber;
    author: z.ZodObject<{
        id: z.ZodNumber;
        name: z.ZodBranded<z.ZodString, "CamperDisplayName">;
        handle: z.ZodBranded<z.ZodString, "CamperHandle">;
        color: z.ZodNullable<z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">>;
        pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
        avatarUrl: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
    }, "strip", z.ZodTypeAny, {
        color: (string & z.BRAND<"ColorString">) | null;
        handle: string & z.BRAND<"CamperHandle">;
        pronouns: (string & z.BRAND<"PronounString">) | null;
        id: number;
        name: string & z.BRAND<"CamperDisplayName">;
        avatarUrl: (string & z.BRAND<"URLString">) | null;
    }, {
        color: string | null;
        handle: string;
        pronouns: string | null;
        id: number;
        name: string;
        avatarUrl: string | null;
    }>;
    discordMessageId: z.ZodString;
    discordChannelId: z.ZodString;
    discordParentChannelId: z.ZodNullable<z.ZodString>;
    content: z.ZodString;
    createdAt: z.ZodBranded<z.ZodString, "TimestampString">;
    isThread: z.ZodBoolean;
    link: z.ZodBranded<z.ZodString, "URLString">;
}, "strip", z.ZodTypeAny, {
    id: number;
    createdAt: string & z.BRAND<"TimestampString">;
    author: {
        color: (string & z.BRAND<"ColorString">) | null;
        handle: string & z.BRAND<"CamperHandle">;
        pronouns: (string & z.BRAND<"PronounString">) | null;
        id: number;
        name: string & z.BRAND<"CamperDisplayName">;
        avatarUrl: (string & z.BRAND<"URLString">) | null;
    };
    discordMessageId: string;
    discordChannelId: string;
    discordParentChannelId: string | null;
    content: string;
    isThread: boolean;
    link: string & z.BRAND<"URLString">;
}, {
    id: number;
    createdAt: string;
    author: {
        color: string | null;
        handle: string;
        pronouns: string | null;
        id: number;
        name: string;
        avatarUrl: string | null;
    };
    discordMessageId: string;
    discordChannelId: string;
    discordParentChannelId: string | null;
    content: string;
    isThread: boolean;
    link: string;
}>;
export type DiscordMessage = z.infer<typeof DiscordMessageSchema>;
export declare const DiscordRelayEvents: {
    readonly "discord:message": z.ZodObject<{
        id: z.ZodNumber;
        author: z.ZodObject<{
            id: z.ZodNumber;
            name: z.ZodBranded<z.ZodString, "CamperDisplayName">;
            handle: z.ZodBranded<z.ZodString, "CamperHandle">;
            color: z.ZodNullable<z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">>;
            pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
            avatarUrl: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
        }, "strip", z.ZodTypeAny, {
            color: (string & z.BRAND<"ColorString">) | null;
            handle: string & z.BRAND<"CamperHandle">;
            pronouns: (string & z.BRAND<"PronounString">) | null;
            id: number;
            name: string & z.BRAND<"CamperDisplayName">;
            avatarUrl: (string & z.BRAND<"URLString">) | null;
        }, {
            color: string | null;
            handle: string;
            pronouns: string | null;
            id: number;
            name: string;
            avatarUrl: string | null;
        }>;
        discordMessageId: z.ZodString;
        discordChannelId: z.ZodString;
        discordParentChannelId: z.ZodNullable<z.ZodString>;
        content: z.ZodString;
        createdAt: z.ZodBranded<z.ZodString, "TimestampString">;
        isThread: z.ZodBoolean;
        link: z.ZodBranded<z.ZodString, "URLString">;
    }, "strip", z.ZodTypeAny, {
        id: number;
        createdAt: string & z.BRAND<"TimestampString">;
        author: {
            color: (string & z.BRAND<"ColorString">) | null;
            handle: string & z.BRAND<"CamperHandle">;
            pronouns: (string & z.BRAND<"PronounString">) | null;
            id: number;
            name: string & z.BRAND<"CamperDisplayName">;
            avatarUrl: (string & z.BRAND<"URLString">) | null;
        };
        discordMessageId: string;
        discordChannelId: string;
        discordParentChannelId: string | null;
        content: string;
        isThread: boolean;
        link: string & z.BRAND<"URLString">;
    }, {
        id: number;
        createdAt: string;
        author: {
            color: string | null;
            handle: string;
            pronouns: string | null;
            id: number;
            name: string;
            avatarUrl: string | null;
        };
        discordMessageId: string;
        discordChannelId: string;
        discordParentChannelId: string | null;
        content: string;
        isThread: boolean;
        link: string;
    }>;
};
