import { z } from "zod";
import { BotanyPlantSchema } from "./botany";
import { CONCOCTION_SLUGS, ConcoctionSchema } from "./chemistry";
import { ITEM_SLUGS, ItemSchema, ItemUseResultSchema } from "./items";
import { PortentSchema } from "./portent";
/******************
 * BOTANY ACTIONS *
 ******************/
export const BotanyRelayActions = {
    "botany@water-plant": {
        input: z.object({
            amount: z.number().positive().int(),
            plantId: z.number().positive().int(),
        }),
        output: z.object({
            plant: BotanyPlantSchema,
            waterUsed: z.number().positive().int(),
        }),
    },
    "botany@use-item": {
        input: z.object({
            itemId: z.number().positive().int(),
            plantId: z.number().positive().int(),
        }),
        output: z.string(),
    },
    "botany@water-all-for-camper": {
        input: z.object({
            camperId: z.number().positive().int(),
        }),
        output: z.object({
            waterUsed: z.number().int(),
        }),
    },
    "botany@harvest-plant": {
        input: z.object({
            plantId: z.number().positive().int(),
        }),
        output: z.object({
            conduits: z.number().int(),
            items: z.array(z.enum(ITEM_SLUGS)),
            waterRefund: z.number().int(),
        }),
    },
    "botany@destroy-plant": {
        input: z.object({
            plantId: z.number().positive().int(),
        }),
        output: z.literal(true),
    },
    "botany@sow": {
        input: z.object({
            seedItemId: z.number().positive().int(),
        }),
        output: BotanyPlantSchema,
    },
    "botany@purchase-silkwater": {
        input: z.object({
            type: z.literal("jug").or(z.literal("barrel")),
        }),
        output: z.void(),
    },
};
/*********************
 * CHEMISTRY ACTIONS *
 *********************/
export const ChemistryRelayActions = {
    "chemistry@brew": {
        input: z.object({
            concoctionSlug: z.enum(CONCOCTION_SLUGS),
            useScrap: z.boolean(),
        }),
        output: ConcoctionSchema,
    },
    "chemistry@complete": {
        input: z.object({
            concoctionId: z.number().int().positive(),
        }),
        output: z.union([
            z.object({
                state: z.literal("success"),
                item: ItemSchema,
            }),
            z.object({
                state: z.enum(["too-early", "too-late"]),
                item: z.null(),
            }),
        ]),
    },
    "chemistry@scribe": {
        input: z.object({
            concoctionSlug: z.enum(CONCOCTION_SLUGS),
        }),
        output: z.void(),
    },
};
/****************
 * ITEM ACTIONS *
 ****************/
export const ItemRelayActions = {
    "item@use": {
        input: z.object({
            itemId: z.number(),
        }),
        output: ItemUseResultSchema,
    },
    "item@transfer": {
        input: z.object({
            itemId: z.number(),
            targetId: z.number(),
        }),
        output: ItemSchema,
    },
};
/*******************
 * PORTENT ACTIONS *
 *******************/
export const PortentRelayActions = {
    "portent@roll": {
        input: z.void(),
        output: PortentSchema,
    },
};
/*********************
 * CHARACTER ACTIONS *
 *********************/
export const CharacterRelayActions = {
    "character@transfer-conduits": {
        input: z.object({
            targetCamperId: z.number().int().positive(),
            amount: z.number().int().positive(),
        }),
        output: z.number(),
    },
};
/****************
 * SHOP ACTIONS *
 ****************/
export const ShopRelayActions = {
    "shop@sell-item": {
        input: z.object({
            itemId: z.number(),
        }),
        output: z.number(),
    },
    "shop@bulk-sell-item": {
        input: z.object({
            itemSlug: z.enum(ITEM_SLUGS),
            count: z.number(),
        }),
        output: z.number(),
    },
    "shop@purchase-item": {
        input: z.object({
            itemSlug: z.enum(ITEM_SLUGS),
        }),
        output: ItemSchema,
    },
};
export const GameRelayActions = {
    ...BotanyRelayActions,
    ...ChemistryRelayActions,
    ...ItemRelayActions,
    ...PortentRelayActions,
    ...CharacterRelayActions,
    ...ShopRelayActions,
};
