import { BadgeImages } from "./assets";
export const MERIT_BADGE_SLUGS = [
    "minecrafter",
    "trial1complete",
    "trial1Exalted",
    "trial2complete",
    "trial2Exalted",
    "lodgeLaunch",
    "botanyPropagator",
    "botanyGreenThumb",
    "botanyGrowTogether",
    "visitedSkyCafe",
    "sparkleFoot",
    "stellarvibe2022",
    "stellarvibe2024",
    "stellarvibe2024Max",
    "thunderstruck",
    "selfthunderstruck",
    "potluckParticipant",
    "potluckHero",
    "sousChef",
    "starboarded",
    "seeds100",
    "seeds500",
    "seeds1000",
    "waterOther100",
    "waterOther1000",
    "waterOther10000",
    "waterOther100000",
    "fruitHarvest",
    "trophyThistleHarvest",
];
export function parseMeritBadgeSlug(check) {
    if (!MERIT_BADGE_SLUGS.includes(check)) {
        throw new Error(`Invalid MeritBadgeSlug: ${check}`);
    }
    return check;
}
export function isMeritBadgeSlug(check) {
    return MERIT_BADGE_SLUGS.includes(check);
}
export function getMeritBadgeDefinition(slug) {
    return MERIT_BADGES[slug];
}
export const MERIT_BADGES = {
    minecrafter: {
        slug: "minecrafter",
        name: "Minecrafter",
        description: "This Camper is a player on the Minecraft Realm",
        level: 1,
        icon: BadgeImages.minecrafter,
    },
    trial1complete: {
        slug: "trial1complete",
        name: "MC Trial 1",
        description: "This Camper has cleared Trial 1: The Floor is Lava in the Minecraft Realm",
        level: 2,
        icon: BadgeImages.trial1complete,
    },
    trial1Exalted: {
        slug: "trial1Exalted",
        name: "MC Trial 1 Exalted",
        description: "This Camper has found every secret in Trial 1: The Floor is Lava in the Minecraft Realm",
        level: 3,
        icon: BadgeImages.trial1Exalted,
    },
    trial2complete: {
        slug: "trial2complete",
        name: "MC Trial 2",
        description: "This Camper has cleared Trial 1: Library of Souls in the Minecraft Realm",
        level: 2,
        icon: BadgeImages.trial2complete,
    },
    trial2Exalted: {
        slug: "trial2Exalted",
        name: "MC Trial 2 Exalted",
        description: "This Camper has found every secret in Trial 2: Library of Souls in the Minecraft Realm",
        level: 3,
        icon: BadgeImages.trial2Exalted,
    },
    lodgeLaunch: {
        slug: "lodgeLaunch",
        name: "Lodge Discovery",
        description: "This Camper was here when the Lodge was found",
        level: 1,
        icon: BadgeImages.lodgeLaunch,
    },
    botanyPropagator: {
        slug: "botanyPropagator",
        name: "Propagator",
        description: "This Camper has planted a flower",
        level: 1,
        icon: BadgeImages.botanyPropagator,
    },
    botanyGreenThumb: {
        slug: "botanyGreenThumb",
        name: "Green Thumb",
        description: "This Camper has successfully harvested a flower",
        level: 1,
        icon: BadgeImages.botanyGreenThumb,
    },
    botanyGrowTogether: {
        slug: "botanyGrowTogether",
        name: "Grow Together",
        description: "This Camper watered another Camper's flower with 10 or more Silkwater.",
        level: 2,
        icon: BadgeImages.botanyGrowTogether,
    },
    visitedSkyCafe: {
        slug: "visitedSkyCafe",
        name: "Cafe in the Clouds",
        description: "This Camper has visited the Sky Cafe",
        level: 2,
        icon: BadgeImages.visitedSkyCafe,
    },
    sparkleFoot: {
        slug: "sparkleFoot",
        name: "Sparklefoot",
        description: "This Camper has donned a pair of Cosmic Socks",
        level: 1,
        icon: BadgeImages.sparkleFoot,
    },
    stellarvibe2022: {
        slug: "stellarvibe2022",
        name: "Stellarvibe 2022",
        description: "This Camper opened a gift during Stellarvibe 2022",
        level: 3,
        icon: BadgeImages.stellarvibe2022,
    },
    stellarvibe2024: {
        slug: "stellarvibe2024",
        name: "Stellarvibe 2024",
        description: "This Camper cultivated and gifted a Joyblossom fruit. Or was it just a present? Was it a fruit? That's unclear, honestly.",
        level: 3,
        icon: BadgeImages.stellarvibe2024,
    },
    stellarvibe2024Max: {
        slug: "stellarvibe2024Max",
        name: "Maximum Joy",
        description: "This camper cultivated a Maximum Joy gift and gave it to someone else during Stellarvibe 2024!",
        level: 3,
        icon: BadgeImages.stellarvibe2024Max,
    },
    thunderstruck: {
        slug: "thunderstruck",
        name: "Thunderstruck",
        description: "This Camper has been struck by lightning!",
        level: 2,
        icon: BadgeImages.thunderstruck,
    },
    selfthunderstruck: {
        slug: "selfthunderstruck",
        name: "Whoops!",
        description: "This Camper has struck themselves with lightning!",
        level: 3,
        icon: BadgeImages.selfthunderstruck,
    },
    potluckParticipant: {
        slug: "potluckParticipant",
        name: "Potluck Participant",
        description: "This Camper has donated ingredients to the Gilded Galley",
        level: 1,
        icon: BadgeImages.potluckParticipant,
    },
    potluckHero: {
        slug: "potluckHero",
        name: "Potluck Hero",
        description: `This Camper donated a full day's worth of food items at once to the Gilded Galley`,
        level: 2,
        icon: BadgeImages.potluckHero,
    },
    sousChef: {
        slug: "sousChef",
        name: "Sous Chef",
        description: "This Camper donated at least 500 food items in total to the Gilded Galley",
        level: 2,
        icon: BadgeImages.sousChef,
    },
    starboarded: {
        slug: "starboarded",
        name: "Starboarded",
        description: "This Camper has had a Discord message make it to the Starboard",
        level: 1,
        icon: BadgeImages.starboarded,
    },
    seeds100: {
        slug: "seeds100",
        name: "Crop Tender",
        description: "This Camper has planted at least 100 seeds in Botany",
        level: 1,
        icon: BadgeImages.seeds100,
    },
    seeds500: {
        slug: "seeds500",
        name: "Prolific Propagator",
        description: "This Camper has planted at least 500 seeds in Botany",
        level: 2,
        icon: BadgeImages.seeds500,
    },
    seeds1000: {
        slug: "seeds1000",
        name: "Bee-kin of Hope",
        description: "This Camper has planted at least 1,000 seeds in Botany",
        level: 3,
        icon: BadgeImages.seeds1000,
    },
    waterOther100: {
        slug: "waterOther100",
        name: "Friendly Farmer",
        description: "This Camper has spent at least 100 Silkwater on other Camper's crops",
        level: 1,
        icon: BadgeImages.waterOther100,
    },
    waterOther1000: {
        slug: "waterOther1000",
        name: "Water Wizard",
        description: "This Camper has spent at least 1,000 Silkwater on other Camper's crops!",
        level: 2,
        icon: BadgeImages.waterOther1000,
    },
    waterOther10000: {
        slug: "waterOther10000",
        name: "Intense Irrigator",
        description: "This Camper has spent at least 10,000 Silkwater on other Camper's crops!",
        level: 2,
        icon: BadgeImages.waterOther10000,
    },
    waterOther100000: {
        slug: "waterOther100000",
        name: "Astonishing Agriculturalist",
        description: "This Camper has spent at least 100,000 Silkwater on other Camper's crops! WOW!",
        level: 3,
        icon: BadgeImages.waterOther100000,
    },
    fruitHarvest: {
        slug: "fruitHarvest",
        name: "Feeling Fruity",
        description: "This Camper has successfully grown and harvested a fruit tree in Botany.",
        level: 2,
        icon: BadgeImages.fruitHarvest,
    },
    trophyThistleHarvest: {
        slug: "trophyThistleHarvest",
        name: "Triumphant Treehugger",
        description: "This Camper has successfully grown and harvested a Trophy Thistle in Botany.",
        level: 3,
        icon: BadgeImages.trophyThistleHarvest,
    },
};
