import { z } from "zod";
import { type ItemSlug, type SeedItemSlug } from "./items";
export declare const MAX_FLOWERS_PER_USER = 10;
export declare const MAX_FLOWER_WATER_LEVEL = 100;
export declare const FLOWER_SLUGS: readonly ["astralDaisy", "voidIvy", "crystalOrchid", "bloodLily", "obsidianRose", "rainbowLotus", "dragonleaf", "wanderingIce", "lightningLotus", "smoulderingRose", "stardustBlossom", "celestialBulb", "celestialBoonflower", "astralMangoTree", "spectralPapayaTree", "ritualPumpkin", "acidBlossom", "trophyThistle", "joyroot", "joyblossom", "joybrushTangle"];
export declare const FlowerSlugSchema: z.ZodEnum<["astralDaisy", "voidIvy", "crystalOrchid", "bloodLily", "obsidianRose", "rainbowLotus", "dragonleaf", "wanderingIce", "lightningLotus", "smoulderingRose", "stardustBlossom", "celestialBulb", "celestialBoonflower", "astralMangoTree", "spectralPapayaTree", "ritualPumpkin", "acidBlossom", "trophyThistle", "joyroot", "joyblossom", "joybrushTangle"]>;
export type FlowerSlug = z.infer<typeof FlowerSlugSchema>;
export interface FlowerDefinition {
    name: string;
    slug: FlowerSlug;
    description: string;
    waterConsumptionRate: number;
    growingTicks: number;
    loot: {
        conduitDropMin: number;
        conduitDropMax: number;
        possibleItemDrops: ItemSlug[];
        guaranteedItemDrops: ItemSlug[];
        itemDropMin: number;
        itemDropMax: number;
    };
    icon: string;
    destroyOnHarvest: boolean;
    regrowthTicks?: number;
}
export declare const BotanyPlantSchema: z.ZodObject<{
    slug: z.ZodEnum<["astralDaisy", "voidIvy", "crystalOrchid", "bloodLily", "obsidianRose", "rainbowLotus", "dragonleaf", "wanderingIce", "lightningLotus", "smoulderingRose", "stardustBlossom", "celestialBulb", "celestialBoonflower", "astralMangoTree", "spectralPapayaTree", "ritualPumpkin", "acidBlossom", "trophyThistle", "joyroot", "joyblossom", "joybrushTangle"]>;
    id: z.ZodNumber;
    ownerId: z.ZodNumber;
    plantedAt: z.ZodNumber;
    waterLevel: z.ZodNumber;
    waterMissing: z.ZodNumber;
    waterRate: z.ZodNumber;
    ticksRemaining: z.ZodNumber;
    name: z.ZodString;
    description: z.ZodString;
    icon: z.ZodString;
    isGrowing: z.ZodBoolean;
    isWaterable: z.ZodBoolean;
    isDead: z.ZodBoolean;
    isReady: z.ZodBoolean;
}, "strip", z.ZodTypeAny, {
    id: number;
    name: string;
    slug: "astralDaisy" | "voidIvy" | "crystalOrchid" | "bloodLily" | "obsidianRose" | "rainbowLotus" | "dragonleaf" | "wanderingIce" | "lightningLotus" | "smoulderingRose" | "stardustBlossom" | "celestialBulb" | "celestialBoonflower" | "astralMangoTree" | "spectralPapayaTree" | "ritualPumpkin" | "acidBlossom" | "trophyThistle" | "joyroot" | "joyblossom" | "joybrushTangle";
    description: string;
    isReady: boolean;
    icon: string;
    ownerId: number;
    plantedAt: number;
    waterLevel: number;
    waterMissing: number;
    waterRate: number;
    ticksRemaining: number;
    isGrowing: boolean;
    isWaterable: boolean;
    isDead: boolean;
}, {
    id: number;
    name: string;
    slug: "astralDaisy" | "voidIvy" | "crystalOrchid" | "bloodLily" | "obsidianRose" | "rainbowLotus" | "dragonleaf" | "wanderingIce" | "lightningLotus" | "smoulderingRose" | "stardustBlossom" | "celestialBulb" | "celestialBoonflower" | "astralMangoTree" | "spectralPapayaTree" | "ritualPumpkin" | "acidBlossom" | "trophyThistle" | "joyroot" | "joyblossom" | "joybrushTangle";
    description: string;
    isReady: boolean;
    icon: string;
    ownerId: number;
    plantedAt: number;
    waterLevel: number;
    waterMissing: number;
    waterRate: number;
    ticksRemaining: number;
    isGrowing: boolean;
    isWaterable: boolean;
    isDead: boolean;
}>;
export type BotanyPlant = z.infer<typeof BotanyPlantSchema>;
export declare const BotanyCommunityGardenSchema: z.ZodRecord<z.ZodNumber, z.ZodArray<z.ZodObject<{
    slug: z.ZodEnum<["astralDaisy", "voidIvy", "crystalOrchid", "bloodLily", "obsidianRose", "rainbowLotus", "dragonleaf", "wanderingIce", "lightningLotus", "smoulderingRose", "stardustBlossom", "celestialBulb", "celestialBoonflower", "astralMangoTree", "spectralPapayaTree", "ritualPumpkin", "acidBlossom", "trophyThistle", "joyroot", "joyblossom", "joybrushTangle"]>;
    id: z.ZodNumber;
    ownerId: z.ZodNumber;
    plantedAt: z.ZodNumber;
    waterLevel: z.ZodNumber;
    waterMissing: z.ZodNumber;
    waterRate: z.ZodNumber;
    ticksRemaining: z.ZodNumber;
    name: z.ZodString;
    description: z.ZodString;
    icon: z.ZodString;
    isGrowing: z.ZodBoolean;
    isWaterable: z.ZodBoolean;
    isDead: z.ZodBoolean;
    isReady: z.ZodBoolean;
}, "strip", z.ZodTypeAny, {
    id: number;
    name: string;
    slug: "astralDaisy" | "voidIvy" | "crystalOrchid" | "bloodLily" | "obsidianRose" | "rainbowLotus" | "dragonleaf" | "wanderingIce" | "lightningLotus" | "smoulderingRose" | "stardustBlossom" | "celestialBulb" | "celestialBoonflower" | "astralMangoTree" | "spectralPapayaTree" | "ritualPumpkin" | "acidBlossom" | "trophyThistle" | "joyroot" | "joyblossom" | "joybrushTangle";
    description: string;
    isReady: boolean;
    icon: string;
    ownerId: number;
    plantedAt: number;
    waterLevel: number;
    waterMissing: number;
    waterRate: number;
    ticksRemaining: number;
    isGrowing: boolean;
    isWaterable: boolean;
    isDead: boolean;
}, {
    id: number;
    name: string;
    slug: "astralDaisy" | "voidIvy" | "crystalOrchid" | "bloodLily" | "obsidianRose" | "rainbowLotus" | "dragonleaf" | "wanderingIce" | "lightningLotus" | "smoulderingRose" | "stardustBlossom" | "celestialBulb" | "celestialBoonflower" | "astralMangoTree" | "spectralPapayaTree" | "ritualPumpkin" | "acidBlossom" | "trophyThistle" | "joyroot" | "joyblossom" | "joybrushTangle";
    description: string;
    isReady: boolean;
    icon: string;
    ownerId: number;
    plantedAt: number;
    waterLevel: number;
    waterMissing: number;
    waterRate: number;
    ticksRemaining: number;
    isGrowing: boolean;
    isWaterable: boolean;
    isDead: boolean;
}>, "many">>;
export type BotanyCommunityGarden = z.infer<typeof BotanyCommunityGardenSchema>;
/**
 * Given a seed item, pick a flower to plant
 * @param slug The seed item to pick a flower from
 * @returns The slug of the flower to plant
 */
export declare function getFlowerFromSeed(slug: SeedItemSlug): "astralDaisy" | "voidIvy" | "crystalOrchid" | "bloodLily" | "obsidianRose" | "rainbowLotus" | "dragonleaf" | "wanderingIce" | "lightningLotus" | "smoulderingRose" | "stardustBlossom" | "celestialBulb" | "celestialBoonflower" | "astralMangoTree" | "spectralPapayaTree" | "ritualPumpkin" | "acidBlossom" | "trophyThistle" | "joyroot" | "joyblossom" | "joybrushTangle";
declare const FLOWER_DEFINITIONS: Record<FlowerSlug, FlowerDefinition>;
export { FLOWER_DEFINITIONS };
export declare function getFlowerDefinition(slug: FlowerSlug): FlowerDefinition;
