import { z } from "zod";
import { ConcoctionImages, SeedImages } from "./assets";
import { ITEM_SLUGS, getItemDefinition, } from "./items";
export const CONCOCTION_SLUGS = [
    "liquidWanderingIce",
    "solidLiquidWanderingIce",
    "lightningInABottle",
    "soulWater",
    "silkwaterMist",
    "joyfultilizer",
    "maxJoyfultilizer",
    "quantumSeed",
    "fourthDimensionalPlantFood",
];
export function parseConcoctionSlug(check) {
    if (!CONCOCTION_SLUGS.includes(check)) {
        throw new Error(`Invalid ConcoctionSlug: ${check}`);
    }
    return check;
}
export function isConcoctionSlug(check) {
    return CONCOCTION_SLUGS.includes(check);
}
export const ConcoctionRecipeSchema = z.object({
    slug: z.enum(CONCOCTION_SLUGS),
    title: z.string(),
    description: z.string(),
    image: z.string(),
    brewTime: z.number(),
    brewTimeLeniency: z.number(),
    ingredients: z.array(z.tuple([z.enum(ITEM_SLUGS), z.number()])),
    result: z.enum(ITEM_SLUGS),
});
export const ConcoctionSchema = z.object({
    id: z.number(),
    camperId: z.number(),
    slug: z.enum(CONCOCTION_SLUGS),
    turnsBrewing: z.number(),
    state: z.string(),
    recipe: ConcoctionRecipeSchema,
    isReady: z.boolean(),
    autoStop: z.boolean(),
});
export const ConcoctionStateSchema = z.enum([
    "early",
    "ready",
    "late",
    "destroyed",
]);
export const CONCOCTION_DEFINITIONS = {
    liquidWanderingIce: {
        title: "Liquid Wandering Ice",
        description: 'You\'d think this would just be "Wandering Water," but nope. Wandering Ice, but liquid.',
        image: ConcoctionImages.liquidWanderingIce,
        brewTime: 1,
        brewTimeLeniency: 5,
        ingredients: [
            ["livingIcicle", 1],
            ["flaskSmall", 1],
        ],
        result: "liquidWanderingIce",
        recipe: "recipeLiquidWanderingIce",
    },
    solidLiquidWanderingIce: {
        title: "Solid Liquid Wandering Ice",
        description: "It's liquid, but it's also ice. It's also wandering. It's also solid.",
        image: ConcoctionImages.solidLiquidWanderingIce,
        brewTime: 1,
        brewTimeLeniency: 5,
        ingredients: [["liquidWanderingIce", 1]],
        result: "livingIcicle",
        recipe: "recipeSolidLiquidWanderingIce",
    },
    lightningInABottle: {
        title: "Lightning in a Bottle",
        description: "Just kinda gotta angle the flask's opening towards the sky just right and then...",
        image: ConcoctionImages.lightningInABottle,
        brewTime: 3,
        brewTimeLeniency: 2,
        ingredients: [
            ["harvestedLightningLotus", 1],
            ["mermaidScale", 1],
            ["flaskSmall", 1],
        ],
        result: "lightningInABottle",
        recipe: "recipeLightningInABottle",
    },
    soulWater: {
        title: "Soul Water",
        description: "Life essence distilled to liquid. Capable of reviving dead plants.",
        image: ConcoctionImages.soulWater,
        brewTime: 6,
        brewTimeLeniency: 2,
        ingredients: [
            ["liquidWanderingIce", 2],
            ["harvestedBloodLily", 1],
            ["stardustBag", 1],
            ["flaskSmall", 1],
        ],
        result: "soulWater",
        recipe: "recipeSoulWater",
    },
    silkwaterMist: {
        title: "Silkwater Mist",
        description: "A refreshing mist of Silkwater which fills the space it's released in. Waters all plants for all Campers to full.",
        image: ConcoctionImages.silkwaterMist,
        brewTime: 3,
        brewTimeLeniency: 2,
        ingredients: [
            ["liquidWanderingIce", 1],
            ["harvestedRainbowLotus", 1],
            ["silkwaterJug", 1],
            ["mermaidScale", 1],
            ["spritzBottle", 1],
        ],
        result: "silkwaterMist",
        recipe: "recipeSilkwaterMist",
    },
    joyfultilizer: {
        title: "Joyfultilizer",
        description: "Spread the joy with this magical fertilizer. Use on a Joyroot plant and see what happens!",
        image: ConcoctionImages.Joyfultilizer,
        brewTime: 4,
        brewTimeLeniency: 2,
        ingredients: [
            ["joyrootSeed", 10],
            ["harvestedAstralDaisy", 1],
            ["timerootBark", 1],
        ],
        result: "joyfultilizer",
        recipe: "recipeBlankPlaceholder",
        hidden: true,
    },
    maxJoyfultilizer: {
        title: "Max Joyfultilizer",
        description: "The most joyous fertilizer. Use on a Joyblossom and see what happens!",
        image: ConcoctionImages.MaximumJoyfultilizer,
        brewTime: 18,
        brewTimeLeniency: 2,
        ingredients: [
            ["joyrootSeed", 500],
            ["timerootBark", 5],
            ["mermaidScale", 5],
            ["harvestedBloodLily", 1],
            ["harvestedAcidBlossom", 1],
            ["fourthDimensionalPlantFood", 1],
            ["silkwaterMist", 1],
            ["soulWater", 1],
        ],
        result: "maxJoyfultilizer",
        recipe: "recipeBlankPlaceholder",
        hidden: true,
    },
    quantumSeed: {
        title: "Quantum Seed",
        description: "A seed containing everything (and every not-thing) at once",
        image: SeedImages.quantumSeed,
        brewTime: 2,
        brewTimeLeniency: 5,
        ingredients: [
            ["mundaneSeed", 1],
            ["stardustBag", 1],
        ],
        result: "quantumSeed",
        recipe: "recipeQuantumSeed",
    },
    fourthDimensionalPlantFood: {
        title: "4th Dimensional Plant Food",
        description: "Plant food unbound from the linear flow of time. Use it on a plant to advance its growth by 1 turn.",
        image: ConcoctionImages.FourthDimensionalPlantFood,
        brewTime: 5,
        brewTimeLeniency: 1,
        ingredients: [
            ["timerootBark", 1],
            ["harvestedVoidIvy", 1],
            ["flaskSmall", 1],
        ],
        result: "fourthDimensionalPlantFood",
        recipe: "recipeFourthDimensionalPlantFood",
    },
};
export function getConcoctionDefinition(slug) {
    return CONCOCTION_DEFINITIONS[slug];
}
export const RECIPE_MAPPING = {
    solidLiquidWanderingIce: "recipeSolidLiquidWanderingIce",
    joyfultilizer: "recipeJoyfultilizer",
    maxJoyfultilizer: "recipeMaxJoyfultilizer",
    fourthDimensionalPlantFood: "recipeFourthDimensionalPlantFood",
    lightningInABottle: "recipeLightningInABottle",
    liquidWanderingIce: "recipeLiquidWanderingIce",
    silkwaterMist: "recipeSilkwaterMist",
    soulWater: "recipeSoulWater",
    quantumSeed: "recipeQuantumSeed",
};
/**
 * Retrieves the expanded concoction definition associated with a given concoction slug.
 *
 * @param cocncoctionSlug - The slug of the concoction to find the expanded definition for.
 * @returns The expanded definition of the concoction associated with the given slug.
 * @throws Will throw an error if no concoction is found for the given slug.
 */
export function getExpandedConcoction(cocncoctionSlug) {
    const concoction = CONCOCTION_DEFINITIONS[cocncoctionSlug];
    if (!concoction) {
        throw new Error(`DATA ERROR: No concoction found for slug ${cocncoctionSlug}`);
    }
    const resultItem = getItemDefinition(concoction.result);
    const recipeItem = getItemDefinition(concoction.recipe);
    return {
        ...concoction,
        resultItem,
        recipeItem,
    };
}
/**
 * Retrieves an expanded concoction based on the provided source item definition and slug.
 *
 * @param source - The item definition which can be a recipe or a concoction.
 * @param sourceSlug - The slug of the source item.
 * @returns The expanded concoction derived from the source.
 * @throws Will throw an error if the source item is not a valid recipe or concoction.
 */
export function getExpandedRelatedConcoction(source) {
    if (!source.relatedConcoction) {
        throw new Error(`DATA ERROR: Item ${source.name} has no related concoction`);
    }
    return getExpandedConcoction(source.relatedConcoction);
}
