import { z } from "zod";
import type { FlowerSlug } from "../botany";
import { type ConcoctionSlug } from "../chemistry";
import { type ItemSlug } from "./internal";
export declare const ITEM_CATEGORIES: readonly ["redeemable", "cosmetic", "container", "seed", "flower", "consumable", "card", "food", "relic", "scroll", "concoction", "recipe", "component"];
export declare const ItemCategorySchema: z.ZodEnum<["redeemable", "cosmetic", "container", "seed", "flower", "consumable", "card", "food", "relic", "scroll", "concoction", "recipe", "component"]>;
export type ItemCategory = z.infer<typeof ItemCategorySchema>;
export declare const ITEM_RARITIES: readonly ["common", "uncommon", "rare", "relic"];
export declare const ItemRaritySchema: z.ZodEnum<["common", "uncommon", "rare", "relic"]>;
export type ItemRarity = z.infer<typeof ItemRaritySchema>;
export interface ItemDefinition {
    slug: ItemSlug;
    name: string;
    description: string;
    flavorText: string;
    rarity: ItemRarity;
    icon: string;
    value: number;
    category: ItemCategory;
    dropIcon: string;
    canBeUsed?: boolean;
    preserveAfterUsing?: boolean;
    canUseInBotany?: boolean;
    relatedConcoction?: ConcoctionSlug;
    relatedFlower?: FlowerSlug | FlowerSlug[];
    contents?: {
        count: number;
        items: ItemSlug[];
    };
    cardGeneration?: string;
    hidden?: boolean;
}
export interface SeedItemDefinition extends ItemDefinition {
    category: "seed";
    relatedFlower: FlowerSlug | FlowerSlug[];
}
export declare const ItemSchema: z.ZodObject<{
    itemId: z.ZodNumber;
    camperId: z.ZodNumber;
    slug: z.ZodEnum<["silkwaterJug", "silkwaterJugLarge", "cracklingRainmeter", "swirlingStormwrangler", "fourthDimensionalPlantFood", "tcGen1Beeatrice", "tcGen1Campfire", "tcGen1Chisel", "tcGen1Cloudsailor", "tcGen1Lodge", "tcGen1Murmus", "tcGen1MurmusFoil", "tcGen1Giant", "tcGen1LettersInFlight", "tcGen1SkyCafe", "tcGen1UnknownLunar", "tcGen1UnknownSolar", "tcGen1SecretSauce", "tcGen1GillroyFoil", "tcGen2DapperInPurple", "tcGen2DefinitelyFits", "tcGen2KnowsHowItWorks", "tcGen2Casual", "tcGen2Arcwild", "tcGen2Mysthull", "tcGen2Lelatoll", "tcGen2Skyhook", "tcGen2Goldspire", "tcGen2DukePepperbottom", "tcGen2StudioFoil", "randomScrap", "mermaidScale", "timerootBark", "spritzBottle", "livingIcicle", "stardustBag", "flaskSmall", "harvestedAstralDaisy", "harvestedVoidIvy", "harvestedCrystalOrchid", "harvestedBloodLily", "harvestedRainbowLotus", "harvestedDragonleaf", "harvestedAcidBlossom", "harvestedLightningLotus", "recipeLiquidWanderingIce", "recipeSolidLiquidWanderingIce", "recipeLightningInABottle", "recipeSoulWater", "recipeSilkwaterMist", "recipeQuantumSeed", "recipeFourthDimensionalPlantFood", "recipeBlankPlaceholder", "liquidWanderingIce", "soulWater", "silkwaterMist", "lightningInABottle", "crystalGeode", "treasureChest", "leafPile", "fallenStar", "frozenTreasureChest", "heartShapedBox", "shippingCrate", "giantsGift", "seedPouch", "tcBoosterPackGen1Common", "tcBoosterPackGen1Uncommon", "tcBoosterPackGen1Part2", "tcBoosterPackGen1Full", "tcBoosterPackGen2Drop1", "cosmicPinwheel", "discardedJacket", "trident", "goldLeaf", "doubloon", "harvestedObsidianRose", "harvestedSmoulderingRose", "harvestedRitualPumpkin", "harvestedTrophyThistle", "astralMango", "spectralPapaya", "mysticMorel", "otherworldlyOnion", "bansheeBerry", "secretSauce", "cosmicSocks", "compositionNotebook", "shatteredSpyglassLens", "shatteredSpyglassBody", "shatteredSpyglassEyepiece", "restoredSpyglass", "netheriteVoucher", "fatefulLoom", "bullhorn", "fleetingFeather", "celestialStone", "stellarvibePresentSmall2023", "stellarvibePresentMedium2023", "stellarvibePresentSmallGlowing2023", "stellarvibePresentMediumGlowing2023", "stellarvibePresent2024", "stellarvibePresentGlowing2024", "stellarvibePresent2024Max", "stellarvibePresent2024GlowingMax", "stellarvibePresentSmall", "stellarvibePresentSmallGlowing", "stellarvibePresentMedium", "stellarvibePresentMediumGlowing", "stellarvibePresentLarge", "stellarvibePresentLargeGlowing", "joyfultilizer", "maxJoyfultilizer", "joyrootSeed", "recipeJoyfultilizer", "recipeMaxJoyfultilizer", "scrollOfCultivation", "scrollOfGreaterCultivation", "quantumSeed", "mundaneSeed", "voidIvySeed", "crystalOrchidSeed", "bloodLilySeed", "obsidianRoseSeed", "rainbowLotusSeed", "dragonleafSeed", "smoulderingRoseSeed", "wanderingIceSeed", "stardustBlossomSeed", "celestialBulbSeed", "celestialBoonflowerSeed", "astralMangoTreeSeed", "spectralPapayaTreeSeed", "ritualPumpkinSeed", "trophyThistleSeed", "acidBlossomSeed"]>;
    name: z.ZodString;
    description: z.ZodString;
    flavorText: z.ZodString;
    icon: z.ZodString;
    value: z.ZodNumber;
    category: z.ZodEnum<["redeemable", "cosmetic", "container", "seed", "flower", "consumable", "card", "food", "relic", "scroll", "concoction", "recipe", "component"]>;
    categoryTitle: z.ZodString;
    preserveAfterUsing: z.ZodBoolean;
    canBeUsed: z.ZodBoolean;
    canUseInBotany: z.ZodBoolean;
    rarity: z.ZodEnum<["common", "uncommon", "rare", "relic"]>;
    relatedConcoction: z.ZodOptional<z.ZodEnum<["liquidWanderingIce", "solidLiquidWanderingIce", "lightningInABottle", "soulWater", "silkwaterMist", "joyfultilizer", "maxJoyfultilizer", "quantumSeed", "fourthDimensionalPlantFood"]>>;
}, "strip", z.ZodTypeAny, {
    value: number;
    name: string;
    slug: "silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed";
    description: string;
    camperId: number;
    itemId: number;
    flavorText: string;
    icon: string;
    category: "recipe" | "redeemable" | "cosmetic" | "container" | "seed" | "flower" | "consumable" | "card" | "food" | "relic" | "scroll" | "concoction" | "component";
    categoryTitle: string;
    preserveAfterUsing: boolean;
    canBeUsed: boolean;
    canUseInBotany: boolean;
    rarity: "relic" | "common" | "uncommon" | "rare";
    relatedConcoction?: "fourthDimensionalPlantFood" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "joyfultilizer" | "maxJoyfultilizer" | "quantumSeed" | "solidLiquidWanderingIce" | undefined;
}, {
    value: number;
    name: string;
    slug: "silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed";
    description: string;
    camperId: number;
    itemId: number;
    flavorText: string;
    icon: string;
    category: "recipe" | "redeemable" | "cosmetic" | "container" | "seed" | "flower" | "consumable" | "card" | "food" | "relic" | "scroll" | "concoction" | "component";
    categoryTitle: string;
    preserveAfterUsing: boolean;
    canBeUsed: boolean;
    canUseInBotany: boolean;
    rarity: "relic" | "common" | "uncommon" | "rare";
    relatedConcoction?: "fourthDimensionalPlantFood" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "joyfultilizer" | "maxJoyfultilizer" | "quantumSeed" | "solidLiquidWanderingIce" | undefined;
}>;
export type GameItem = z.infer<typeof ItemSchema>;
export declare const ItemUseResultSchema: z.ZodUnion<[z.ZodString, z.ZodObject<{
    error: z.ZodString;
}, "strip", z.ZodTypeAny, {
    error: string;
}, {
    error: string;
}>]>;
export type ItemUseResult = z.infer<typeof ItemUseResultSchema>;
