import { z } from "zod";
import { pickOne } from "../util";
import { ITEM_SLUGS } from "./items";
export const ROLL_CUTOFFS = {
    fail: 1,
    low: 8,
    mid: 15,
    high: 20,
    crit: 21,
};
export const PortentSchema = z.object({
    id: z.number(),
    camperId: z.number(),
    date: z.string(),
    roll: z.number(),
    description: z.string(),
    itemSlug: z.enum(ITEM_SLUGS),
});
/**************
 * DROP LISTS *
 **************/
export const PORTENT_DROPS = {
    fail: ["cosmicPinwheel", "randomScrap"],
    low: [
        "compositionNotebook",
        "cosmicSocks",
        "seedPouch",
        "quantumSeed",
        "silkwaterJug",
        "mermaidScale",
        "spritzBottle",
        "randomScrap",
    ],
    mid: [
        "liquidWanderingIce",
        "compositionNotebook",
        "scrollOfCultivation",
        "swirlingStormwrangler",
        "mermaidScale",
    ],
    high: [
        "scrollOfGreaterCultivation",
        "mermaidScale",
        "lightningInABottle",
        "harvestedSmoulderingRose",
    ],
    crit: ["doubloon", "silkwaterMist", "soulWater"],
};
export const ALL_POSSIBLE_PORTENT_DROPS = Object.values(PORTENT_DROPS).flat();
export function isInPortentDropList(itemSlug) {
    return ALL_POSSIBLE_PORTENT_DROPS.includes(itemSlug);
}
export function getPortentDrop(value) {
    if (value === ROLL_CUTOFFS.fail) {
        return pickOne(PORTENT_DROPS.fail);
    }
    if (value < ROLL_CUTOFFS.low) {
        return pickOne(PORTENT_DROPS.low);
    }
    if (value < ROLL_CUTOFFS.mid) {
        return pickOne(PORTENT_DROPS.mid);
    }
    if (value < ROLL_CUTOFFS.high) {
        return pickOne(PORTENT_DROPS.high);
    }
    return pickOne(PORTENT_DROPS.crit);
}
/******************
 * OUTCOME TEXTS *
 ******************/
export const PORTENT_OUTCOMES = {
    fail: [
        "Oof. Just oof. Like... oof.",
        "That—maybe stay inside today?",
        "If luck were a lady, she would block you.",
        "You know what? Maybe today isn't your day.",
        "I'm not a betting Campfire, but if I were, I would not bet on you.",
    ],
    low: [
        "Could be worse!",
        "It's... not great, but it's not terrible.",
        "You know, you could have done worse.",
        "Well, it's not a total disaster.",
        "Can always go up from here, right?",
    ],
    mid: [
        "Not bad! Not bad at all!",
        "You know, that's pretty good!",
        "All things considered, pretty good!",
        "Hey, that's pretty good!",
    ],
    high: [
        "Wow! That's really good!",
        "Hey, that's a great roll!",
        "You're on fire today!",
        "That's a fantastic roll!",
        "You're really on a roll!",
    ],
    crit: [
        "AMAZING!",
        "We were all here to witness greatness.",
        "I stand in awe. Well, I don't stand, I have no legs. But if I had legs, I'd be standing in awe.",
        "You're a legend!",
        "Your mastery of the dice is unparalleled!",
    ],
};
export function getPortentOutcomeDescription(value) {
    if (value === ROLL_CUTOFFS.fail) {
        return pickOne(PORTENT_OUTCOMES.fail);
    }
    if (value < ROLL_CUTOFFS.low) {
        return pickOne(PORTENT_OUTCOMES.low);
    }
    if (value < ROLL_CUTOFFS.mid) {
        return pickOne(PORTENT_OUTCOMES.mid);
    }
    if (value < ROLL_CUTOFFS.high) {
        return pickOne(PORTENT_OUTCOMES.high);
    }
    return pickOne(PORTENT_OUTCOMES.crit);
}
export const PortentRelayEvents = {
    "portent:roll": PortentSchema,
};
