import { z } from "zod";
/*******************
 * WORLD CONSTANTS *
 *******************/
export declare const DAILY_RESET_UTC_HOUR = 8;
export declare const WORLD_TICKS_SINCE_EPOCH_FLAG = "world.ticksSinceEpoch";
export declare const WORLD_DAYS_SINCE_EPOCH_FLAG = "world.daysSinceEpoch";
export declare const WEATHER_OPTIONS: readonly ["blue lightning", "starfall", "full skies", "no sky", "moths... lots of moths", "cloudfall", "ducks", "a full moon", "ten full moons", "sunshine from a star long since forgotten", "dogs", "cats", "literally just rain", "moonbeams", "sunbeams", "auroras", "ghost showers", "red lightning", "purple lightning", "a bloodmoon", "twelve angry men", "reverse showers", "pumpkins", "pomegranite seeds", "more vibes than you'd expect", "a heavy ghost field", "a light ghost field", "quadruple rainbows", "silkwater rain", "acid storms"];
export declare const TEMPERATURE_OPTIONS: readonly ["freezing", "cold", "chilly", "temperate", "pretty much normal", "room temp", "a tad humid", "temporal temps", "unfathomably nice", "perfect", "no temperature", "warm", "hot", "sweltering"];
/****************
 * WORLD SHAPES *
 ****************/
export type Weather = (typeof WEATHER_OPTIONS)[number];
export type Temperature = (typeof TEMPERATURE_OPTIONS)[number];
export declare const COLD_TEMPS: Temperature[];
export declare const HOT_TEMPS: Temperature[];
export declare const GHOST_WEATHERS: Weather[];
export declare const WeatherEffectSchema: z.ZodObject<{
    system: z.ZodString;
    effect: z.ZodString;
}, "strip", z.ZodTypeAny, {
    system: string;
    effect: string;
}, {
    system: string;
    effect: string;
}>;
export type WeatherEffect = z.infer<typeof WeatherEffectSchema>;
export declare const WeatherInfoShapeSchema: z.ZodObject<{
    conditions: z.ZodEnum<["blue lightning", "starfall", "full skies", "no sky", "moths... lots of moths", "cloudfall", "ducks", "a full moon", "ten full moons", "sunshine from a star long since forgotten", "dogs", "cats", "literally just rain", "moonbeams", "sunbeams", "auroras", "ghost showers", "red lightning", "purple lightning", "a bloodmoon", "twelve angry men", "reverse showers", "pumpkins", "pomegranite seeds", "more vibes than you'd expect", "a heavy ghost field", "a light ghost field", "quadruple rainbows", "silkwater rain", "acid storms"]>;
    temperature: z.ZodEnum<["freezing", "cold", "chilly", "temperate", "pretty much normal", "room temp", "a tad humid", "temporal temps", "unfathomably nice", "perfect", "no temperature", "warm", "hot", "sweltering"]>;
    effects: z.ZodArray<z.ZodObject<{
        system: z.ZodString;
        effect: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        system: string;
        effect: string;
    }, {
        system: string;
        effect: string;
    }>, "many">;
    isCold: z.ZodBoolean;
    isHot: z.ZodBoolean;
    isGhostly: z.ZodBoolean;
}, "strip", z.ZodTypeAny, {
    conditions: "blue lightning" | "starfall" | "full skies" | "no sky" | "moths... lots of moths" | "cloudfall" | "ducks" | "a full moon" | "ten full moons" | "sunshine from a star long since forgotten" | "dogs" | "cats" | "literally just rain" | "moonbeams" | "sunbeams" | "auroras" | "ghost showers" | "red lightning" | "purple lightning" | "a bloodmoon" | "twelve angry men" | "reverse showers" | "pumpkins" | "pomegranite seeds" | "more vibes than you'd expect" | "a heavy ghost field" | "a light ghost field" | "quadruple rainbows" | "silkwater rain" | "acid storms";
    temperature: "freezing" | "cold" | "chilly" | "temperate" | "pretty much normal" | "room temp" | "a tad humid" | "temporal temps" | "unfathomably nice" | "perfect" | "no temperature" | "warm" | "hot" | "sweltering";
    effects: {
        system: string;
        effect: string;
    }[];
    isCold: boolean;
    isHot: boolean;
    isGhostly: boolean;
}, {
    conditions: "blue lightning" | "starfall" | "full skies" | "no sky" | "moths... lots of moths" | "cloudfall" | "ducks" | "a full moon" | "ten full moons" | "sunshine from a star long since forgotten" | "dogs" | "cats" | "literally just rain" | "moonbeams" | "sunbeams" | "auroras" | "ghost showers" | "red lightning" | "purple lightning" | "a bloodmoon" | "twelve angry men" | "reverse showers" | "pumpkins" | "pomegranite seeds" | "more vibes than you'd expect" | "a heavy ghost field" | "a light ghost field" | "quadruple rainbows" | "silkwater rain" | "acid storms";
    temperature: "freezing" | "cold" | "chilly" | "temperate" | "pretty much normal" | "room temp" | "a tad humid" | "temporal temps" | "unfathomably nice" | "perfect" | "no temperature" | "warm" | "hot" | "sweltering";
    effects: {
        system: string;
        effect: string;
    }[];
    isCold: boolean;
    isHot: boolean;
    isGhostly: boolean;
}>;
export type WeatherInfoShape = z.infer<typeof WeatherInfoShapeSchema>;
export declare const WorldWeatherSchema: z.ZodObject<{
    current: z.ZodObject<{
        conditions: z.ZodEnum<["blue lightning", "starfall", "full skies", "no sky", "moths... lots of moths", "cloudfall", "ducks", "a full moon", "ten full moons", "sunshine from a star long since forgotten", "dogs", "cats", "literally just rain", "moonbeams", "sunbeams", "auroras", "ghost showers", "red lightning", "purple lightning", "a bloodmoon", "twelve angry men", "reverse showers", "pumpkins", "pomegranite seeds", "more vibes than you'd expect", "a heavy ghost field", "a light ghost field", "quadruple rainbows", "silkwater rain", "acid storms"]>;
        temperature: z.ZodEnum<["freezing", "cold", "chilly", "temperate", "pretty much normal", "room temp", "a tad humid", "temporal temps", "unfathomably nice", "perfect", "no temperature", "warm", "hot", "sweltering"]>;
        effects: z.ZodArray<z.ZodObject<{
            system: z.ZodString;
            effect: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            system: string;
            effect: string;
        }, {
            system: string;
            effect: string;
        }>, "many">;
        isCold: z.ZodBoolean;
        isHot: z.ZodBoolean;
        isGhostly: z.ZodBoolean;
    }, "strip", z.ZodTypeAny, {
        conditions: "blue lightning" | "starfall" | "full skies" | "no sky" | "moths... lots of moths" | "cloudfall" | "ducks" | "a full moon" | "ten full moons" | "sunshine from a star long since forgotten" | "dogs" | "cats" | "literally just rain" | "moonbeams" | "sunbeams" | "auroras" | "ghost showers" | "red lightning" | "purple lightning" | "a bloodmoon" | "twelve angry men" | "reverse showers" | "pumpkins" | "pomegranite seeds" | "more vibes than you'd expect" | "a heavy ghost field" | "a light ghost field" | "quadruple rainbows" | "silkwater rain" | "acid storms";
        temperature: "freezing" | "cold" | "chilly" | "temperate" | "pretty much normal" | "room temp" | "a tad humid" | "temporal temps" | "unfathomably nice" | "perfect" | "no temperature" | "warm" | "hot" | "sweltering";
        effects: {
            system: string;
            effect: string;
        }[];
        isCold: boolean;
        isHot: boolean;
        isGhostly: boolean;
    }, {
        conditions: "blue lightning" | "starfall" | "full skies" | "no sky" | "moths... lots of moths" | "cloudfall" | "ducks" | "a full moon" | "ten full moons" | "sunshine from a star long since forgotten" | "dogs" | "cats" | "literally just rain" | "moonbeams" | "sunbeams" | "auroras" | "ghost showers" | "red lightning" | "purple lightning" | "a bloodmoon" | "twelve angry men" | "reverse showers" | "pumpkins" | "pomegranite seeds" | "more vibes than you'd expect" | "a heavy ghost field" | "a light ghost field" | "quadruple rainbows" | "silkwater rain" | "acid storms";
        temperature: "freezing" | "cold" | "chilly" | "temperate" | "pretty much normal" | "room temp" | "a tad humid" | "temporal temps" | "unfathomably nice" | "perfect" | "no temperature" | "warm" | "hot" | "sweltering";
        effects: {
            system: string;
            effect: string;
        }[];
        isCold: boolean;
        isHot: boolean;
        isGhostly: boolean;
    }>;
    forecast: z.ZodArray<z.ZodObject<{
        conditions: z.ZodEnum<["blue lightning", "starfall", "full skies", "no sky", "moths... lots of moths", "cloudfall", "ducks", "a full moon", "ten full moons", "sunshine from a star long since forgotten", "dogs", "cats", "literally just rain", "moonbeams", "sunbeams", "auroras", "ghost showers", "red lightning", "purple lightning", "a bloodmoon", "twelve angry men", "reverse showers", "pumpkins", "pomegranite seeds", "more vibes than you'd expect", "a heavy ghost field", "a light ghost field", "quadruple rainbows", "silkwater rain", "acid storms"]>;
        temperature: z.ZodEnum<["freezing", "cold", "chilly", "temperate", "pretty much normal", "room temp", "a tad humid", "temporal temps", "unfathomably nice", "perfect", "no temperature", "warm", "hot", "sweltering"]>;
        effects: z.ZodArray<z.ZodObject<{
            system: z.ZodString;
            effect: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            system: string;
            effect: string;
        }, {
            system: string;
            effect: string;
        }>, "many">;
        isCold: z.ZodBoolean;
        isHot: z.ZodBoolean;
        isGhostly: z.ZodBoolean;
    }, "strip", z.ZodTypeAny, {
        conditions: "blue lightning" | "starfall" | "full skies" | "no sky" | "moths... lots of moths" | "cloudfall" | "ducks" | "a full moon" | "ten full moons" | "sunshine from a star long since forgotten" | "dogs" | "cats" | "literally just rain" | "moonbeams" | "sunbeams" | "auroras" | "ghost showers" | "red lightning" | "purple lightning" | "a bloodmoon" | "twelve angry men" | "reverse showers" | "pumpkins" | "pomegranite seeds" | "more vibes than you'd expect" | "a heavy ghost field" | "a light ghost field" | "quadruple rainbows" | "silkwater rain" | "acid storms";
        temperature: "freezing" | "cold" | "chilly" | "temperate" | "pretty much normal" | "room temp" | "a tad humid" | "temporal temps" | "unfathomably nice" | "perfect" | "no temperature" | "warm" | "hot" | "sweltering";
        effects: {
            system: string;
            effect: string;
        }[];
        isCold: boolean;
        isHot: boolean;
        isGhostly: boolean;
    }, {
        conditions: "blue lightning" | "starfall" | "full skies" | "no sky" | "moths... lots of moths" | "cloudfall" | "ducks" | "a full moon" | "ten full moons" | "sunshine from a star long since forgotten" | "dogs" | "cats" | "literally just rain" | "moonbeams" | "sunbeams" | "auroras" | "ghost showers" | "red lightning" | "purple lightning" | "a bloodmoon" | "twelve angry men" | "reverse showers" | "pumpkins" | "pomegranite seeds" | "more vibes than you'd expect" | "a heavy ghost field" | "a light ghost field" | "quadruple rainbows" | "silkwater rain" | "acid storms";
        temperature: "freezing" | "cold" | "chilly" | "temperate" | "pretty much normal" | "room temp" | "a tad humid" | "temporal temps" | "unfathomably nice" | "perfect" | "no temperature" | "warm" | "hot" | "sweltering";
        effects: {
            system: string;
            effect: string;
        }[];
        isCold: boolean;
        isHot: boolean;
        isGhostly: boolean;
    }>, "many">;
}, "strip", z.ZodTypeAny, {
    current: {
        conditions: "blue lightning" | "starfall" | "full skies" | "no sky" | "moths... lots of moths" | "cloudfall" | "ducks" | "a full moon" | "ten full moons" | "sunshine from a star long since forgotten" | "dogs" | "cats" | "literally just rain" | "moonbeams" | "sunbeams" | "auroras" | "ghost showers" | "red lightning" | "purple lightning" | "a bloodmoon" | "twelve angry men" | "reverse showers" | "pumpkins" | "pomegranite seeds" | "more vibes than you'd expect" | "a heavy ghost field" | "a light ghost field" | "quadruple rainbows" | "silkwater rain" | "acid storms";
        temperature: "freezing" | "cold" | "chilly" | "temperate" | "pretty much normal" | "room temp" | "a tad humid" | "temporal temps" | "unfathomably nice" | "perfect" | "no temperature" | "warm" | "hot" | "sweltering";
        effects: {
            system: string;
            effect: string;
        }[];
        isCold: boolean;
        isHot: boolean;
        isGhostly: boolean;
    };
    forecast: {
        conditions: "blue lightning" | "starfall" | "full skies" | "no sky" | "moths... lots of moths" | "cloudfall" | "ducks" | "a full moon" | "ten full moons" | "sunshine from a star long since forgotten" | "dogs" | "cats" | "literally just rain" | "moonbeams" | "sunbeams" | "auroras" | "ghost showers" | "red lightning" | "purple lightning" | "a bloodmoon" | "twelve angry men" | "reverse showers" | "pumpkins" | "pomegranite seeds" | "more vibes than you'd expect" | "a heavy ghost field" | "a light ghost field" | "quadruple rainbows" | "silkwater rain" | "acid storms";
        temperature: "freezing" | "cold" | "chilly" | "temperate" | "pretty much normal" | "room temp" | "a tad humid" | "temporal temps" | "unfathomably nice" | "perfect" | "no temperature" | "warm" | "hot" | "sweltering";
        effects: {
            system: string;
            effect: string;
        }[];
        isCold: boolean;
        isHot: boolean;
        isGhostly: boolean;
    }[];
}, {
    current: {
        conditions: "blue lightning" | "starfall" | "full skies" | "no sky" | "moths... lots of moths" | "cloudfall" | "ducks" | "a full moon" | "ten full moons" | "sunshine from a star long since forgotten" | "dogs" | "cats" | "literally just rain" | "moonbeams" | "sunbeams" | "auroras" | "ghost showers" | "red lightning" | "purple lightning" | "a bloodmoon" | "twelve angry men" | "reverse showers" | "pumpkins" | "pomegranite seeds" | "more vibes than you'd expect" | "a heavy ghost field" | "a light ghost field" | "quadruple rainbows" | "silkwater rain" | "acid storms";
        temperature: "freezing" | "cold" | "chilly" | "temperate" | "pretty much normal" | "room temp" | "a tad humid" | "temporal temps" | "unfathomably nice" | "perfect" | "no temperature" | "warm" | "hot" | "sweltering";
        effects: {
            system: string;
            effect: string;
        }[];
        isCold: boolean;
        isHot: boolean;
        isGhostly: boolean;
    };
    forecast: {
        conditions: "blue lightning" | "starfall" | "full skies" | "no sky" | "moths... lots of moths" | "cloudfall" | "ducks" | "a full moon" | "ten full moons" | "sunshine from a star long since forgotten" | "dogs" | "cats" | "literally just rain" | "moonbeams" | "sunbeams" | "auroras" | "ghost showers" | "red lightning" | "purple lightning" | "a bloodmoon" | "twelve angry men" | "reverse showers" | "pumpkins" | "pomegranite seeds" | "more vibes than you'd expect" | "a heavy ghost field" | "a light ghost field" | "quadruple rainbows" | "silkwater rain" | "acid storms";
        temperature: "freezing" | "cold" | "chilly" | "temperate" | "pretty much normal" | "room temp" | "a tad humid" | "temporal temps" | "unfathomably nice" | "perfect" | "no temperature" | "warm" | "hot" | "sweltering";
        effects: {
            system: string;
            effect: string;
        }[];
        isCold: boolean;
        isHot: boolean;
        isGhostly: boolean;
    }[];
}>;
export type WorldWeather = z.infer<typeof WorldWeatherSchema>;
export declare const WorldTimeSchema: z.ZodObject<{
    ticksSinceEpoch: z.ZodNumber;
    daysSinceEpoch: z.ZodNumber;
}, "strip", z.ZodTypeAny, {
    ticksSinceEpoch: number;
    daysSinceEpoch: number;
}, {
    ticksSinceEpoch: number;
    daysSinceEpoch: number;
}>;
export type WorldTime = z.infer<typeof WorldTimeSchema>;
export declare const GameWorldSchema: z.ZodObject<{
    weather: z.ZodObject<{
        current: z.ZodObject<{
            conditions: z.ZodEnum<["blue lightning", "starfall", "full skies", "no sky", "moths... lots of moths", "cloudfall", "ducks", "a full moon", "ten full moons", "sunshine from a star long since forgotten", "dogs", "cats", "literally just rain", "moonbeams", "sunbeams", "auroras", "ghost showers", "red lightning", "purple lightning", "a bloodmoon", "twelve angry men", "reverse showers", "pumpkins", "pomegranite seeds", "more vibes than you'd expect", "a heavy ghost field", "a light ghost field", "quadruple rainbows", "silkwater rain", "acid storms"]>;
            temperature: z.ZodEnum<["freezing", "cold", "chilly", "temperate", "pretty much normal", "room temp", "a tad humid", "temporal temps", "unfathomably nice", "perfect", "no temperature", "warm", "hot", "sweltering"]>;
            effects: z.ZodArray<z.ZodObject<{
                system: z.ZodString;
                effect: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                system: string;
                effect: string;
            }, {
                system: string;
                effect: string;
            }>, "many">;
            isCold: z.ZodBoolean;
            isHot: z.ZodBoolean;
            isGhostly: z.ZodBoolean;
        }, "strip", z.ZodTypeAny, {
            conditions: "blue lightning" | "starfall" | "full skies" | "no sky" | "moths... lots of moths" | "cloudfall" | "ducks" | "a full moon" | "ten full moons" | "sunshine from a star long since forgotten" | "dogs" | "cats" | "literally just rain" | "moonbeams" | "sunbeams" | "auroras" | "ghost showers" | "red lightning" | "purple lightning" | "a bloodmoon" | "twelve angry men" | "reverse showers" | "pumpkins" | "pomegranite seeds" | "more vibes than you'd expect" | "a heavy ghost field" | "a light ghost field" | "quadruple rainbows" | "silkwater rain" | "acid storms";
            temperature: "freezing" | "cold" | "chilly" | "temperate" | "pretty much normal" | "room temp" | "a tad humid" | "temporal temps" | "unfathomably nice" | "perfect" | "no temperature" | "warm" | "hot" | "sweltering";
            effects: {
                system: string;
                effect: string;
            }[];
            isCold: boolean;
            isHot: boolean;
            isGhostly: boolean;
        }, {
            conditions: "blue lightning" | "starfall" | "full skies" | "no sky" | "moths... lots of moths" | "cloudfall" | "ducks" | "a full moon" | "ten full moons" | "sunshine from a star long since forgotten" | "dogs" | "cats" | "literally just rain" | "moonbeams" | "sunbeams" | "auroras" | "ghost showers" | "red lightning" | "purple lightning" | "a bloodmoon" | "twelve angry men" | "reverse showers" | "pumpkins" | "pomegranite seeds" | "more vibes than you'd expect" | "a heavy ghost field" | "a light ghost field" | "quadruple rainbows" | "silkwater rain" | "acid storms";
            temperature: "freezing" | "cold" | "chilly" | "temperate" | "pretty much normal" | "room temp" | "a tad humid" | "temporal temps" | "unfathomably nice" | "perfect" | "no temperature" | "warm" | "hot" | "sweltering";
            effects: {
                system: string;
                effect: string;
            }[];
            isCold: boolean;
            isHot: boolean;
            isGhostly: boolean;
        }>;
        forecast: z.ZodArray<z.ZodObject<{
            conditions: z.ZodEnum<["blue lightning", "starfall", "full skies", "no sky", "moths... lots of moths", "cloudfall", "ducks", "a full moon", "ten full moons", "sunshine from a star long since forgotten", "dogs", "cats", "literally just rain", "moonbeams", "sunbeams", "auroras", "ghost showers", "red lightning", "purple lightning", "a bloodmoon", "twelve angry men", "reverse showers", "pumpkins", "pomegranite seeds", "more vibes than you'd expect", "a heavy ghost field", "a light ghost field", "quadruple rainbows", "silkwater rain", "acid storms"]>;
            temperature: z.ZodEnum<["freezing", "cold", "chilly", "temperate", "pretty much normal", "room temp", "a tad humid", "temporal temps", "unfathomably nice", "perfect", "no temperature", "warm", "hot", "sweltering"]>;
            effects: z.ZodArray<z.ZodObject<{
                system: z.ZodString;
                effect: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                system: string;
                effect: string;
            }, {
                system: string;
                effect: string;
            }>, "many">;
            isCold: z.ZodBoolean;
            isHot: z.ZodBoolean;
            isGhostly: z.ZodBoolean;
        }, "strip", z.ZodTypeAny, {
            conditions: "blue lightning" | "starfall" | "full skies" | "no sky" | "moths... lots of moths" | "cloudfall" | "ducks" | "a full moon" | "ten full moons" | "sunshine from a star long since forgotten" | "dogs" | "cats" | "literally just rain" | "moonbeams" | "sunbeams" | "auroras" | "ghost showers" | "red lightning" | "purple lightning" | "a bloodmoon" | "twelve angry men" | "reverse showers" | "pumpkins" | "pomegranite seeds" | "more vibes than you'd expect" | "a heavy ghost field" | "a light ghost field" | "quadruple rainbows" | "silkwater rain" | "acid storms";
            temperature: "freezing" | "cold" | "chilly" | "temperate" | "pretty much normal" | "room temp" | "a tad humid" | "temporal temps" | "unfathomably nice" | "perfect" | "no temperature" | "warm" | "hot" | "sweltering";
            effects: {
                system: string;
                effect: string;
            }[];
            isCold: boolean;
            isHot: boolean;
            isGhostly: boolean;
        }, {
            conditions: "blue lightning" | "starfall" | "full skies" | "no sky" | "moths... lots of moths" | "cloudfall" | "ducks" | "a full moon" | "ten full moons" | "sunshine from a star long since forgotten" | "dogs" | "cats" | "literally just rain" | "moonbeams" | "sunbeams" | "auroras" | "ghost showers" | "red lightning" | "purple lightning" | "a bloodmoon" | "twelve angry men" | "reverse showers" | "pumpkins" | "pomegranite seeds" | "more vibes than you'd expect" | "a heavy ghost field" | "a light ghost field" | "quadruple rainbows" | "silkwater rain" | "acid storms";
            temperature: "freezing" | "cold" | "chilly" | "temperate" | "pretty much normal" | "room temp" | "a tad humid" | "temporal temps" | "unfathomably nice" | "perfect" | "no temperature" | "warm" | "hot" | "sweltering";
            effects: {
                system: string;
                effect: string;
            }[];
            isCold: boolean;
            isHot: boolean;
            isGhostly: boolean;
        }>, "many">;
    }, "strip", z.ZodTypeAny, {
        current: {
            conditions: "blue lightning" | "starfall" | "full skies" | "no sky" | "moths... lots of moths" | "cloudfall" | "ducks" | "a full moon" | "ten full moons" | "sunshine from a star long since forgotten" | "dogs" | "cats" | "literally just rain" | "moonbeams" | "sunbeams" | "auroras" | "ghost showers" | "red lightning" | "purple lightning" | "a bloodmoon" | "twelve angry men" | "reverse showers" | "pumpkins" | "pomegranite seeds" | "more vibes than you'd expect" | "a heavy ghost field" | "a light ghost field" | "quadruple rainbows" | "silkwater rain" | "acid storms";
            temperature: "freezing" | "cold" | "chilly" | "temperate" | "pretty much normal" | "room temp" | "a tad humid" | "temporal temps" | "unfathomably nice" | "perfect" | "no temperature" | "warm" | "hot" | "sweltering";
            effects: {
                system: string;
                effect: string;
            }[];
            isCold: boolean;
            isHot: boolean;
            isGhostly: boolean;
        };
        forecast: {
            conditions: "blue lightning" | "starfall" | "full skies" | "no sky" | "moths... lots of moths" | "cloudfall" | "ducks" | "a full moon" | "ten full moons" | "sunshine from a star long since forgotten" | "dogs" | "cats" | "literally just rain" | "moonbeams" | "sunbeams" | "auroras" | "ghost showers" | "red lightning" | "purple lightning" | "a bloodmoon" | "twelve angry men" | "reverse showers" | "pumpkins" | "pomegranite seeds" | "more vibes than you'd expect" | "a heavy ghost field" | "a light ghost field" | "quadruple rainbows" | "silkwater rain" | "acid storms";
            temperature: "freezing" | "cold" | "chilly" | "temperate" | "pretty much normal" | "room temp" | "a tad humid" | "temporal temps" | "unfathomably nice" | "perfect" | "no temperature" | "warm" | "hot" | "sweltering";
            effects: {
                system: string;
                effect: string;
            }[];
            isCold: boolean;
            isHot: boolean;
            isGhostly: boolean;
        }[];
    }, {
        current: {
            conditions: "blue lightning" | "starfall" | "full skies" | "no sky" | "moths... lots of moths" | "cloudfall" | "ducks" | "a full moon" | "ten full moons" | "sunshine from a star long since forgotten" | "dogs" | "cats" | "literally just rain" | "moonbeams" | "sunbeams" | "auroras" | "ghost showers" | "red lightning" | "purple lightning" | "a bloodmoon" | "twelve angry men" | "reverse showers" | "pumpkins" | "pomegranite seeds" | "more vibes than you'd expect" | "a heavy ghost field" | "a light ghost field" | "quadruple rainbows" | "silkwater rain" | "acid storms";
            temperature: "freezing" | "cold" | "chilly" | "temperate" | "pretty much normal" | "room temp" | "a tad humid" | "temporal temps" | "unfathomably nice" | "perfect" | "no temperature" | "warm" | "hot" | "sweltering";
            effects: {
                system: string;
                effect: string;
            }[];
            isCold: boolean;
            isHot: boolean;
            isGhostly: boolean;
        };
        forecast: {
            conditions: "blue lightning" | "starfall" | "full skies" | "no sky" | "moths... lots of moths" | "cloudfall" | "ducks" | "a full moon" | "ten full moons" | "sunshine from a star long since forgotten" | "dogs" | "cats" | "literally just rain" | "moonbeams" | "sunbeams" | "auroras" | "ghost showers" | "red lightning" | "purple lightning" | "a bloodmoon" | "twelve angry men" | "reverse showers" | "pumpkins" | "pomegranite seeds" | "more vibes than you'd expect" | "a heavy ghost field" | "a light ghost field" | "quadruple rainbows" | "silkwater rain" | "acid storms";
            temperature: "freezing" | "cold" | "chilly" | "temperate" | "pretty much normal" | "room temp" | "a tad humid" | "temporal temps" | "unfathomably nice" | "perfect" | "no temperature" | "warm" | "hot" | "sweltering";
            effects: {
                system: string;
                effect: string;
            }[];
            isCold: boolean;
            isHot: boolean;
            isGhostly: boolean;
        }[];
    }>;
    time: z.ZodObject<{
        ticksSinceEpoch: z.ZodNumber;
        daysSinceEpoch: z.ZodNumber;
    }, "strip", z.ZodTypeAny, {
        ticksSinceEpoch: number;
        daysSinceEpoch: number;
    }, {
        ticksSinceEpoch: number;
        daysSinceEpoch: number;
    }>;
}, "strip", z.ZodTypeAny, {
    weather: {
        current: {
            conditions: "blue lightning" | "starfall" | "full skies" | "no sky" | "moths... lots of moths" | "cloudfall" | "ducks" | "a full moon" | "ten full moons" | "sunshine from a star long since forgotten" | "dogs" | "cats" | "literally just rain" | "moonbeams" | "sunbeams" | "auroras" | "ghost showers" | "red lightning" | "purple lightning" | "a bloodmoon" | "twelve angry men" | "reverse showers" | "pumpkins" | "pomegranite seeds" | "more vibes than you'd expect" | "a heavy ghost field" | "a light ghost field" | "quadruple rainbows" | "silkwater rain" | "acid storms";
            temperature: "freezing" | "cold" | "chilly" | "temperate" | "pretty much normal" | "room temp" | "a tad humid" | "temporal temps" | "unfathomably nice" | "perfect" | "no temperature" | "warm" | "hot" | "sweltering";
            effects: {
                system: string;
                effect: string;
            }[];
            isCold: boolean;
            isHot: boolean;
            isGhostly: boolean;
        };
        forecast: {
            conditions: "blue lightning" | "starfall" | "full skies" | "no sky" | "moths... lots of moths" | "cloudfall" | "ducks" | "a full moon" | "ten full moons" | "sunshine from a star long since forgotten" | "dogs" | "cats" | "literally just rain" | "moonbeams" | "sunbeams" | "auroras" | "ghost showers" | "red lightning" | "purple lightning" | "a bloodmoon" | "twelve angry men" | "reverse showers" | "pumpkins" | "pomegranite seeds" | "more vibes than you'd expect" | "a heavy ghost field" | "a light ghost field" | "quadruple rainbows" | "silkwater rain" | "acid storms";
            temperature: "freezing" | "cold" | "chilly" | "temperate" | "pretty much normal" | "room temp" | "a tad humid" | "temporal temps" | "unfathomably nice" | "perfect" | "no temperature" | "warm" | "hot" | "sweltering";
            effects: {
                system: string;
                effect: string;
            }[];
            isCold: boolean;
            isHot: boolean;
            isGhostly: boolean;
        }[];
    };
    time: {
        ticksSinceEpoch: number;
        daysSinceEpoch: number;
    };
}, {
    weather: {
        current: {
            conditions: "blue lightning" | "starfall" | "full skies" | "no sky" | "moths... lots of moths" | "cloudfall" | "ducks" | "a full moon" | "ten full moons" | "sunshine from a star long since forgotten" | "dogs" | "cats" | "literally just rain" | "moonbeams" | "sunbeams" | "auroras" | "ghost showers" | "red lightning" | "purple lightning" | "a bloodmoon" | "twelve angry men" | "reverse showers" | "pumpkins" | "pomegranite seeds" | "more vibes than you'd expect" | "a heavy ghost field" | "a light ghost field" | "quadruple rainbows" | "silkwater rain" | "acid storms";
            temperature: "freezing" | "cold" | "chilly" | "temperate" | "pretty much normal" | "room temp" | "a tad humid" | "temporal temps" | "unfathomably nice" | "perfect" | "no temperature" | "warm" | "hot" | "sweltering";
            effects: {
                system: string;
                effect: string;
            }[];
            isCold: boolean;
            isHot: boolean;
            isGhostly: boolean;
        };
        forecast: {
            conditions: "blue lightning" | "starfall" | "full skies" | "no sky" | "moths... lots of moths" | "cloudfall" | "ducks" | "a full moon" | "ten full moons" | "sunshine from a star long since forgotten" | "dogs" | "cats" | "literally just rain" | "moonbeams" | "sunbeams" | "auroras" | "ghost showers" | "red lightning" | "purple lightning" | "a bloodmoon" | "twelve angry men" | "reverse showers" | "pumpkins" | "pomegranite seeds" | "more vibes than you'd expect" | "a heavy ghost field" | "a light ghost field" | "quadruple rainbows" | "silkwater rain" | "acid storms";
            temperature: "freezing" | "cold" | "chilly" | "temperate" | "pretty much normal" | "room temp" | "a tad humid" | "temporal temps" | "unfathomably nice" | "perfect" | "no temperature" | "warm" | "hot" | "sweltering";
            effects: {
                system: string;
                effect: string;
            }[];
            isCold: boolean;
            isHot: boolean;
            isGhostly: boolean;
        }[];
    };
    time: {
        ticksSinceEpoch: number;
        daysSinceEpoch: number;
    };
}>;
export type GameWorld = z.infer<typeof GameWorldSchema>;
