import { z } from "zod";
/*******************
 * WORLD CONSTANTS *
 *******************/
export const DAILY_RESET_UTC_HOUR = 8;
export const WORLD_TICKS_SINCE_EPOCH_FLAG = "world.ticksSinceEpoch";
export const WORLD_DAYS_SINCE_EPOCH_FLAG = "world.daysSinceEpoch";
export const WEATHER_OPTIONS = [
    // Cosmetic
    "blue lightning",
    "starfall",
    "full skies",
    "no sky",
    "moths... lots of moths",
    "cloudfall",
    "ducks",
    "a full moon",
    "ten full moons",
    "sunshine from a star long since forgotten",
    "dogs",
    "cats",
    "literally just rain",
    "moonbeams",
    "sunbeams",
    "auroras",
    "ghost showers",
    "red lightning",
    "purple lightning",
    "a bloodmoon",
    "twelve angry men",
    "reverse showers",
    "pumpkins",
    "pomegranite seeds",
    "more vibes than you'd expect",
    // Functional
    "a heavy ghost field",
    "a light ghost field",
    "quadruple rainbows",
    "silkwater rain",
    "acid storms",
];
export const TEMPERATURE_OPTIONS = [
    // Cold
    "freezing",
    "cold",
    "chilly",
    // Neutral
    "temperate",
    "pretty much normal",
    "room temp",
    "a tad humid",
    "temporal temps",
    "unfathomably nice",
    "perfect",
    "no temperature",
    // Hot
    "warm",
    "hot",
    "sweltering",
];
export const COLD_TEMPS = ["freezing", "cold", "chilly"];
export const HOT_TEMPS = ["warm", "hot", "sweltering"];
export const GHOST_WEATHERS = [
    "a heavy ghost field",
    "a light ghost field",
    "ghost showers",
];
export const WeatherEffectSchema = z.object({
    system: z.string(),
    effect: z.string(),
});
export const WeatherInfoShapeSchema = z.object({
    conditions: z.enum(WEATHER_OPTIONS),
    temperature: z.enum(TEMPERATURE_OPTIONS),
    effects: z.array(WeatherEffectSchema),
    isCold: z.boolean(),
    isHot: z.boolean(),
    isGhostly: z.boolean(),
});
export const WorldWeatherSchema = z.object({
    current: WeatherInfoShapeSchema,
    forecast: z.array(WeatherInfoShapeSchema),
});
export const WorldTimeSchema = z.object({
    ticksSinceEpoch: z.number(),
    daysSinceEpoch: z.number(),
});
export const GameWorldSchema = z.object({
    weather: WorldWeatherSchema,
    time: WorldTimeSchema,
});
