import { z } from "zod";
/*******************
 * MASTODON SHAPES *
 *******************/
/**
 * An identity object for a Mastodon account associated with a camper
 */
export declare const MastodonIdentitySchema: z.ZodObject<{
    mastodonIdentityId: z.ZodNumber;
    mastodonId: z.ZodString;
    camper: z.ZodNullable<z.ZodObject<{
        id: z.ZodNumber;
        name: z.ZodBranded<z.ZodString, "CamperDisplayName">;
        handle: z.ZodBranded<z.ZodString, "CamperHandle">;
        color: z.ZodNullable<z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">>;
        pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
        avatarUrl: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
    }, "strip", z.ZodTypeAny, {
        color: (string & z.BRAND<"ColorString">) | null;
        handle: string & z.BRAND<"CamperHandle">;
        pronouns: (string & z.BRAND<"PronounString">) | null;
        id: number;
        name: string & z.BRAND<"CamperDisplayName">;
        avatarUrl: (string & z.BRAND<"URLString">) | null;
    }, {
        color: string | null;
        handle: string;
        pronouns: string | null;
        id: number;
        name: string;
        avatarUrl: string | null;
    }>>;
    token: z.ZodNullable<z.ZodString>;
    handle: z.ZodString;
}, "strip", z.ZodTypeAny, {
    handle: string;
    camper: {
        color: (string & z.BRAND<"ColorString">) | null;
        handle: string & z.BRAND<"CamperHandle">;
        pronouns: (string & z.BRAND<"PronounString">) | null;
        id: number;
        name: string & z.BRAND<"CamperDisplayName">;
        avatarUrl: (string & z.BRAND<"URLString">) | null;
    } | null;
    mastodonIdentityId: number;
    mastodonId: string;
    token: string | null;
}, {
    handle: string;
    camper: {
        color: string | null;
        handle: string;
        pronouns: string | null;
        id: number;
        name: string;
        avatarUrl: string | null;
    } | null;
    mastodonIdentityId: number;
    mastodonId: string;
    token: string | null;
}>;
/**
 * An identity object for a Mastodon account associated with a camper
 */
export type MastodonIdentity = z.infer<typeof MastodonIdentitySchema>;
/**
 * An attachment object for a Mastodon status
 */
export declare const MastodonStatusAttachmentSchema: z.ZodObject<{
    type: z.ZodEnum<["image", "video", "gifv", "audio", "unknown"]>;
    url: z.ZodString;
    description: z.ZodNullable<z.ZodString>;
}, "strip", z.ZodTypeAny, {
    type: "unknown" | "image" | "video" | "gifv" | "audio";
    description: string | null;
    url: string;
}, {
    type: "unknown" | "image" | "video" | "gifv" | "audio";
    description: string | null;
    url: string;
}>;
/**
 * An attachment object for a Mastodon status
 */
export type MastodonStatusAttachment = z.infer<typeof MastodonStatusAttachmentSchema>;
/**
 * A Mastodon status as represented in the Relay
 */
export declare const MastodonStatusSchema: z.ZodObject<{
    id: z.ZodNumber;
    mastodonId: z.ZodString;
    createdAt: z.ZodString;
    authorIdentity: z.ZodObject<{
        mastodonIdentityId: z.ZodNumber;
        mastodonId: z.ZodString;
        camper: z.ZodNullable<z.ZodObject<{
            id: z.ZodNumber;
            name: z.ZodBranded<z.ZodString, "CamperDisplayName">;
            handle: z.ZodBranded<z.ZodString, "CamperHandle">;
            color: z.ZodNullable<z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">>;
            pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
            avatarUrl: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
        }, "strip", z.ZodTypeAny, {
            color: (string & z.BRAND<"ColorString">) | null;
            handle: string & z.BRAND<"CamperHandle">;
            pronouns: (string & z.BRAND<"PronounString">) | null;
            id: number;
            name: string & z.BRAND<"CamperDisplayName">;
            avatarUrl: (string & z.BRAND<"URLString">) | null;
        }, {
            color: string | null;
            handle: string;
            pronouns: string | null;
            id: number;
            name: string;
            avatarUrl: string | null;
        }>>;
        token: z.ZodNullable<z.ZodString>;
        handle: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        handle: string;
        camper: {
            color: (string & z.BRAND<"ColorString">) | null;
            handle: string & z.BRAND<"CamperHandle">;
            pronouns: (string & z.BRAND<"PronounString">) | null;
            id: number;
            name: string & z.BRAND<"CamperDisplayName">;
            avatarUrl: (string & z.BRAND<"URLString">) | null;
        } | null;
        mastodonIdentityId: number;
        mastodonId: string;
        token: string | null;
    }, {
        handle: string;
        camper: {
            color: string | null;
            handle: string;
            pronouns: string | null;
            id: number;
            name: string;
            avatarUrl: string | null;
        } | null;
        mastodonIdentityId: number;
        mastodonId: string;
        token: string | null;
    }>;
    inReplyToId: z.ZodNullable<z.ZodString>;
    inReplyToAccountId: z.ZodNullable<z.ZodString>;
    contentWarning: z.ZodNullable<z.ZodString>;
    visibility: z.ZodString;
    language: z.ZodNullable<z.ZodString>;
    url: z.ZodString;
    replyCount: z.ZodNumber;
    repostCount: z.ZodNumber;
    favoriteCount: z.ZodNumber;
    editedAt: z.ZodNullable<z.ZodString>;
    content: z.ZodString;
    repostedStatusId: z.ZodNullable<z.ZodString>;
    attachments: z.ZodArray<z.ZodObject<{
        type: z.ZodEnum<["image", "video", "gifv", "audio", "unknown"]>;
        url: z.ZodString;
        description: z.ZodNullable<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        type: "unknown" | "image" | "video" | "gifv" | "audio";
        description: string | null;
        url: string;
    }, {
        type: "unknown" | "image" | "video" | "gifv" | "audio";
        description: string | null;
        url: string;
    }>, "many">;
}, "strip", z.ZodTypeAny, {
    id: number;
    createdAt: string;
    content: string;
    mastodonId: string;
    url: string;
    authorIdentity: {
        handle: string;
        camper: {
            color: (string & z.BRAND<"ColorString">) | null;
            handle: string & z.BRAND<"CamperHandle">;
            pronouns: (string & z.BRAND<"PronounString">) | null;
            id: number;
            name: string & z.BRAND<"CamperDisplayName">;
            avatarUrl: (string & z.BRAND<"URLString">) | null;
        } | null;
        mastodonIdentityId: number;
        mastodonId: string;
        token: string | null;
    };
    inReplyToId: string | null;
    inReplyToAccountId: string | null;
    contentWarning: string | null;
    visibility: string;
    language: string | null;
    replyCount: number;
    repostCount: number;
    favoriteCount: number;
    editedAt: string | null;
    repostedStatusId: string | null;
    attachments: {
        type: "unknown" | "image" | "video" | "gifv" | "audio";
        description: string | null;
        url: string;
    }[];
}, {
    id: number;
    createdAt: string;
    content: string;
    mastodonId: string;
    url: string;
    authorIdentity: {
        handle: string;
        camper: {
            color: string | null;
            handle: string;
            pronouns: string | null;
            id: number;
            name: string;
            avatarUrl: string | null;
        } | null;
        mastodonIdentityId: number;
        mastodonId: string;
        token: string | null;
    };
    inReplyToId: string | null;
    inReplyToAccountId: string | null;
    contentWarning: string | null;
    visibility: string;
    language: string | null;
    replyCount: number;
    repostCount: number;
    favoriteCount: number;
    editedAt: string | null;
    repostedStatusId: string | null;
    attachments: {
        type: "unknown" | "image" | "video" | "gifv" | "audio";
        description: string | null;
        url: string;
    }[];
}>;
/**
 * A Mastodon status as represented in the Relay
 */
export type MastodonStatus = z.infer<typeof MastodonStatusSchema>;
/******************************
 * MASTODN API RESPONSE TYPES *
 ******************************/
/**
 * Represents the expected shape of a Mastodon API account object
 */
export declare const MastodonAPIAccountSchema: z.ZodObject<{
    id: z.ZodString;
    username: z.ZodString;
}, "strip", z.ZodTypeAny, {
    id: string;
    username: string;
}, {
    id: string;
    username: string;
}>;
/**
 * Represents the expected shape of a Mastodon API account object
 */
export type MastodonAPIAcount = z.infer<typeof MastodonAPIAccountSchema>;
/**
 * Represents the expected shape of a Mastodon tag in a status
 */
export declare const MastodonAPIStatusTagSchema: z.ZodObject<{
    name: z.ZodString;
    url: z.ZodString;
}, "strip", z.ZodTypeAny, {
    name: string;
    url: string;
}, {
    name: string;
    url: string;
}>;
/**
 * Represents the expected shape of a Mastodon media object in a status
 */
export declare const MastodonAPIStatusMediaSchema: z.ZodObject<{
    id: z.ZodString;
    type: z.ZodEnum<["image", "video", "gifv", "audio", "unknown"]>;
    url: z.ZodString;
    preview_url: z.ZodNullable<z.ZodString>;
    remote_url: z.ZodNullable<z.ZodString>;
    description: z.ZodNullable<z.ZodString>;
    blurhash: z.ZodNullable<z.ZodString>;
}, "strip", z.ZodTypeAny, {
    type: "unknown" | "image" | "video" | "gifv" | "audio";
    id: string;
    description: string | null;
    url: string;
    preview_url: string | null;
    remote_url: string | null;
    blurhash: string | null;
}, {
    type: "unknown" | "image" | "video" | "gifv" | "audio";
    id: string;
    description: string | null;
    url: string;
    preview_url: string | null;
    remote_url: string | null;
    blurhash: string | null;
}>;
/**
 * A Mastodon API status object.
 * Convert to an internal MastodonStatus upon receiving
 */
export declare const MastodonAPIStatusSchema: z.ZodObject<{
    account: z.ZodObject<{
        id: z.ZodString;
        username: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        id: string;
        username: string;
    }, {
        id: string;
        username: string;
    }>;
    id: z.ZodString;
    created_at: z.ZodString;
    in_reply_to_id: z.ZodNullable<z.ZodString>;
    in_reply_to_account_id: z.ZodNullable<z.ZodString>;
    sensitive: z.ZodBoolean;
    spoiler_text: z.ZodString;
    visibility: z.ZodString;
    language: z.ZodNullable<z.ZodString>;
    uri: z.ZodString;
    url: z.ZodString;
    replies_count: z.ZodNumber;
    reblogs_count: z.ZodNumber;
    favourites_count: z.ZodNumber;
    edited_at: z.ZodNullable<z.ZodString>;
    content: z.ZodString;
    tags: z.ZodArray<z.ZodObject<{
        name: z.ZodString;
        url: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        name: string;
        url: string;
    }, {
        name: string;
        url: string;
    }>, "many">;
    reblog: z.ZodNullable<z.ZodAny>;
    media_attachments: z.ZodArray<z.ZodObject<{
        id: z.ZodString;
        type: z.ZodEnum<["image", "video", "gifv", "audio", "unknown"]>;
        url: z.ZodString;
        preview_url: z.ZodNullable<z.ZodString>;
        remote_url: z.ZodNullable<z.ZodString>;
        description: z.ZodNullable<z.ZodString>;
        blurhash: z.ZodNullable<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        type: "unknown" | "image" | "video" | "gifv" | "audio";
        id: string;
        description: string | null;
        url: string;
        preview_url: string | null;
        remote_url: string | null;
        blurhash: string | null;
    }, {
        type: "unknown" | "image" | "video" | "gifv" | "audio";
        id: string;
        description: string | null;
        url: string;
        preview_url: string | null;
        remote_url: string | null;
        blurhash: string | null;
    }>, "many">;
}, "strip", z.ZodTypeAny, {
    id: string;
    content: string;
    url: string;
    visibility: string;
    language: string | null;
    account: {
        id: string;
        username: string;
    };
    created_at: string;
    in_reply_to_id: string | null;
    in_reply_to_account_id: string | null;
    sensitive: boolean;
    spoiler_text: string;
    uri: string;
    replies_count: number;
    reblogs_count: number;
    favourites_count: number;
    edited_at: string | null;
    tags: {
        name: string;
        url: string;
    }[];
    media_attachments: {
        type: "unknown" | "image" | "video" | "gifv" | "audio";
        id: string;
        description: string | null;
        url: string;
        preview_url: string | null;
        remote_url: string | null;
        blurhash: string | null;
    }[];
    reblog?: any;
}, {
    id: string;
    content: string;
    url: string;
    visibility: string;
    language: string | null;
    account: {
        id: string;
        username: string;
    };
    created_at: string;
    in_reply_to_id: string | null;
    in_reply_to_account_id: string | null;
    sensitive: boolean;
    spoiler_text: string;
    uri: string;
    replies_count: number;
    reblogs_count: number;
    favourites_count: number;
    edited_at: string | null;
    tags: {
        name: string;
        url: string;
    }[];
    media_attachments: {
        type: "unknown" | "image" | "video" | "gifv" | "audio";
        id: string;
        description: string | null;
        url: string;
        preview_url: string | null;
        remote_url: string | null;
        blurhash: string | null;
    }[];
    reblog?: any;
}>;
export declare const MastodonAPIStatusArraySchema: z.ZodArray<z.ZodObject<{
    account: z.ZodObject<{
        id: z.ZodString;
        username: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        id: string;
        username: string;
    }, {
        id: string;
        username: string;
    }>;
    id: z.ZodString;
    created_at: z.ZodString;
    in_reply_to_id: z.ZodNullable<z.ZodString>;
    in_reply_to_account_id: z.ZodNullable<z.ZodString>;
    sensitive: z.ZodBoolean;
    spoiler_text: z.ZodString;
    visibility: z.ZodString;
    language: z.ZodNullable<z.ZodString>;
    uri: z.ZodString;
    url: z.ZodString;
    replies_count: z.ZodNumber;
    reblogs_count: z.ZodNumber;
    favourites_count: z.ZodNumber;
    edited_at: z.ZodNullable<z.ZodString>;
    content: z.ZodString;
    tags: z.ZodArray<z.ZodObject<{
        name: z.ZodString;
        url: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        name: string;
        url: string;
    }, {
        name: string;
        url: string;
    }>, "many">;
    reblog: z.ZodNullable<z.ZodAny>;
    media_attachments: z.ZodArray<z.ZodObject<{
        id: z.ZodString;
        type: z.ZodEnum<["image", "video", "gifv", "audio", "unknown"]>;
        url: z.ZodString;
        preview_url: z.ZodNullable<z.ZodString>;
        remote_url: z.ZodNullable<z.ZodString>;
        description: z.ZodNullable<z.ZodString>;
        blurhash: z.ZodNullable<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        type: "unknown" | "image" | "video" | "gifv" | "audio";
        id: string;
        description: string | null;
        url: string;
        preview_url: string | null;
        remote_url: string | null;
        blurhash: string | null;
    }, {
        type: "unknown" | "image" | "video" | "gifv" | "audio";
        id: string;
        description: string | null;
        url: string;
        preview_url: string | null;
        remote_url: string | null;
        blurhash: string | null;
    }>, "many">;
}, "strip", z.ZodTypeAny, {
    id: string;
    content: string;
    url: string;
    visibility: string;
    language: string | null;
    account: {
        id: string;
        username: string;
    };
    created_at: string;
    in_reply_to_id: string | null;
    in_reply_to_account_id: string | null;
    sensitive: boolean;
    spoiler_text: string;
    uri: string;
    replies_count: number;
    reblogs_count: number;
    favourites_count: number;
    edited_at: string | null;
    tags: {
        name: string;
        url: string;
    }[];
    media_attachments: {
        type: "unknown" | "image" | "video" | "gifv" | "audio";
        id: string;
        description: string | null;
        url: string;
        preview_url: string | null;
        remote_url: string | null;
        blurhash: string | null;
    }[];
    reblog?: any;
}, {
    id: string;
    content: string;
    url: string;
    visibility: string;
    language: string | null;
    account: {
        id: string;
        username: string;
    };
    created_at: string;
    in_reply_to_id: string | null;
    in_reply_to_account_id: string | null;
    sensitive: boolean;
    spoiler_text: string;
    uri: string;
    replies_count: number;
    reblogs_count: number;
    favourites_count: number;
    edited_at: string | null;
    tags: {
        name: string;
        url: string;
    }[];
    media_attachments: {
        type: "unknown" | "image" | "video" | "gifv" | "audio";
        id: string;
        description: string | null;
        url: string;
        preview_url: string | null;
        remote_url: string | null;
        blurhash: string | null;
    }[];
    reblog?: any;
}>, "many">;
export type MastodonAPIStatus = z.infer<typeof MastodonAPIStatusSchema>;
/*******************
 * MASTODON EVENTS *
 *******************/
export declare const MastodonRelayEvents: {
    readonly "mastodon:status": z.ZodObject<{
        id: z.ZodNumber;
        mastodonId: z.ZodString;
        createdAt: z.ZodString;
        authorIdentity: z.ZodObject<{
            mastodonIdentityId: z.ZodNumber;
            mastodonId: z.ZodString;
            camper: z.ZodNullable<z.ZodObject<{
                id: z.ZodNumber;
                name: z.ZodBranded<z.ZodString, "CamperDisplayName">;
                handle: z.ZodBranded<z.ZodString, "CamperHandle">;
                color: z.ZodNullable<z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">>;
                pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
                avatarUrl: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
            }, "strip", z.ZodTypeAny, {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            }, {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            }>>;
            token: z.ZodNullable<z.ZodString>;
            handle: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            handle: string;
            camper: {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            } | null;
            mastodonIdentityId: number;
            mastodonId: string;
            token: string | null;
        }, {
            handle: string;
            camper: {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            } | null;
            mastodonIdentityId: number;
            mastodonId: string;
            token: string | null;
        }>;
        inReplyToId: z.ZodNullable<z.ZodString>;
        inReplyToAccountId: z.ZodNullable<z.ZodString>;
        contentWarning: z.ZodNullable<z.ZodString>;
        visibility: z.ZodString;
        language: z.ZodNullable<z.ZodString>;
        url: z.ZodString;
        replyCount: z.ZodNumber;
        repostCount: z.ZodNumber;
        favoriteCount: z.ZodNumber;
        editedAt: z.ZodNullable<z.ZodString>;
        content: z.ZodString;
        repostedStatusId: z.ZodNullable<z.ZodString>;
        attachments: z.ZodArray<z.ZodObject<{
            type: z.ZodEnum<["image", "video", "gifv", "audio", "unknown"]>;
            url: z.ZodString;
            description: z.ZodNullable<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            type: "unknown" | "image" | "video" | "gifv" | "audio";
            description: string | null;
            url: string;
        }, {
            type: "unknown" | "image" | "video" | "gifv" | "audio";
            description: string | null;
            url: string;
        }>, "many">;
    }, "strip", z.ZodTypeAny, {
        id: number;
        createdAt: string;
        content: string;
        mastodonId: string;
        url: string;
        authorIdentity: {
            handle: string;
            camper: {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            } | null;
            mastodonIdentityId: number;
            mastodonId: string;
            token: string | null;
        };
        inReplyToId: string | null;
        inReplyToAccountId: string | null;
        contentWarning: string | null;
        visibility: string;
        language: string | null;
        replyCount: number;
        repostCount: number;
        favoriteCount: number;
        editedAt: string | null;
        repostedStatusId: string | null;
        attachments: {
            type: "unknown" | "image" | "video" | "gifv" | "audio";
            description: string | null;
            url: string;
        }[];
    }, {
        id: number;
        createdAt: string;
        content: string;
        mastodonId: string;
        url: string;
        authorIdentity: {
            handle: string;
            camper: {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            } | null;
            mastodonIdentityId: number;
            mastodonId: string;
            token: string | null;
        };
        inReplyToId: string | null;
        inReplyToAccountId: string | null;
        contentWarning: string | null;
        visibility: string;
        language: string | null;
        replyCount: number;
        repostCount: number;
        favoriteCount: number;
        editedAt: string | null;
        repostedStatusId: string | null;
        attachments: {
            type: "unknown" | "image" | "video" | "gifv" | "audio";
            description: string | null;
            url: string;
        }[];
    }>;
};
export type MastodonEventIdentifier = keyof typeof MastodonRelayEvents;
/********************
 * MASTODON ACTIONS *
 ********************/
export declare const MastodonRelayActions: {
    readonly "mastodon@attach-identity": {
        readonly input: z.ZodObject<{
            token: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            token: string;
        }, {
            token: string;
        }>;
        readonly output: z.ZodString;
    };
    readonly "mastodon@detach-identity": {
        readonly input: z.ZodVoid;
        readonly output: z.ZodBoolean;
    };
    readonly "mastodon@status": {
        readonly input: z.ZodObject<{
            status: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            status: string;
        }, {
            status: string;
        }>;
        readonly output: z.ZodString;
    };
};
