import { z } from "zod";
export declare const NoteVisibilitySchema: z.ZodEnum<["public", "private"]>;
export type NoteVisibility = z.infer<typeof NoteVisibilitySchema>;
export declare const NoteCategorySchema: z.ZodEnum<["game", "game:botany", "game:chemistry", "game:economy", "game:badge", "game:item", "game:portent", "social", "social:mastodon", "social:prose", "social:twitch", "social:discord", "camp", "camp:mail", "camp:vibe-check", "camp:shortlink", "camp:camper"]>;
export type NoteCategory = z.infer<typeof NoteCategorySchema>;
/**
 * A note associated with a camper
 */
export declare const NoteSchema: z.ZodObject<{
    noteId: z.ZodNumber;
    camper: z.ZodObject<{
        id: z.ZodNumber;
        name: z.ZodBranded<z.ZodString, "CamperDisplayName">;
        handle: z.ZodBranded<z.ZodString, "CamperHandle">;
        color: z.ZodNullable<z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">>;
        pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
        avatarUrl: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
    }, "strip", z.ZodTypeAny, {
        color: (string & z.BRAND<"ColorString">) | null;
        handle: string & z.BRAND<"CamperHandle">;
        pronouns: (string & z.BRAND<"PronounString">) | null;
        id: number;
        name: string & z.BRAND<"CamperDisplayName">;
        avatarUrl: (string & z.BRAND<"URLString">) | null;
    }, {
        color: string | null;
        handle: string;
        pronouns: string | null;
        id: number;
        name: string;
        avatarUrl: string | null;
    }>;
    content: z.ZodString;
    category: z.ZodEnum<["game", "game:botany", "game:chemistry", "game:economy", "game:badge", "game:item", "game:portent", "social", "social:mastodon", "social:prose", "social:twitch", "social:discord", "camp", "camp:mail", "camp:vibe-check", "camp:shortlink", "camp:camper"]>;
    visibility: z.ZodEnum<["public", "private"]>;
    createdAt: z.ZodString;
}, "strip", z.ZodTypeAny, {
    createdAt: string;
    camper: {
        color: (string & z.BRAND<"ColorString">) | null;
        handle: string & z.BRAND<"CamperHandle">;
        pronouns: (string & z.BRAND<"PronounString">) | null;
        id: number;
        name: string & z.BRAND<"CamperDisplayName">;
        avatarUrl: (string & z.BRAND<"URLString">) | null;
    };
    content: string;
    category: "game" | "game:botany" | "game:chemistry" | "game:economy" | "game:badge" | "game:item" | "game:portent" | "social" | "social:mastodon" | "social:prose" | "social:twitch" | "social:discord" | "camp" | "camp:mail" | "camp:vibe-check" | "camp:shortlink" | "camp:camper";
    visibility: "public" | "private";
    noteId: number;
}, {
    createdAt: string;
    camper: {
        color: string | null;
        handle: string;
        pronouns: string | null;
        id: number;
        name: string;
        avatarUrl: string | null;
    };
    content: string;
    category: "game" | "game:botany" | "game:chemistry" | "game:economy" | "game:badge" | "game:item" | "game:portent" | "social" | "social:mastodon" | "social:prose" | "social:twitch" | "social:discord" | "camp" | "camp:mail" | "camp:vibe-check" | "camp:shortlink" | "camp:camper";
    visibility: "public" | "private";
    noteId: number;
}>;
/**
 * A note associated with a camper
 */
export type Note = z.infer<typeof NoteSchema>;
