import { z } from "zod";
import { GameRelayActions } from "./game";
import { MailRelayActions } from "./mail";
import { MastodonRelayActions } from "./mastodon";
import { ShortlinkRelayActions } from "./shortlink";
import { TwitchRelayActions } from "./twitch";
import { VibeCheckRelayActions } from "./vibe-check";
export const RelayActions = {
    ...GameRelayActions,
    ...MailRelayActions,
    ...MastodonRelayActions,
    ...ShortlinkRelayActions,
    ...TwitchRelayActions,
    ...VibeCheckRelayActions,
};
export const SuccessfulActionResultSchema = z.object({
    success: z.literal(true),
    payload: z.unknown(),
});
export const FailedActionResultSchema = z.object({
    success: z.literal(false),
    errorId: z.string(),
});
export const RelayActionResultSchema = z.union([
    SuccessfulActionResultSchema,
    FailedActionResultSchema,
]);
export var ActionErrorClass;
(function (ActionErrorClass) {
    // User errors such as validation or logic errors
    ActionErrorClass["USER"] = "USER";
    // System errors such as crashes or network errors
    ActionErrorClass["SYSTEM"] = "SYSTEM";
})(ActionErrorClass || (ActionErrorClass = {}));
export var ActionErrorCode;
(function (ActionErrorCode) {
    ActionErrorCode["GENERIC"] = "ERR_GENERIC";
    ActionErrorCode["INVALID"] = "ERR_INVALID";
    ActionErrorCode["UNAUTHORIZED"] = "ERR_UNAUTHORIZED";
    ActionErrorCode["NOT_FOUND"] = "ERR_NOT_FOUND";
    ActionErrorCode["UNEXPECTED"] = "ERR_UNEXPECTED";
})(ActionErrorCode || (ActionErrorCode = {}));
