import { z } from "zod";
/**
 * Shortlinks may only contain alphanumeric characters, hyphens, and underscores,
 * must start with an alphanumeric character, and must be between 2 and 30 characters long.
 */
export declare const SHORTLINK_ALIAS_REGEX: RegExp;
/**
 * A shortlink that redirects to a URL
 */
export declare const ShortlinkSchema: z.ZodObject<{
    camper: z.ZodObject<{
        id: z.ZodNumber;
        name: z.ZodBranded<z.ZodString, "CamperDisplayName">;
        handle: z.ZodBranded<z.ZodString, "CamperHandle">;
        color: z.ZodNullable<z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">>;
        pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
        avatarUrl: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
    }, "strip", z.ZodTypeAny, {
        color: (string & z.BRAND<"ColorString">) | null;
        handle: string & z.BRAND<"CamperHandle">;
        pronouns: (string & z.BRAND<"PronounString">) | null;
        id: number;
        name: string & z.BRAND<"CamperDisplayName">;
        avatarUrl: (string & z.BRAND<"URLString">) | null;
    }, {
        color: string | null;
        handle: string;
        pronouns: string | null;
        id: number;
        name: string;
        avatarUrl: string | null;
    }>;
    href: z.ZodString;
    alias: z.ZodString;
}, "strip", z.ZodTypeAny, {
    camper: {
        color: (string & z.BRAND<"ColorString">) | null;
        handle: string & z.BRAND<"CamperHandle">;
        pronouns: (string & z.BRAND<"PronounString">) | null;
        id: number;
        name: string & z.BRAND<"CamperDisplayName">;
        avatarUrl: (string & z.BRAND<"URLString">) | null;
    };
    href: string;
    alias: string;
}, {
    camper: {
        color: string | null;
        handle: string;
        pronouns: string | null;
        id: number;
        name: string;
        avatarUrl: string | null;
    };
    href: string;
    alias: string;
}>;
/**
 * A shortlink that redirects to a URL
 */
export type Shortlink = z.infer<typeof ShortlinkSchema>;
/***********
 * ACTIONS *
 ***********/
export declare const ShortlinkRelayActions: {
    readonly "shortlinks@create": {
        readonly input: z.ZodObject<{
            href: z.ZodString;
            alias: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            href: string;
            alias: string;
        }, {
            href: string;
            alias: string;
        }>;
        readonly output: z.ZodObject<{
            camper: z.ZodObject<{
                id: z.ZodNumber;
                name: z.ZodBranded<z.ZodString, "CamperDisplayName">;
                handle: z.ZodBranded<z.ZodString, "CamperHandle">;
                color: z.ZodNullable<z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">>;
                pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
                avatarUrl: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
            }, "strip", z.ZodTypeAny, {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            }, {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            }>;
            href: z.ZodString;
            alias: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            camper: {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            };
            href: string;
            alias: string;
        }, {
            camper: {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            };
            href: string;
            alias: string;
        }>;
    };
    readonly "shortlinks@delete": {
        readonly input: z.ZodObject<{
            alias: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            alias: string;
        }, {
            alias: string;
        }>;
        readonly output: z.ZodBoolean;
    };
};
