import { z } from "zod";
import { CamperChipSchema } from "./core";
/**
 * Shortlinks may only contain alphanumeric characters, hyphens, and underscores,
 * must start with an alphanumeric character, and must be between 2 and 30 characters long.
 */
export const SHORTLINK_ALIAS_REGEX = /^[a-zA-Z0-9]+[a-zA-Z0-9-_]{1,29}$/;
/**
 * A shortlink that redirects to a URL
 */
export const ShortlinkSchema = z.object({
    camper: CamperChipSchema,
    href: z.string(),
    alias: z.string(),
});
/***********
 * ACTIONS *
 ***********/
export const ShortlinkRelayActions = {
    "shortlinks@create": {
        input: z.object({
            href: z.string().url(),
            alias: z.string(),
        }),
        output: ShortlinkSchema,
    },
    "shortlinks@delete": {
        input: z.object({
            alias: z.string(),
        }),
        output: z.boolean(),
    },
};
