import { z } from "zod";
/********************
 * TWITCH CONSTANTS *
 ********************/
/**
 * Flairs that can be applied to a chat message
 */
export declare const TWITCH_CHAT_FLAIRS: readonly ["broadcaster", "vip", "mod", "highlighted", "subscriber", "camper", "bot", "firstThisSession", "firstEver"];
/**
 * Scopes required for the Twitch API
 */
export declare const TWITCH_AUTH_SCOPE: string;
export declare const TWITCH_AUTH_SCOPE_BASIC: string;
/*****************
 * TWITCH SHAPES *
 *****************/
export declare const TwitchSubscriptionTierSchema: z.ZodUnion<[z.ZodLiteral<"1000">, z.ZodLiteral<"2000">, z.ZodLiteral<"3000">]>;
export type TwitchSubscriptionTier = z.infer<typeof TwitchSubscriptionTierSchema>;
/**
 * #SHAPE# TwitchIdentity
 *
 * An identity object for a Twitch account associated with a camper
 */
export declare const TwitchIdentitySchema: z.ZodReadonly<z.ZodObject<{
    twitchIdentityId: z.ZodNumber;
    twitchId: z.ZodString;
    camper: z.ZodNullable<z.ZodObject<{
        id: z.ZodNumber;
        name: z.ZodBranded<z.ZodString, "CamperDisplayName">;
        handle: z.ZodBranded<z.ZodString, "CamperHandle">;
        color: z.ZodNullable<z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">>;
        pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
        avatarUrl: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
    }, "strip", z.ZodTypeAny, {
        color: (string & z.BRAND<"ColorString">) | null;
        handle: string & z.BRAND<"CamperHandle">;
        pronouns: (string & z.BRAND<"PronounString">) | null;
        id: number;
        name: string & z.BRAND<"CamperDisplayName">;
        avatarUrl: (string & z.BRAND<"URLString">) | null;
    }, {
        color: string | null;
        handle: string;
        pronouns: string | null;
        id: number;
        name: string;
        avatarUrl: string | null;
    }>>;
    twitchHandle: z.ZodString;
    twitchDisplayName: z.ZodString;
    twitchNameColor: z.ZodString;
    twitchChannelURL: z.ZodString;
    info: z.ZodObject<{
        name: z.ZodString;
        color: z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">;
        pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
        avatarURL: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
    }, "strip", z.ZodTypeAny, {
        color: string & z.BRAND<"ColorString">;
        pronouns: (string & z.BRAND<"PronounString">) | null;
        name: string;
        avatarURL: (string & z.BRAND<"URLString">) | null;
    }, {
        color: string;
        pronouns: string | null;
        name: string;
        avatarURL: string | null;
    }>;
}, "strip", z.ZodTypeAny, {
    camper: {
        color: (string & z.BRAND<"ColorString">) | null;
        handle: string & z.BRAND<"CamperHandle">;
        pronouns: (string & z.BRAND<"PronounString">) | null;
        id: number;
        name: string & z.BRAND<"CamperDisplayName">;
        avatarUrl: (string & z.BRAND<"URLString">) | null;
    } | null;
    twitchIdentityId: number;
    twitchId: string;
    twitchHandle: string;
    twitchDisplayName: string;
    twitchNameColor: string;
    twitchChannelURL: string;
    info: {
        color: string & z.BRAND<"ColorString">;
        pronouns: (string & z.BRAND<"PronounString">) | null;
        name: string;
        avatarURL: (string & z.BRAND<"URLString">) | null;
    };
}, {
    camper: {
        color: string | null;
        handle: string;
        pronouns: string | null;
        id: number;
        name: string;
        avatarUrl: string | null;
    } | null;
    twitchIdentityId: number;
    twitchId: string;
    twitchHandle: string;
    twitchDisplayName: string;
    twitchNameColor: string;
    twitchChannelURL: string;
    info: {
        color: string;
        pronouns: string | null;
        name: string;
        avatarURL: string | null;
    };
}>>;
/**
 * An identity object for a Twitch account associated with a camper
 */
export type TwitchIdentity = z.infer<typeof TwitchIdentitySchema>;
export declare const TwitchChatFlairSchema: z.ZodEnum<["broadcaster", "vip", "mod", "highlighted", "subscriber", "camper", "bot", "firstThisSession", "firstEver"]>;
export declare const TwitchCharFlairArraySchema: z.ZodArray<z.ZodEnum<["broadcaster", "vip", "mod", "highlighted", "subscriber", "camper", "bot", "firstThisSession", "firstEver"]>, "many">;
/**
 * Flairs that can be applied to a chat message
 */
export type TwitchChatFlair = z.infer<typeof TwitchChatFlairSchema>;
/**
 * A chat message in a Twitch channel as represented in the Relay
 */
export declare const TwitchChatSchema: z.ZodReadonly<z.ZodObject<{
    chatRecordId: z.ZodNumber;
    twitchMessageId: z.ZodString;
    twitchParentMessageId: z.ZodNullable<z.ZodString>;
    authorName: z.ZodString;
    content: z.ZodString;
    richContent: z.ZodNullable<z.ZodString>;
    flair: z.ZodArray<z.ZodEnum<["broadcaster", "vip", "mod", "highlighted", "subscriber", "camper", "bot", "firstThisSession", "firstEver"]>, "many">;
    identity: z.ZodReadonly<z.ZodObject<{
        twitchIdentityId: z.ZodNumber;
        twitchId: z.ZodString;
        camper: z.ZodNullable<z.ZodObject<{
            id: z.ZodNumber;
            name: z.ZodBranded<z.ZodString, "CamperDisplayName">;
            handle: z.ZodBranded<z.ZodString, "CamperHandle">;
            color: z.ZodNullable<z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">>;
            pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
            avatarUrl: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
        }, "strip", z.ZodTypeAny, {
            color: (string & z.BRAND<"ColorString">) | null;
            handle: string & z.BRAND<"CamperHandle">;
            pronouns: (string & z.BRAND<"PronounString">) | null;
            id: number;
            name: string & z.BRAND<"CamperDisplayName">;
            avatarUrl: (string & z.BRAND<"URLString">) | null;
        }, {
            color: string | null;
            handle: string;
            pronouns: string | null;
            id: number;
            name: string;
            avatarUrl: string | null;
        }>>;
        twitchHandle: z.ZodString;
        twitchDisplayName: z.ZodString;
        twitchNameColor: z.ZodString;
        twitchChannelURL: z.ZodString;
        info: z.ZodObject<{
            name: z.ZodString;
            color: z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">;
            pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
            avatarURL: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
        }, "strip", z.ZodTypeAny, {
            color: string & z.BRAND<"ColorString">;
            pronouns: (string & z.BRAND<"PronounString">) | null;
            name: string;
            avatarURL: (string & z.BRAND<"URLString">) | null;
        }, {
            color: string;
            pronouns: string | null;
            name: string;
            avatarURL: string | null;
        }>;
    }, "strip", z.ZodTypeAny, {
        camper: {
            color: (string & z.BRAND<"ColorString">) | null;
            handle: string & z.BRAND<"CamperHandle">;
            pronouns: (string & z.BRAND<"PronounString">) | null;
            id: number;
            name: string & z.BRAND<"CamperDisplayName">;
            avatarUrl: (string & z.BRAND<"URLString">) | null;
        } | null;
        twitchIdentityId: number;
        twitchId: string;
        twitchHandle: string;
        twitchDisplayName: string;
        twitchNameColor: string;
        twitchChannelURL: string;
        info: {
            color: string & z.BRAND<"ColorString">;
            pronouns: (string & z.BRAND<"PronounString">) | null;
            name: string;
            avatarURL: (string & z.BRAND<"URLString">) | null;
        };
    }, {
        camper: {
            color: string | null;
            handle: string;
            pronouns: string | null;
            id: number;
            name: string;
            avatarUrl: string | null;
        } | null;
        twitchIdentityId: number;
        twitchId: string;
        twitchHandle: string;
        twitchDisplayName: string;
        twitchNameColor: string;
        twitchChannelURL: string;
        info: {
            color: string;
            pronouns: string | null;
            name: string;
            avatarURL: string | null;
        };
    }>>;
    camper: z.ZodNullable<z.ZodObject<{
        id: z.ZodNumber;
        name: z.ZodBranded<z.ZodString, "CamperDisplayName">;
        handle: z.ZodBranded<z.ZodString, "CamperHandle">;
        color: z.ZodNullable<z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">>;
        pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
        avatarUrl: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
    }, "strip", z.ZodTypeAny, {
        color: (string & z.BRAND<"ColorString">) | null;
        handle: string & z.BRAND<"CamperHandle">;
        pronouns: (string & z.BRAND<"PronounString">) | null;
        id: number;
        name: string & z.BRAND<"CamperDisplayName">;
        avatarUrl: (string & z.BRAND<"URLString">) | null;
    }, {
        color: string | null;
        handle: string;
        pronouns: string | null;
        id: number;
        name: string;
        avatarUrl: string | null;
    }>>;
}, "strip", z.ZodTypeAny, {
    camper: {
        color: (string & z.BRAND<"ColorString">) | null;
        handle: string & z.BRAND<"CamperHandle">;
        pronouns: (string & z.BRAND<"PronounString">) | null;
        id: number;
        name: string & z.BRAND<"CamperDisplayName">;
        avatarUrl: (string & z.BRAND<"URLString">) | null;
    } | null;
    content: string;
    chatRecordId: number;
    twitchMessageId: string;
    twitchParentMessageId: string | null;
    authorName: string;
    richContent: string | null;
    flair: ("camper" | "broadcaster" | "vip" | "mod" | "highlighted" | "subscriber" | "bot" | "firstThisSession" | "firstEver")[];
    identity: Readonly<{
        camper: {
            color: (string & z.BRAND<"ColorString">) | null;
            handle: string & z.BRAND<"CamperHandle">;
            pronouns: (string & z.BRAND<"PronounString">) | null;
            id: number;
            name: string & z.BRAND<"CamperDisplayName">;
            avatarUrl: (string & z.BRAND<"URLString">) | null;
        } | null;
        twitchIdentityId: number;
        twitchId: string;
        twitchHandle: string;
        twitchDisplayName: string;
        twitchNameColor: string;
        twitchChannelURL: string;
        info: {
            color: string & z.BRAND<"ColorString">;
            pronouns: (string & z.BRAND<"PronounString">) | null;
            name: string;
            avatarURL: (string & z.BRAND<"URLString">) | null;
        };
    }>;
}, {
    camper: {
        color: string | null;
        handle: string;
        pronouns: string | null;
        id: number;
        name: string;
        avatarUrl: string | null;
    } | null;
    content: string;
    chatRecordId: number;
    twitchMessageId: string;
    twitchParentMessageId: string | null;
    authorName: string;
    richContent: string | null;
    flair: ("camper" | "broadcaster" | "vip" | "mod" | "highlighted" | "subscriber" | "bot" | "firstThisSession" | "firstEver")[];
    identity: Readonly<{
        camper: {
            color: string | null;
            handle: string;
            pronouns: string | null;
            id: number;
            name: string;
            avatarUrl: string | null;
        } | null;
        twitchIdentityId: number;
        twitchId: string;
        twitchHandle: string;
        twitchDisplayName: string;
        twitchNameColor: string;
        twitchChannelURL: string;
        info: {
            color: string;
            pronouns: string | null;
            name: string;
            avatarURL: string | null;
        };
    }>;
}>>;
/**
 * A chat message in a Twitch channel as represented in the Relay
 */
export type TwitchChat = z.infer<typeof TwitchChatSchema>;
/****************
 * TWITCH VIEWS *
 ****************/
export declare const TwitchRelayViews: {
    readonly "twitch/chat/history": {
        readonly params: z.ZodObject<{}, "strip", z.ZodTypeAny, {}, {}>;
        readonly response: z.ZodArray<z.ZodReadonly<z.ZodObject<{
            chatRecordId: z.ZodNumber;
            twitchMessageId: z.ZodString;
            twitchParentMessageId: z.ZodNullable<z.ZodString>;
            authorName: z.ZodString;
            content: z.ZodString;
            richContent: z.ZodNullable<z.ZodString>;
            flair: z.ZodArray<z.ZodEnum<["broadcaster", "vip", "mod", "highlighted", "subscriber", "camper", "bot", "firstThisSession", "firstEver"]>, "many">;
            identity: z.ZodReadonly<z.ZodObject<{
                twitchIdentityId: z.ZodNumber;
                twitchId: z.ZodString;
                camper: z.ZodNullable<z.ZodObject<{
                    id: z.ZodNumber;
                    name: z.ZodBranded<z.ZodString, "CamperDisplayName">;
                    handle: z.ZodBranded<z.ZodString, "CamperHandle">;
                    color: z.ZodNullable<z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">>;
                    pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
                    avatarUrl: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
                }, "strip", z.ZodTypeAny, {
                    color: (string & z.BRAND<"ColorString">) | null;
                    handle: string & z.BRAND<"CamperHandle">;
                    pronouns: (string & z.BRAND<"PronounString">) | null;
                    id: number;
                    name: string & z.BRAND<"CamperDisplayName">;
                    avatarUrl: (string & z.BRAND<"URLString">) | null;
                }, {
                    color: string | null;
                    handle: string;
                    pronouns: string | null;
                    id: number;
                    name: string;
                    avatarUrl: string | null;
                }>>;
                twitchHandle: z.ZodString;
                twitchDisplayName: z.ZodString;
                twitchNameColor: z.ZodString;
                twitchChannelURL: z.ZodString;
                info: z.ZodObject<{
                    name: z.ZodString;
                    color: z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">;
                    pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
                    avatarURL: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
                }, "strip", z.ZodTypeAny, {
                    color: string & z.BRAND<"ColorString">;
                    pronouns: (string & z.BRAND<"PronounString">) | null;
                    name: string;
                    avatarURL: (string & z.BRAND<"URLString">) | null;
                }, {
                    color: string;
                    pronouns: string | null;
                    name: string;
                    avatarURL: string | null;
                }>;
            }, "strip", z.ZodTypeAny, {
                camper: {
                    color: (string & z.BRAND<"ColorString">) | null;
                    handle: string & z.BRAND<"CamperHandle">;
                    pronouns: (string & z.BRAND<"PronounString">) | null;
                    id: number;
                    name: string & z.BRAND<"CamperDisplayName">;
                    avatarUrl: (string & z.BRAND<"URLString">) | null;
                } | null;
                twitchIdentityId: number;
                twitchId: string;
                twitchHandle: string;
                twitchDisplayName: string;
                twitchNameColor: string;
                twitchChannelURL: string;
                info: {
                    color: string & z.BRAND<"ColorString">;
                    pronouns: (string & z.BRAND<"PronounString">) | null;
                    name: string;
                    avatarURL: (string & z.BRAND<"URLString">) | null;
                };
            }, {
                camper: {
                    color: string | null;
                    handle: string;
                    pronouns: string | null;
                    id: number;
                    name: string;
                    avatarUrl: string | null;
                } | null;
                twitchIdentityId: number;
                twitchId: string;
                twitchHandle: string;
                twitchDisplayName: string;
                twitchNameColor: string;
                twitchChannelURL: string;
                info: {
                    color: string;
                    pronouns: string | null;
                    name: string;
                    avatarURL: string | null;
                };
            }>>;
            camper: z.ZodNullable<z.ZodObject<{
                id: z.ZodNumber;
                name: z.ZodBranded<z.ZodString, "CamperDisplayName">;
                handle: z.ZodBranded<z.ZodString, "CamperHandle">;
                color: z.ZodNullable<z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">>;
                pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
                avatarUrl: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
            }, "strip", z.ZodTypeAny, {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            }, {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            }>>;
        }, "strip", z.ZodTypeAny, {
            camper: {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            } | null;
            content: string;
            chatRecordId: number;
            twitchMessageId: string;
            twitchParentMessageId: string | null;
            authorName: string;
            richContent: string | null;
            flair: ("camper" | "broadcaster" | "vip" | "mod" | "highlighted" | "subscriber" | "bot" | "firstThisSession" | "firstEver")[];
            identity: Readonly<{
                camper: {
                    color: (string & z.BRAND<"ColorString">) | null;
                    handle: string & z.BRAND<"CamperHandle">;
                    pronouns: (string & z.BRAND<"PronounString">) | null;
                    id: number;
                    name: string & z.BRAND<"CamperDisplayName">;
                    avatarUrl: (string & z.BRAND<"URLString">) | null;
                } | null;
                twitchIdentityId: number;
                twitchId: string;
                twitchHandle: string;
                twitchDisplayName: string;
                twitchNameColor: string;
                twitchChannelURL: string;
                info: {
                    color: string & z.BRAND<"ColorString">;
                    pronouns: (string & z.BRAND<"PronounString">) | null;
                    name: string;
                    avatarURL: (string & z.BRAND<"URLString">) | null;
                };
            }>;
        }, {
            camper: {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            } | null;
            content: string;
            chatRecordId: number;
            twitchMessageId: string;
            twitchParentMessageId: string | null;
            authorName: string;
            richContent: string | null;
            flair: ("camper" | "broadcaster" | "vip" | "mod" | "highlighted" | "subscriber" | "bot" | "firstThisSession" | "firstEver")[];
            identity: Readonly<{
                camper: {
                    color: string | null;
                    handle: string;
                    pronouns: string | null;
                    id: number;
                    name: string;
                    avatarUrl: string | null;
                } | null;
                twitchIdentityId: number;
                twitchId: string;
                twitchHandle: string;
                twitchDisplayName: string;
                twitchNameColor: string;
                twitchChannelURL: string;
                info: {
                    color: string;
                    pronouns: string | null;
                    name: string;
                    avatarURL: string | null;
                };
            }>;
        }>>, "many">;
    };
    readonly "twitch/identity/by-id": {
        readonly params: z.ZodObject<{
            id: z.ZodNumber;
        }, "strip", z.ZodTypeAny, {
            id: number;
        }, {
            id: number;
        }>;
        readonly response: z.ZodNullable<z.ZodReadonly<z.ZodObject<{
            twitchIdentityId: z.ZodNumber;
            twitchId: z.ZodString;
            camper: z.ZodNullable<z.ZodObject<{
                id: z.ZodNumber;
                name: z.ZodBranded<z.ZodString, "CamperDisplayName">;
                handle: z.ZodBranded<z.ZodString, "CamperHandle">;
                color: z.ZodNullable<z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">>;
                pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
                avatarUrl: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
            }, "strip", z.ZodTypeAny, {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            }, {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            }>>;
            twitchHandle: z.ZodString;
            twitchDisplayName: z.ZodString;
            twitchNameColor: z.ZodString;
            twitchChannelURL: z.ZodString;
            info: z.ZodObject<{
                name: z.ZodString;
                color: z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">;
                pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
                avatarURL: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
            }, "strip", z.ZodTypeAny, {
                color: string & z.BRAND<"ColorString">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                name: string;
                avatarURL: (string & z.BRAND<"URLString">) | null;
            }, {
                color: string;
                pronouns: string | null;
                name: string;
                avatarURL: string | null;
            }>;
        }, "strip", z.ZodTypeAny, {
            camper: {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string & z.BRAND<"ColorString">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                name: string;
                avatarURL: (string & z.BRAND<"URLString">) | null;
            };
        }, {
            camper: {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string;
                pronouns: string | null;
                name: string;
                avatarURL: string | null;
            };
        }>>>;
    };
    readonly "twitch/identity/by-twitch-id": {
        readonly params: z.ZodObject<{
            twitchId: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            twitchId: string;
        }, {
            twitchId: string;
        }>;
        readonly response: z.ZodNullable<z.ZodReadonly<z.ZodObject<{
            twitchIdentityId: z.ZodNumber;
            twitchId: z.ZodString;
            camper: z.ZodNullable<z.ZodObject<{
                id: z.ZodNumber;
                name: z.ZodBranded<z.ZodString, "CamperDisplayName">;
                handle: z.ZodBranded<z.ZodString, "CamperHandle">;
                color: z.ZodNullable<z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">>;
                pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
                avatarUrl: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
            }, "strip", z.ZodTypeAny, {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            }, {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            }>>;
            twitchHandle: z.ZodString;
            twitchDisplayName: z.ZodString;
            twitchNameColor: z.ZodString;
            twitchChannelURL: z.ZodString;
            info: z.ZodObject<{
                name: z.ZodString;
                color: z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">;
                pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
                avatarURL: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
            }, "strip", z.ZodTypeAny, {
                color: string & z.BRAND<"ColorString">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                name: string;
                avatarURL: (string & z.BRAND<"URLString">) | null;
            }, {
                color: string;
                pronouns: string | null;
                name: string;
                avatarURL: string | null;
            }>;
        }, "strip", z.ZodTypeAny, {
            camper: {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string & z.BRAND<"ColorString">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                name: string;
                avatarURL: (string & z.BRAND<"URLString">) | null;
            };
        }, {
            camper: {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string;
                pronouns: string | null;
                name: string;
                avatarURL: string | null;
            };
        }>>>;
    };
    readonly "twitch/identity/by-twitch-handle": {
        readonly params: z.ZodObject<{
            twitchHandle: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            twitchHandle: string;
        }, {
            twitchHandle: string;
        }>;
        readonly response: z.ZodNullable<z.ZodReadonly<z.ZodObject<{
            twitchIdentityId: z.ZodNumber;
            twitchId: z.ZodString;
            camper: z.ZodNullable<z.ZodObject<{
                id: z.ZodNumber;
                name: z.ZodBranded<z.ZodString, "CamperDisplayName">;
                handle: z.ZodBranded<z.ZodString, "CamperHandle">;
                color: z.ZodNullable<z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">>;
                pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
                avatarUrl: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
            }, "strip", z.ZodTypeAny, {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            }, {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            }>>;
            twitchHandle: z.ZodString;
            twitchDisplayName: z.ZodString;
            twitchNameColor: z.ZodString;
            twitchChannelURL: z.ZodString;
            info: z.ZodObject<{
                name: z.ZodString;
                color: z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">;
                pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
                avatarURL: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
            }, "strip", z.ZodTypeAny, {
                color: string & z.BRAND<"ColorString">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                name: string;
                avatarURL: (string & z.BRAND<"URLString">) | null;
            }, {
                color: string;
                pronouns: string | null;
                name: string;
                avatarURL: string | null;
            }>;
        }, "strip", z.ZodTypeAny, {
            camper: {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string & z.BRAND<"ColorString">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                name: string;
                avatarURL: (string & z.BRAND<"URLString">) | null;
            };
        }, {
            camper: {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string;
                pronouns: string | null;
                name: string;
                avatarURL: string | null;
            };
        }>>>;
    };
    readonly "twitch/identity/by-camper-id": {
        readonly params: z.ZodObject<{
            camperId: z.ZodNumber;
        }, "strip", z.ZodTypeAny, {
            camperId: number;
        }, {
            camperId: number;
        }>;
        readonly response: z.ZodNullable<z.ZodReadonly<z.ZodObject<{
            twitchIdentityId: z.ZodNumber;
            twitchId: z.ZodString;
            camper: z.ZodNullable<z.ZodObject<{
                id: z.ZodNumber;
                name: z.ZodBranded<z.ZodString, "CamperDisplayName">;
                handle: z.ZodBranded<z.ZodString, "CamperHandle">;
                color: z.ZodNullable<z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">>;
                pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
                avatarUrl: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
            }, "strip", z.ZodTypeAny, {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            }, {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            }>>;
            twitchHandle: z.ZodString;
            twitchDisplayName: z.ZodString;
            twitchNameColor: z.ZodString;
            twitchChannelURL: z.ZodString;
            info: z.ZodObject<{
                name: z.ZodString;
                color: z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">;
                pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
                avatarURL: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
            }, "strip", z.ZodTypeAny, {
                color: string & z.BRAND<"ColorString">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                name: string;
                avatarURL: (string & z.BRAND<"URLString">) | null;
            }, {
                color: string;
                pronouns: string | null;
                name: string;
                avatarURL: string | null;
            }>;
        }, "strip", z.ZodTypeAny, {
            camper: {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string & z.BRAND<"ColorString">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                name: string;
                avatarURL: (string & z.BRAND<"URLString">) | null;
            };
        }, {
            camper: {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string;
                pronouns: string | null;
                name: string;
                avatarURL: string | null;
            };
        }>>>;
    };
    readonly "twitch/identities-with-campers": {
        readonly params: z.ZodObject<{}, "strip", z.ZodTypeAny, {}, {}>;
        readonly response: z.ZodArray<z.ZodReadonly<z.ZodObject<{
            twitchIdentityId: z.ZodNumber;
            twitchId: z.ZodString;
            camper: z.ZodNullable<z.ZodObject<{
                id: z.ZodNumber;
                name: z.ZodBranded<z.ZodString, "CamperDisplayName">;
                handle: z.ZodBranded<z.ZodString, "CamperHandle">;
                color: z.ZodNullable<z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">>;
                pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
                avatarUrl: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
            }, "strip", z.ZodTypeAny, {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            }, {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            }>>;
            twitchHandle: z.ZodString;
            twitchDisplayName: z.ZodString;
            twitchNameColor: z.ZodString;
            twitchChannelURL: z.ZodString;
            info: z.ZodObject<{
                name: z.ZodString;
                color: z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">;
                pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
                avatarURL: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
            }, "strip", z.ZodTypeAny, {
                color: string & z.BRAND<"ColorString">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                name: string;
                avatarURL: (string & z.BRAND<"URLString">) | null;
            }, {
                color: string;
                pronouns: string | null;
                name: string;
                avatarURL: string | null;
            }>;
        }, "strip", z.ZodTypeAny, {
            camper: {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string & z.BRAND<"ColorString">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                name: string;
                avatarURL: (string & z.BRAND<"URLString">) | null;
            };
        }, {
            camper: {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string;
                pronouns: string | null;
                name: string;
                avatarURL: string | null;
            };
        }>>, "many">;
    };
    readonly "twitch/identities-with-camper-and-token": {
        readonly params: z.ZodObject<{}, "strip", z.ZodTypeAny, {}, {}>;
        readonly response: z.ZodArray<z.ZodReadonly<z.ZodObject<{
            twitchIdentityId: z.ZodNumber;
            twitchId: z.ZodString;
            camper: z.ZodNullable<z.ZodObject<{
                id: z.ZodNumber;
                name: z.ZodBranded<z.ZodString, "CamperDisplayName">;
                handle: z.ZodBranded<z.ZodString, "CamperHandle">;
                color: z.ZodNullable<z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">>;
                pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
                avatarUrl: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
            }, "strip", z.ZodTypeAny, {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            }, {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            }>>;
            twitchHandle: z.ZodString;
            twitchDisplayName: z.ZodString;
            twitchNameColor: z.ZodString;
            twitchChannelURL: z.ZodString;
            info: z.ZodObject<{
                name: z.ZodString;
                color: z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">;
                pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
                avatarURL: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
            }, "strip", z.ZodTypeAny, {
                color: string & z.BRAND<"ColorString">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                name: string;
                avatarURL: (string & z.BRAND<"URLString">) | null;
            }, {
                color: string;
                pronouns: string | null;
                name: string;
                avatarURL: string | null;
            }>;
        }, "strip", z.ZodTypeAny, {
            camper: {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string & z.BRAND<"ColorString">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                name: string;
                avatarURL: (string & z.BRAND<"URLString">) | null;
            };
        }, {
            camper: {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string;
                pronouns: string | null;
                name: string;
                avatarURL: string | null;
            };
        }>>, "many">;
    };
};
export declare const TwitchRelayEvents: {
    readonly "twitch:chat": z.ZodObject<{
        chat: z.ZodReadonly<z.ZodObject<{
            chatRecordId: z.ZodNumber;
            twitchMessageId: z.ZodString;
            twitchParentMessageId: z.ZodNullable<z.ZodString>;
            authorName: z.ZodString;
            content: z.ZodString;
            richContent: z.ZodNullable<z.ZodString>;
            flair: z.ZodArray<z.ZodEnum<["broadcaster", "vip", "mod", "highlighted", "subscriber", "camper", "bot", "firstThisSession", "firstEver"]>, "many">;
            identity: z.ZodReadonly<z.ZodObject<{
                twitchIdentityId: z.ZodNumber;
                twitchId: z.ZodString;
                camper: z.ZodNullable<z.ZodObject<{
                    id: z.ZodNumber;
                    name: z.ZodBranded<z.ZodString, "CamperDisplayName">;
                    handle: z.ZodBranded<z.ZodString, "CamperHandle">;
                    color: z.ZodNullable<z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">>;
                    pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
                    avatarUrl: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
                }, "strip", z.ZodTypeAny, {
                    color: (string & z.BRAND<"ColorString">) | null;
                    handle: string & z.BRAND<"CamperHandle">;
                    pronouns: (string & z.BRAND<"PronounString">) | null;
                    id: number;
                    name: string & z.BRAND<"CamperDisplayName">;
                    avatarUrl: (string & z.BRAND<"URLString">) | null;
                }, {
                    color: string | null;
                    handle: string;
                    pronouns: string | null;
                    id: number;
                    name: string;
                    avatarUrl: string | null;
                }>>;
                twitchHandle: z.ZodString;
                twitchDisplayName: z.ZodString;
                twitchNameColor: z.ZodString;
                twitchChannelURL: z.ZodString;
                info: z.ZodObject<{
                    name: z.ZodString;
                    color: z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">;
                    pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
                    avatarURL: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
                }, "strip", z.ZodTypeAny, {
                    color: string & z.BRAND<"ColorString">;
                    pronouns: (string & z.BRAND<"PronounString">) | null;
                    name: string;
                    avatarURL: (string & z.BRAND<"URLString">) | null;
                }, {
                    color: string;
                    pronouns: string | null;
                    name: string;
                    avatarURL: string | null;
                }>;
            }, "strip", z.ZodTypeAny, {
                camper: {
                    color: (string & z.BRAND<"ColorString">) | null;
                    handle: string & z.BRAND<"CamperHandle">;
                    pronouns: (string & z.BRAND<"PronounString">) | null;
                    id: number;
                    name: string & z.BRAND<"CamperDisplayName">;
                    avatarUrl: (string & z.BRAND<"URLString">) | null;
                } | null;
                twitchIdentityId: number;
                twitchId: string;
                twitchHandle: string;
                twitchDisplayName: string;
                twitchNameColor: string;
                twitchChannelURL: string;
                info: {
                    color: string & z.BRAND<"ColorString">;
                    pronouns: (string & z.BRAND<"PronounString">) | null;
                    name: string;
                    avatarURL: (string & z.BRAND<"URLString">) | null;
                };
            }, {
                camper: {
                    color: string | null;
                    handle: string;
                    pronouns: string | null;
                    id: number;
                    name: string;
                    avatarUrl: string | null;
                } | null;
                twitchIdentityId: number;
                twitchId: string;
                twitchHandle: string;
                twitchDisplayName: string;
                twitchNameColor: string;
                twitchChannelURL: string;
                info: {
                    color: string;
                    pronouns: string | null;
                    name: string;
                    avatarURL: string | null;
                };
            }>>;
            camper: z.ZodNullable<z.ZodObject<{
                id: z.ZodNumber;
                name: z.ZodBranded<z.ZodString, "CamperDisplayName">;
                handle: z.ZodBranded<z.ZodString, "CamperHandle">;
                color: z.ZodNullable<z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">>;
                pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
                avatarUrl: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
            }, "strip", z.ZodTypeAny, {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            }, {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            }>>;
        }, "strip", z.ZodTypeAny, {
            camper: {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            } | null;
            content: string;
            chatRecordId: number;
            twitchMessageId: string;
            twitchParentMessageId: string | null;
            authorName: string;
            richContent: string | null;
            flair: ("camper" | "broadcaster" | "vip" | "mod" | "highlighted" | "subscriber" | "bot" | "firstThisSession" | "firstEver")[];
            identity: Readonly<{
                camper: {
                    color: (string & z.BRAND<"ColorString">) | null;
                    handle: string & z.BRAND<"CamperHandle">;
                    pronouns: (string & z.BRAND<"PronounString">) | null;
                    id: number;
                    name: string & z.BRAND<"CamperDisplayName">;
                    avatarUrl: (string & z.BRAND<"URLString">) | null;
                } | null;
                twitchIdentityId: number;
                twitchId: string;
                twitchHandle: string;
                twitchDisplayName: string;
                twitchNameColor: string;
                twitchChannelURL: string;
                info: {
                    color: string & z.BRAND<"ColorString">;
                    pronouns: (string & z.BRAND<"PronounString">) | null;
                    name: string;
                    avatarURL: (string & z.BRAND<"URLString">) | null;
                };
            }>;
        }, {
            camper: {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            } | null;
            content: string;
            chatRecordId: number;
            twitchMessageId: string;
            twitchParentMessageId: string | null;
            authorName: string;
            richContent: string | null;
            flair: ("camper" | "broadcaster" | "vip" | "mod" | "highlighted" | "subscriber" | "bot" | "firstThisSession" | "firstEver")[];
            identity: Readonly<{
                camper: {
                    color: string | null;
                    handle: string;
                    pronouns: string | null;
                    id: number;
                    name: string;
                    avatarUrl: string | null;
                } | null;
                twitchIdentityId: number;
                twitchId: string;
                twitchHandle: string;
                twitchDisplayName: string;
                twitchNameColor: string;
                twitchChannelURL: string;
                info: {
                    color: string;
                    pronouns: string | null;
                    name: string;
                    avatarURL: string | null;
                };
            }>;
        }>>;
        channel: z.ZodReadonly<z.ZodObject<{
            twitchIdentityId: z.ZodNumber;
            twitchId: z.ZodString;
            camper: z.ZodNullable<z.ZodObject<{
                id: z.ZodNumber;
                name: z.ZodBranded<z.ZodString, "CamperDisplayName">;
                handle: z.ZodBranded<z.ZodString, "CamperHandle">;
                color: z.ZodNullable<z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">>;
                pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
                avatarUrl: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
            }, "strip", z.ZodTypeAny, {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            }, {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            }>>;
            twitchHandle: z.ZodString;
            twitchDisplayName: z.ZodString;
            twitchNameColor: z.ZodString;
            twitchChannelURL: z.ZodString;
            info: z.ZodObject<{
                name: z.ZodString;
                color: z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">;
                pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
                avatarURL: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
            }, "strip", z.ZodTypeAny, {
                color: string & z.BRAND<"ColorString">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                name: string;
                avatarURL: (string & z.BRAND<"URLString">) | null;
            }, {
                color: string;
                pronouns: string | null;
                name: string;
                avatarURL: string | null;
            }>;
        }, "strip", z.ZodTypeAny, {
            camper: {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string & z.BRAND<"ColorString">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                name: string;
                avatarURL: (string & z.BRAND<"URLString">) | null;
            };
        }, {
            camper: {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string;
                pronouns: string | null;
                name: string;
                avatarURL: string | null;
            };
        }>>;
    }, "strip", z.ZodTypeAny, {
        chat: Readonly<{
            camper: {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            } | null;
            content: string;
            chatRecordId: number;
            twitchMessageId: string;
            twitchParentMessageId: string | null;
            authorName: string;
            richContent: string | null;
            flair: ("camper" | "broadcaster" | "vip" | "mod" | "highlighted" | "subscriber" | "bot" | "firstThisSession" | "firstEver")[];
            identity: Readonly<{
                camper: {
                    color: (string & z.BRAND<"ColorString">) | null;
                    handle: string & z.BRAND<"CamperHandle">;
                    pronouns: (string & z.BRAND<"PronounString">) | null;
                    id: number;
                    name: string & z.BRAND<"CamperDisplayName">;
                    avatarUrl: (string & z.BRAND<"URLString">) | null;
                } | null;
                twitchIdentityId: number;
                twitchId: string;
                twitchHandle: string;
                twitchDisplayName: string;
                twitchNameColor: string;
                twitchChannelURL: string;
                info: {
                    color: string & z.BRAND<"ColorString">;
                    pronouns: (string & z.BRAND<"PronounString">) | null;
                    name: string;
                    avatarURL: (string & z.BRAND<"URLString">) | null;
                };
            }>;
        }>;
        channel: Readonly<{
            camper: {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string & z.BRAND<"ColorString">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                name: string;
                avatarURL: (string & z.BRAND<"URLString">) | null;
            };
        }>;
    }, {
        chat: Readonly<{
            camper: {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            } | null;
            content: string;
            chatRecordId: number;
            twitchMessageId: string;
            twitchParentMessageId: string | null;
            authorName: string;
            richContent: string | null;
            flair: ("camper" | "broadcaster" | "vip" | "mod" | "highlighted" | "subscriber" | "bot" | "firstThisSession" | "firstEver")[];
            identity: Readonly<{
                camper: {
                    color: string | null;
                    handle: string;
                    pronouns: string | null;
                    id: number;
                    name: string;
                    avatarUrl: string | null;
                } | null;
                twitchIdentityId: number;
                twitchId: string;
                twitchHandle: string;
                twitchDisplayName: string;
                twitchNameColor: string;
                twitchChannelURL: string;
                info: {
                    color: string;
                    pronouns: string | null;
                    name: string;
                    avatarURL: string | null;
                };
            }>;
        }>;
        channel: Readonly<{
            camper: {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string;
                pronouns: string | null;
                name: string;
                avatarURL: string | null;
            };
        }>;
    }>;
    readonly "twitch:follow": z.ZodObject<{
        channel: z.ZodReadonly<z.ZodObject<{
            twitchIdentityId: z.ZodNumber;
            twitchId: z.ZodString;
            camper: z.ZodNullable<z.ZodObject<{
                id: z.ZodNumber;
                name: z.ZodBranded<z.ZodString, "CamperDisplayName">;
                handle: z.ZodBranded<z.ZodString, "CamperHandle">;
                color: z.ZodNullable<z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">>;
                pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
                avatarUrl: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
            }, "strip", z.ZodTypeAny, {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            }, {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            }>>;
            twitchHandle: z.ZodString;
            twitchDisplayName: z.ZodString;
            twitchNameColor: z.ZodString;
            twitchChannelURL: z.ZodString;
            info: z.ZodObject<{
                name: z.ZodString;
                color: z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">;
                pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
                avatarURL: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
            }, "strip", z.ZodTypeAny, {
                color: string & z.BRAND<"ColorString">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                name: string;
                avatarURL: (string & z.BRAND<"URLString">) | null;
            }, {
                color: string;
                pronouns: string | null;
                name: string;
                avatarURL: string | null;
            }>;
        }, "strip", z.ZodTypeAny, {
            camper: {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string & z.BRAND<"ColorString">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                name: string;
                avatarURL: (string & z.BRAND<"URLString">) | null;
            };
        }, {
            camper: {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string;
                pronouns: string | null;
                name: string;
                avatarURL: string | null;
            };
        }>>;
        follower: z.ZodReadonly<z.ZodObject<{
            twitchIdentityId: z.ZodNumber;
            twitchId: z.ZodString;
            camper: z.ZodNullable<z.ZodObject<{
                id: z.ZodNumber;
                name: z.ZodBranded<z.ZodString, "CamperDisplayName">;
                handle: z.ZodBranded<z.ZodString, "CamperHandle">;
                color: z.ZodNullable<z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">>;
                pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
                avatarUrl: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
            }, "strip", z.ZodTypeAny, {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            }, {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            }>>;
            twitchHandle: z.ZodString;
            twitchDisplayName: z.ZodString;
            twitchNameColor: z.ZodString;
            twitchChannelURL: z.ZodString;
            info: z.ZodObject<{
                name: z.ZodString;
                color: z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">;
                pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
                avatarURL: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
            }, "strip", z.ZodTypeAny, {
                color: string & z.BRAND<"ColorString">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                name: string;
                avatarURL: (string & z.BRAND<"URLString">) | null;
            }, {
                color: string;
                pronouns: string | null;
                name: string;
                avatarURL: string | null;
            }>;
        }, "strip", z.ZodTypeAny, {
            camper: {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string & z.BRAND<"ColorString">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                name: string;
                avatarURL: (string & z.BRAND<"URLString">) | null;
            };
        }, {
            camper: {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string;
                pronouns: string | null;
                name: string;
                avatarURL: string | null;
            };
        }>>;
    }, "strip", z.ZodTypeAny, {
        channel: Readonly<{
            camper: {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string & z.BRAND<"ColorString">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                name: string;
                avatarURL: (string & z.BRAND<"URLString">) | null;
            };
        }>;
        follower: Readonly<{
            camper: {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string & z.BRAND<"ColorString">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                name: string;
                avatarURL: (string & z.BRAND<"URLString">) | null;
            };
        }>;
    }, {
        channel: Readonly<{
            camper: {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string;
                pronouns: string | null;
                name: string;
                avatarURL: string | null;
            };
        }>;
        follower: Readonly<{
            camper: {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string;
                pronouns: string | null;
                name: string;
                avatarURL: string | null;
            };
        }>;
    }>;
    readonly "twitch:live": z.ZodObject<{
        channel: z.ZodReadonly<z.ZodObject<{
            twitchIdentityId: z.ZodNumber;
            twitchId: z.ZodString;
            camper: z.ZodNullable<z.ZodObject<{
                id: z.ZodNumber;
                name: z.ZodBranded<z.ZodString, "CamperDisplayName">;
                handle: z.ZodBranded<z.ZodString, "CamperHandle">;
                color: z.ZodNullable<z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">>;
                pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
                avatarUrl: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
            }, "strip", z.ZodTypeAny, {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            }, {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            }>>;
            twitchHandle: z.ZodString;
            twitchDisplayName: z.ZodString;
            twitchNameColor: z.ZodString;
            twitchChannelURL: z.ZodString;
            info: z.ZodObject<{
                name: z.ZodString;
                color: z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">;
                pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
                avatarURL: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
            }, "strip", z.ZodTypeAny, {
                color: string & z.BRAND<"ColorString">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                name: string;
                avatarURL: (string & z.BRAND<"URLString">) | null;
            }, {
                color: string;
                pronouns: string | null;
                name: string;
                avatarURL: string | null;
            }>;
        }, "strip", z.ZodTypeAny, {
            camper: {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string & z.BRAND<"ColorString">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                name: string;
                avatarURL: (string & z.BRAND<"URLString">) | null;
            };
        }, {
            camper: {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string;
                pronouns: string | null;
                name: string;
                avatarURL: string | null;
            };
        }>>;
    }, "strip", z.ZodTypeAny, {
        channel: Readonly<{
            camper: {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string & z.BRAND<"ColorString">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                name: string;
                avatarURL: (string & z.BRAND<"URLString">) | null;
            };
        }>;
    }, {
        channel: Readonly<{
            camper: {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string;
                pronouns: string | null;
                name: string;
                avatarURL: string | null;
            };
        }>;
    }>;
    readonly "twitch:raid": z.ZodObject<{
        channel: z.ZodReadonly<z.ZodObject<{
            twitchIdentityId: z.ZodNumber;
            twitchId: z.ZodString;
            camper: z.ZodNullable<z.ZodObject<{
                id: z.ZodNumber;
                name: z.ZodBranded<z.ZodString, "CamperDisplayName">;
                handle: z.ZodBranded<z.ZodString, "CamperHandle">;
                color: z.ZodNullable<z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">>;
                pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
                avatarUrl: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
            }, "strip", z.ZodTypeAny, {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            }, {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            }>>;
            twitchHandle: z.ZodString;
            twitchDisplayName: z.ZodString;
            twitchNameColor: z.ZodString;
            twitchChannelURL: z.ZodString;
            info: z.ZodObject<{
                name: z.ZodString;
                color: z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">;
                pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
                avatarURL: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
            }, "strip", z.ZodTypeAny, {
                color: string & z.BRAND<"ColorString">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                name: string;
                avatarURL: (string & z.BRAND<"URLString">) | null;
            }, {
                color: string;
                pronouns: string | null;
                name: string;
                avatarURL: string | null;
            }>;
        }, "strip", z.ZodTypeAny, {
            camper: {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string & z.BRAND<"ColorString">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                name: string;
                avatarURL: (string & z.BRAND<"URLString">) | null;
            };
        }, {
            camper: {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string;
                pronouns: string | null;
                name: string;
                avatarURL: string | null;
            };
        }>>;
        raider: z.ZodReadonly<z.ZodObject<{
            twitchIdentityId: z.ZodNumber;
            twitchId: z.ZodString;
            camper: z.ZodNullable<z.ZodObject<{
                id: z.ZodNumber;
                name: z.ZodBranded<z.ZodString, "CamperDisplayName">;
                handle: z.ZodBranded<z.ZodString, "CamperHandle">;
                color: z.ZodNullable<z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">>;
                pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
                avatarUrl: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
            }, "strip", z.ZodTypeAny, {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            }, {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            }>>;
            twitchHandle: z.ZodString;
            twitchDisplayName: z.ZodString;
            twitchNameColor: z.ZodString;
            twitchChannelURL: z.ZodString;
            info: z.ZodObject<{
                name: z.ZodString;
                color: z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">;
                pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
                avatarURL: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
            }, "strip", z.ZodTypeAny, {
                color: string & z.BRAND<"ColorString">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                name: string;
                avatarURL: (string & z.BRAND<"URLString">) | null;
            }, {
                color: string;
                pronouns: string | null;
                name: string;
                avatarURL: string | null;
            }>;
        }, "strip", z.ZodTypeAny, {
            camper: {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string & z.BRAND<"ColorString">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                name: string;
                avatarURL: (string & z.BRAND<"URLString">) | null;
            };
        }, {
            camper: {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string;
                pronouns: string | null;
                name: string;
                avatarURL: string | null;
            };
        }>>;
        count: z.ZodNumber;
    }, "strip", z.ZodTypeAny, {
        count: number;
        channel: Readonly<{
            camper: {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string & z.BRAND<"ColorString">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                name: string;
                avatarURL: (string & z.BRAND<"URLString">) | null;
            };
        }>;
        raider: Readonly<{
            camper: {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string & z.BRAND<"ColorString">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                name: string;
                avatarURL: (string & z.BRAND<"URLString">) | null;
            };
        }>;
    }, {
        count: number;
        channel: Readonly<{
            camper: {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string;
                pronouns: string | null;
                name: string;
                avatarURL: string | null;
            };
        }>;
        raider: Readonly<{
            camper: {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string;
                pronouns: string | null;
                name: string;
                avatarURL: string | null;
            };
        }>;
    }>;
    readonly "twitch:hype-train-start": z.ZodObject<{
        channel: z.ZodReadonly<z.ZodObject<{
            twitchIdentityId: z.ZodNumber;
            twitchId: z.ZodString;
            camper: z.ZodNullable<z.ZodObject<{
                id: z.ZodNumber;
                name: z.ZodBranded<z.ZodString, "CamperDisplayName">;
                handle: z.ZodBranded<z.ZodString, "CamperHandle">;
                color: z.ZodNullable<z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">>;
                pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
                avatarUrl: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
            }, "strip", z.ZodTypeAny, {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            }, {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            }>>;
            twitchHandle: z.ZodString;
            twitchDisplayName: z.ZodString;
            twitchNameColor: z.ZodString;
            twitchChannelURL: z.ZodString;
            info: z.ZodObject<{
                name: z.ZodString;
                color: z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">;
                pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
                avatarURL: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
            }, "strip", z.ZodTypeAny, {
                color: string & z.BRAND<"ColorString">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                name: string;
                avatarURL: (string & z.BRAND<"URLString">) | null;
            }, {
                color: string;
                pronouns: string | null;
                name: string;
                avatarURL: string | null;
            }>;
        }, "strip", z.ZodTypeAny, {
            camper: {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string & z.BRAND<"ColorString">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                name: string;
                avatarURL: (string & z.BRAND<"URLString">) | null;
            };
        }, {
            camper: {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string;
                pronouns: string | null;
                name: string;
                avatarURL: string | null;
            };
        }>>;
    }, "strip", z.ZodTypeAny, {
        channel: Readonly<{
            camper: {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string & z.BRAND<"ColorString">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                name: string;
                avatarURL: (string & z.BRAND<"URLString">) | null;
            };
        }>;
    }, {
        channel: Readonly<{
            camper: {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string;
                pronouns: string | null;
                name: string;
                avatarURL: string | null;
            };
        }>;
    }>;
    readonly "twitch:hype-train-end": z.ZodObject<{
        channel: z.ZodReadonly<z.ZodObject<{
            twitchIdentityId: z.ZodNumber;
            twitchId: z.ZodString;
            camper: z.ZodNullable<z.ZodObject<{
                id: z.ZodNumber;
                name: z.ZodBranded<z.ZodString, "CamperDisplayName">;
                handle: z.ZodBranded<z.ZodString, "CamperHandle">;
                color: z.ZodNullable<z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">>;
                pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
                avatarUrl: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
            }, "strip", z.ZodTypeAny, {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            }, {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            }>>;
            twitchHandle: z.ZodString;
            twitchDisplayName: z.ZodString;
            twitchNameColor: z.ZodString;
            twitchChannelURL: z.ZodString;
            info: z.ZodObject<{
                name: z.ZodString;
                color: z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">;
                pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
                avatarURL: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
            }, "strip", z.ZodTypeAny, {
                color: string & z.BRAND<"ColorString">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                name: string;
                avatarURL: (string & z.BRAND<"URLString">) | null;
            }, {
                color: string;
                pronouns: string | null;
                name: string;
                avatarURL: string | null;
            }>;
        }, "strip", z.ZodTypeAny, {
            camper: {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string & z.BRAND<"ColorString">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                name: string;
                avatarURL: (string & z.BRAND<"URLString">) | null;
            };
        }, {
            camper: {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string;
                pronouns: string | null;
                name: string;
                avatarURL: string | null;
            };
        }>>;
        level: z.ZodNumber;
    }, "strip", z.ZodTypeAny, {
        channel: Readonly<{
            camper: {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string & z.BRAND<"ColorString">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                name: string;
                avatarURL: (string & z.BRAND<"URLString">) | null;
            };
        }>;
        level: number;
    }, {
        channel: Readonly<{
            camper: {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string;
                pronouns: string | null;
                name: string;
                avatarURL: string | null;
            };
        }>;
        level: number;
    }>;
    readonly "twitch:cheer": z.ZodObject<{
        channel: z.ZodReadonly<z.ZodObject<{
            twitchIdentityId: z.ZodNumber;
            twitchId: z.ZodString;
            camper: z.ZodNullable<z.ZodObject<{
                id: z.ZodNumber;
                name: z.ZodBranded<z.ZodString, "CamperDisplayName">;
                handle: z.ZodBranded<z.ZodString, "CamperHandle">;
                color: z.ZodNullable<z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">>;
                pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
                avatarUrl: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
            }, "strip", z.ZodTypeAny, {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            }, {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            }>>;
            twitchHandle: z.ZodString;
            twitchDisplayName: z.ZodString;
            twitchNameColor: z.ZodString;
            twitchChannelURL: z.ZodString;
            info: z.ZodObject<{
                name: z.ZodString;
                color: z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">;
                pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
                avatarURL: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
            }, "strip", z.ZodTypeAny, {
                color: string & z.BRAND<"ColorString">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                name: string;
                avatarURL: (string & z.BRAND<"URLString">) | null;
            }, {
                color: string;
                pronouns: string | null;
                name: string;
                avatarURL: string | null;
            }>;
        }, "strip", z.ZodTypeAny, {
            camper: {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string & z.BRAND<"ColorString">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                name: string;
                avatarURL: (string & z.BRAND<"URLString">) | null;
            };
        }, {
            camper: {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string;
                pronouns: string | null;
                name: string;
                avatarURL: string | null;
            };
        }>>;
        cheerer: z.ZodReadonly<z.ZodObject<{
            twitchIdentityId: z.ZodNumber;
            twitchId: z.ZodString;
            camper: z.ZodNullable<z.ZodObject<{
                id: z.ZodNumber;
                name: z.ZodBranded<z.ZodString, "CamperDisplayName">;
                handle: z.ZodBranded<z.ZodString, "CamperHandle">;
                color: z.ZodNullable<z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">>;
                pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
                avatarUrl: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
            }, "strip", z.ZodTypeAny, {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            }, {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            }>>;
            twitchHandle: z.ZodString;
            twitchDisplayName: z.ZodString;
            twitchNameColor: z.ZodString;
            twitchChannelURL: z.ZodString;
            info: z.ZodObject<{
                name: z.ZodString;
                color: z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">;
                pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
                avatarURL: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
            }, "strip", z.ZodTypeAny, {
                color: string & z.BRAND<"ColorString">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                name: string;
                avatarURL: (string & z.BRAND<"URLString">) | null;
            }, {
                color: string;
                pronouns: string | null;
                name: string;
                avatarURL: string | null;
            }>;
        }, "strip", z.ZodTypeAny, {
            camper: {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string & z.BRAND<"ColorString">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                name: string;
                avatarURL: (string & z.BRAND<"URLString">) | null;
            };
        }, {
            camper: {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string;
                pronouns: string | null;
                name: string;
                avatarURL: string | null;
            };
        }>>;
        bits: z.ZodNumber;
        message: z.ZodNullable<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        message: string | null;
        channel: Readonly<{
            camper: {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string & z.BRAND<"ColorString">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                name: string;
                avatarURL: (string & z.BRAND<"URLString">) | null;
            };
        }>;
        cheerer: Readonly<{
            camper: {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string & z.BRAND<"ColorString">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                name: string;
                avatarURL: (string & z.BRAND<"URLString">) | null;
            };
        }>;
        bits: number;
    }, {
        message: string | null;
        channel: Readonly<{
            camper: {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string;
                pronouns: string | null;
                name: string;
                avatarURL: string | null;
            };
        }>;
        cheerer: Readonly<{
            camper: {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string;
                pronouns: string | null;
                name: string;
                avatarURL: string | null;
            };
        }>;
        bits: number;
    }>;
    readonly "twitch:ban": z.ZodObject<{
        channel: z.ZodReadonly<z.ZodObject<{
            twitchIdentityId: z.ZodNumber;
            twitchId: z.ZodString;
            camper: z.ZodNullable<z.ZodObject<{
                id: z.ZodNumber;
                name: z.ZodBranded<z.ZodString, "CamperDisplayName">;
                handle: z.ZodBranded<z.ZodString, "CamperHandle">;
                color: z.ZodNullable<z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">>;
                pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
                avatarUrl: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
            }, "strip", z.ZodTypeAny, {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            }, {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            }>>;
            twitchHandle: z.ZodString;
            twitchDisplayName: z.ZodString;
            twitchNameColor: z.ZodString;
            twitchChannelURL: z.ZodString;
            info: z.ZodObject<{
                name: z.ZodString;
                color: z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">;
                pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
                avatarURL: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
            }, "strip", z.ZodTypeAny, {
                color: string & z.BRAND<"ColorString">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                name: string;
                avatarURL: (string & z.BRAND<"URLString">) | null;
            }, {
                color: string;
                pronouns: string | null;
                name: string;
                avatarURL: string | null;
            }>;
        }, "strip", z.ZodTypeAny, {
            camper: {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string & z.BRAND<"ColorString">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                name: string;
                avatarURL: (string & z.BRAND<"URLString">) | null;
            };
        }, {
            camper: {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string;
                pronouns: string | null;
                name: string;
                avatarURL: string | null;
            };
        }>>;
        target: z.ZodReadonly<z.ZodObject<{
            twitchIdentityId: z.ZodNumber;
            twitchId: z.ZodString;
            camper: z.ZodNullable<z.ZodObject<{
                id: z.ZodNumber;
                name: z.ZodBranded<z.ZodString, "CamperDisplayName">;
                handle: z.ZodBranded<z.ZodString, "CamperHandle">;
                color: z.ZodNullable<z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">>;
                pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
                avatarUrl: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
            }, "strip", z.ZodTypeAny, {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            }, {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            }>>;
            twitchHandle: z.ZodString;
            twitchDisplayName: z.ZodString;
            twitchNameColor: z.ZodString;
            twitchChannelURL: z.ZodString;
            info: z.ZodObject<{
                name: z.ZodString;
                color: z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">;
                pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
                avatarURL: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
            }, "strip", z.ZodTypeAny, {
                color: string & z.BRAND<"ColorString">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                name: string;
                avatarURL: (string & z.BRAND<"URLString">) | null;
            }, {
                color: string;
                pronouns: string | null;
                name: string;
                avatarURL: string | null;
            }>;
        }, "strip", z.ZodTypeAny, {
            camper: {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string & z.BRAND<"ColorString">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                name: string;
                avatarURL: (string & z.BRAND<"URLString">) | null;
            };
        }, {
            camper: {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string;
                pronouns: string | null;
                name: string;
                avatarURL: string | null;
            };
        }>>;
        reason: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        channel: Readonly<{
            camper: {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string & z.BRAND<"ColorString">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                name: string;
                avatarURL: (string & z.BRAND<"URLString">) | null;
            };
        }>;
        target: Readonly<{
            camper: {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string & z.BRAND<"ColorString">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                name: string;
                avatarURL: (string & z.BRAND<"URLString">) | null;
            };
        }>;
        reason: string;
    }, {
        channel: Readonly<{
            camper: {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string;
                pronouns: string | null;
                name: string;
                avatarURL: string | null;
            };
        }>;
        target: Readonly<{
            camper: {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string;
                pronouns: string | null;
                name: string;
                avatarURL: string | null;
            };
        }>;
        reason: string;
    }>;
    readonly "twitch:subscription": z.ZodObject<{
        channel: z.ZodReadonly<z.ZodObject<{
            twitchIdentityId: z.ZodNumber;
            twitchId: z.ZodString;
            camper: z.ZodNullable<z.ZodObject<{
                id: z.ZodNumber;
                name: z.ZodBranded<z.ZodString, "CamperDisplayName">;
                handle: z.ZodBranded<z.ZodString, "CamperHandle">;
                color: z.ZodNullable<z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">>;
                pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
                avatarUrl: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
            }, "strip", z.ZodTypeAny, {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            }, {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            }>>;
            twitchHandle: z.ZodString;
            twitchDisplayName: z.ZodString;
            twitchNameColor: z.ZodString;
            twitchChannelURL: z.ZodString;
            info: z.ZodObject<{
                name: z.ZodString;
                color: z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">;
                pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
                avatarURL: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
            }, "strip", z.ZodTypeAny, {
                color: string & z.BRAND<"ColorString">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                name: string;
                avatarURL: (string & z.BRAND<"URLString">) | null;
            }, {
                color: string;
                pronouns: string | null;
                name: string;
                avatarURL: string | null;
            }>;
        }, "strip", z.ZodTypeAny, {
            camper: {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string & z.BRAND<"ColorString">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                name: string;
                avatarURL: (string & z.BRAND<"URLString">) | null;
            };
        }, {
            camper: {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string;
                pronouns: string | null;
                name: string;
                avatarURL: string | null;
            };
        }>>;
        subscriber: z.ZodReadonly<z.ZodObject<{
            twitchIdentityId: z.ZodNumber;
            twitchId: z.ZodString;
            camper: z.ZodNullable<z.ZodObject<{
                id: z.ZodNumber;
                name: z.ZodBranded<z.ZodString, "CamperDisplayName">;
                handle: z.ZodBranded<z.ZodString, "CamperHandle">;
                color: z.ZodNullable<z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">>;
                pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
                avatarUrl: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
            }, "strip", z.ZodTypeAny, {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            }, {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            }>>;
            twitchHandle: z.ZodString;
            twitchDisplayName: z.ZodString;
            twitchNameColor: z.ZodString;
            twitchChannelURL: z.ZodString;
            info: z.ZodObject<{
                name: z.ZodString;
                color: z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">;
                pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
                avatarURL: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
            }, "strip", z.ZodTypeAny, {
                color: string & z.BRAND<"ColorString">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                name: string;
                avatarURL: (string & z.BRAND<"URLString">) | null;
            }, {
                color: string;
                pronouns: string | null;
                name: string;
                avatarURL: string | null;
            }>;
        }, "strip", z.ZodTypeAny, {
            camper: {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string & z.BRAND<"ColorString">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                name: string;
                avatarURL: (string & z.BRAND<"URLString">) | null;
            };
        }, {
            camper: {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string;
                pronouns: string | null;
                name: string;
                avatarURL: string | null;
            };
        }>>;
        months: z.ZodNumber;
        message: z.ZodNullable<z.ZodString>;
        isGift: z.ZodBoolean;
        tier: z.ZodUnion<[z.ZodLiteral<"1000">, z.ZodLiteral<"2000">, z.ZodLiteral<"3000">]>;
    }, "strip", z.ZodTypeAny, {
        message: string | null;
        subscriber: Readonly<{
            camper: {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string & z.BRAND<"ColorString">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                name: string;
                avatarURL: (string & z.BRAND<"URLString">) | null;
            };
        }>;
        channel: Readonly<{
            camper: {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string & z.BRAND<"ColorString">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                name: string;
                avatarURL: (string & z.BRAND<"URLString">) | null;
            };
        }>;
        months: number;
        isGift: boolean;
        tier: "1000" | "2000" | "3000";
    }, {
        message: string | null;
        subscriber: Readonly<{
            camper: {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string;
                pronouns: string | null;
                name: string;
                avatarURL: string | null;
            };
        }>;
        channel: Readonly<{
            camper: {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string;
                pronouns: string | null;
                name: string;
                avatarURL: string | null;
            };
        }>;
        months: number;
        isGift: boolean;
        tier: "1000" | "2000" | "3000";
    }>;
    readonly "twitch:gifted-subscriptions": z.ZodObject<{
        channel: z.ZodReadonly<z.ZodObject<{
            twitchIdentityId: z.ZodNumber;
            twitchId: z.ZodString;
            camper: z.ZodNullable<z.ZodObject<{
                id: z.ZodNumber;
                name: z.ZodBranded<z.ZodString, "CamperDisplayName">;
                handle: z.ZodBranded<z.ZodString, "CamperHandle">;
                color: z.ZodNullable<z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">>;
                pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
                avatarUrl: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
            }, "strip", z.ZodTypeAny, {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            }, {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            }>>;
            twitchHandle: z.ZodString;
            twitchDisplayName: z.ZodString;
            twitchNameColor: z.ZodString;
            twitchChannelURL: z.ZodString;
            info: z.ZodObject<{
                name: z.ZodString;
                color: z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">;
                pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
                avatarURL: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
            }, "strip", z.ZodTypeAny, {
                color: string & z.BRAND<"ColorString">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                name: string;
                avatarURL: (string & z.BRAND<"URLString">) | null;
            }, {
                color: string;
                pronouns: string | null;
                name: string;
                avatarURL: string | null;
            }>;
        }, "strip", z.ZodTypeAny, {
            camper: {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string & z.BRAND<"ColorString">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                name: string;
                avatarURL: (string & z.BRAND<"URLString">) | null;
            };
        }, {
            camper: {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string;
                pronouns: string | null;
                name: string;
                avatarURL: string | null;
            };
        }>>;
        gifter: z.ZodNullable<z.ZodReadonly<z.ZodObject<{
            twitchIdentityId: z.ZodNumber;
            twitchId: z.ZodString;
            camper: z.ZodNullable<z.ZodObject<{
                id: z.ZodNumber;
                name: z.ZodBranded<z.ZodString, "CamperDisplayName">;
                handle: z.ZodBranded<z.ZodString, "CamperHandle">;
                color: z.ZodNullable<z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">>;
                pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
                avatarUrl: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
            }, "strip", z.ZodTypeAny, {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            }, {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            }>>;
            twitchHandle: z.ZodString;
            twitchDisplayName: z.ZodString;
            twitchNameColor: z.ZodString;
            twitchChannelURL: z.ZodString;
            info: z.ZodObject<{
                name: z.ZodString;
                color: z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">;
                pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
                avatarURL: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
            }, "strip", z.ZodTypeAny, {
                color: string & z.BRAND<"ColorString">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                name: string;
                avatarURL: (string & z.BRAND<"URLString">) | null;
            }, {
                color: string;
                pronouns: string | null;
                name: string;
                avatarURL: string | null;
            }>;
        }, "strip", z.ZodTypeAny, {
            camper: {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string & z.BRAND<"ColorString">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                name: string;
                avatarURL: (string & z.BRAND<"URLString">) | null;
            };
        }, {
            camper: {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string;
                pronouns: string | null;
                name: string;
                avatarURL: string | null;
            };
        }>>>;
        count: z.ZodNumber;
        tier: z.ZodUnion<[z.ZodLiteral<"1000">, z.ZodLiteral<"2000">, z.ZodLiteral<"3000">]>;
    }, "strip", z.ZodTypeAny, {
        count: number;
        channel: Readonly<{
            camper: {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string & z.BRAND<"ColorString">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                name: string;
                avatarURL: (string & z.BRAND<"URLString">) | null;
            };
        }>;
        tier: "1000" | "2000" | "3000";
        gifter: Readonly<{
            camper: {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string & z.BRAND<"ColorString">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                name: string;
                avatarURL: (string & z.BRAND<"URLString">) | null;
            };
        }> | null;
    }, {
        count: number;
        channel: Readonly<{
            camper: {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string;
                pronouns: string | null;
                name: string;
                avatarURL: string | null;
            };
        }>;
        tier: "1000" | "2000" | "3000";
        gifter: Readonly<{
            camper: {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string;
                pronouns: string | null;
                name: string;
                avatarURL: string | null;
            };
        }> | null;
    }>;
    readonly "twitch:redemption": z.ZodObject<{
        channel: z.ZodReadonly<z.ZodObject<{
            twitchIdentityId: z.ZodNumber;
            twitchId: z.ZodString;
            camper: z.ZodNullable<z.ZodObject<{
                id: z.ZodNumber;
                name: z.ZodBranded<z.ZodString, "CamperDisplayName">;
                handle: z.ZodBranded<z.ZodString, "CamperHandle">;
                color: z.ZodNullable<z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">>;
                pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
                avatarUrl: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
            }, "strip", z.ZodTypeAny, {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            }, {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            }>>;
            twitchHandle: z.ZodString;
            twitchDisplayName: z.ZodString;
            twitchNameColor: z.ZodString;
            twitchChannelURL: z.ZodString;
            info: z.ZodObject<{
                name: z.ZodString;
                color: z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">;
                pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
                avatarURL: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
            }, "strip", z.ZodTypeAny, {
                color: string & z.BRAND<"ColorString">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                name: string;
                avatarURL: (string & z.BRAND<"URLString">) | null;
            }, {
                color: string;
                pronouns: string | null;
                name: string;
                avatarURL: string | null;
            }>;
        }, "strip", z.ZodTypeAny, {
            camper: {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string & z.BRAND<"ColorString">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                name: string;
                avatarURL: (string & z.BRAND<"URLString">) | null;
            };
        }, {
            camper: {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string;
                pronouns: string | null;
                name: string;
                avatarURL: string | null;
            };
        }>>;
        viewer: z.ZodReadonly<z.ZodObject<{
            twitchIdentityId: z.ZodNumber;
            twitchId: z.ZodString;
            camper: z.ZodNullable<z.ZodObject<{
                id: z.ZodNumber;
                name: z.ZodBranded<z.ZodString, "CamperDisplayName">;
                handle: z.ZodBranded<z.ZodString, "CamperHandle">;
                color: z.ZodNullable<z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">>;
                pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
                avatarUrl: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
            }, "strip", z.ZodTypeAny, {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            }, {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            }>>;
            twitchHandle: z.ZodString;
            twitchDisplayName: z.ZodString;
            twitchNameColor: z.ZodString;
            twitchChannelURL: z.ZodString;
            info: z.ZodObject<{
                name: z.ZodString;
                color: z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">;
                pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
                avatarURL: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
            }, "strip", z.ZodTypeAny, {
                color: string & z.BRAND<"ColorString">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                name: string;
                avatarURL: (string & z.BRAND<"URLString">) | null;
            }, {
                color: string;
                pronouns: string | null;
                name: string;
                avatarURL: string | null;
            }>;
        }, "strip", z.ZodTypeAny, {
            camper: {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string & z.BRAND<"ColorString">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                name: string;
                avatarURL: (string & z.BRAND<"URLString">) | null;
            };
        }, {
            camper: {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string;
                pronouns: string | null;
                name: string;
                avatarURL: string | null;
            };
        }>>;
        redeemable: z.ZodObject<{
            id: z.ZodString;
            title: z.ZodString;
            message: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            id: string;
            title: string;
            message?: string | undefined;
        }, {
            id: string;
            title: string;
            message?: string | undefined;
        }>;
    }, "strip", z.ZodTypeAny, {
        redeemable: {
            id: string;
            title: string;
            message?: string | undefined;
        };
        channel: Readonly<{
            camper: {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string & z.BRAND<"ColorString">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                name: string;
                avatarURL: (string & z.BRAND<"URLString">) | null;
            };
        }>;
        viewer: Readonly<{
            camper: {
                color: (string & z.BRAND<"ColorString">) | null;
                handle: string & z.BRAND<"CamperHandle">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                id: number;
                name: string & z.BRAND<"CamperDisplayName">;
                avatarUrl: (string & z.BRAND<"URLString">) | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string & z.BRAND<"ColorString">;
                pronouns: (string & z.BRAND<"PronounString">) | null;
                name: string;
                avatarURL: (string & z.BRAND<"URLString">) | null;
            };
        }>;
    }, {
        redeemable: {
            id: string;
            title: string;
            message?: string | undefined;
        };
        channel: Readonly<{
            camper: {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string;
                pronouns: string | null;
                name: string;
                avatarURL: string | null;
            };
        }>;
        viewer: Readonly<{
            camper: {
                color: string | null;
                handle: string;
                pronouns: string | null;
                id: number;
                name: string;
                avatarUrl: string | null;
            } | null;
            twitchIdentityId: number;
            twitchId: string;
            twitchHandle: string;
            twitchDisplayName: string;
            twitchNameColor: string;
            twitchChannelURL: string;
            info: {
                color: string;
                pronouns: string | null;
                name: string;
                avatarURL: string | null;
            };
        }>;
    }>;
};
export type TwitchEventIdentifier = keyof typeof TwitchRelayEvents;
/******************
 * TWITCH ACTIONS *
 ******************/
export declare const TwitchRelayActions: {
    readonly "twitch@chat": {
        readonly input: z.ZodObject<{
            channelTwitchId: z.ZodString;
            content: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            content: string;
            channelTwitchId: string;
        }, {
            content: string;
            channelTwitchId: string;
        }>;
        readonly output: z.ZodBoolean;
    };
    readonly "twitch@delete-chat-record": {
        readonly input: z.ZodObject<{
            messageTwitchId: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            messageTwitchId: string;
        }, {
            messageTwitchId: string;
        }>;
        readonly output: z.ZodBoolean;
    };
    readonly "twitch@shoutout": {
        readonly input: z.ZodString;
        readonly output: z.ZodBoolean;
    };
    readonly "twitch@clear-chat": {
        readonly input: z.ZodUndefined;
        readonly output: z.ZodBoolean;
    };
};
