import { z } from "zod";
import { type ItemDefinition, type ItemSlug, type RecipeItemSlug } from "./items";
export declare const CONCOCTION_SLUGS: readonly ["liquidWanderingIce", "solidLiquidWanderingIce", "lightningInABottle", "soulWater", "silkwaterMist", "joyfultilizer", "maxJoyfultilizer", "quantumSeed", "fourthDimensionalPlantFood"];
export type ConcoctionSlug = (typeof CONCOCTION_SLUGS)[number];
export declare function parseConcoctionSlug(check: string): ConcoctionSlug;
export declare function isConcoctionSlug(check: string): check is ConcoctionSlug;
export type ConcoctionIngredientList = [ItemSlug, number][];
export interface ConcoctionDefinition {
    title: string;
    description: string;
    image: string;
    brewTime: number;
    brewTimeLeniency: number;
    ingredients: ConcoctionIngredientList;
    result: ItemSlug;
    recipe: RecipeItemSlug;
    hidden?: boolean;
}
export declare const ConcoctionRecipeSchema: z.ZodObject<{
    slug: z.ZodEnum<["liquidWanderingIce", "solidLiquidWanderingIce", "lightningInABottle", "soulWater", "silkwaterMist", "joyfultilizer", "maxJoyfultilizer", "quantumSeed", "fourthDimensionalPlantFood"]>;
    title: z.ZodString;
    description: z.ZodString;
    image: z.ZodString;
    brewTime: z.ZodNumber;
    brewTimeLeniency: z.ZodNumber;
    ingredients: z.ZodArray<z.ZodTuple<[z.ZodEnum<["silkwaterJug", "silkwaterJugLarge", "cracklingRainmeter", "swirlingStormwrangler", "fourthDimensionalPlantFood", "tcGen1Beeatrice", "tcGen1Campfire", "tcGen1Chisel", "tcGen1Cloudsailor", "tcGen1Lodge", "tcGen1Murmus", "tcGen1MurmusFoil", "tcGen1Giant", "tcGen1LettersInFlight", "tcGen1SkyCafe", "tcGen1UnknownLunar", "tcGen1UnknownSolar", "tcGen1SecretSauce", "tcGen1GillroyFoil", "tcGen2DapperInPurple", "tcGen2DefinitelyFits", "tcGen2KnowsHowItWorks", "tcGen2Casual", "tcGen2Arcwild", "tcGen2Mysthull", "tcGen2Lelatoll", "tcGen2Skyhook", "tcGen2Goldspire", "tcGen2DukePepperbottom", "tcGen2StudioFoil", "randomScrap", "mermaidScale", "timerootBark", "spritzBottle", "livingIcicle", "stardustBag", "flaskSmall", "harvestedAstralDaisy", "harvestedVoidIvy", "harvestedCrystalOrchid", "harvestedBloodLily", "harvestedRainbowLotus", "harvestedDragonleaf", "harvestedAcidBlossom", "harvestedLightningLotus", "recipeLiquidWanderingIce", "recipeSolidLiquidWanderingIce", "recipeLightningInABottle", "recipeSoulWater", "recipeSilkwaterMist", "recipeQuantumSeed", "recipeFourthDimensionalPlantFood", "recipeBlankPlaceholder", "liquidWanderingIce", "soulWater", "silkwaterMist", "lightningInABottle", "crystalGeode", "treasureChest", "leafPile", "fallenStar", "frozenTreasureChest", "heartShapedBox", "shippingCrate", "giantsGift", "seedPouch", "tcBoosterPackGen1Common", "tcBoosterPackGen1Uncommon", "tcBoosterPackGen1Part2", "tcBoosterPackGen1Full", "tcBoosterPackGen2Drop1", "cosmicPinwheel", "discardedJacket", "trident", "goldLeaf", "doubloon", "harvestedObsidianRose", "harvestedSmoulderingRose", "harvestedRitualPumpkin", "harvestedTrophyThistle", "astralMango", "spectralPapaya", "mysticMorel", "otherworldlyOnion", "bansheeBerry", "secretSauce", "cosmicSocks", "compositionNotebook", "shatteredSpyglassLens", "shatteredSpyglassBody", "shatteredSpyglassEyepiece", "restoredSpyglass", "netheriteVoucher", "fatefulLoom", "bullhorn", "fleetingFeather", "celestialStone", "stellarvibePresentSmall2023", "stellarvibePresentMedium2023", "stellarvibePresentSmallGlowing2023", "stellarvibePresentMediumGlowing2023", "stellarvibePresent2024", "stellarvibePresentGlowing2024", "stellarvibePresent2024Max", "stellarvibePresent2024GlowingMax", "stellarvibePresentSmall", "stellarvibePresentSmallGlowing", "stellarvibePresentMedium", "stellarvibePresentMediumGlowing", "stellarvibePresentLarge", "stellarvibePresentLargeGlowing", "joyfultilizer", "maxJoyfultilizer", "joyrootSeed", "recipeJoyfultilizer", "recipeMaxJoyfultilizer", "scrollOfCultivation", "scrollOfGreaterCultivation", "quantumSeed", "mundaneSeed", "voidIvySeed", "crystalOrchidSeed", "bloodLilySeed", "obsidianRoseSeed", "rainbowLotusSeed", "dragonleafSeed", "smoulderingRoseSeed", "wanderingIceSeed", "stardustBlossomSeed", "celestialBulbSeed", "celestialBoonflowerSeed", "astralMangoTreeSeed", "spectralPapayaTreeSeed", "ritualPumpkinSeed", "trophyThistleSeed", "acidBlossomSeed"]>, z.ZodNumber], null>, "many">;
    result: z.ZodEnum<["silkwaterJug", "silkwaterJugLarge", "cracklingRainmeter", "swirlingStormwrangler", "fourthDimensionalPlantFood", "tcGen1Beeatrice", "tcGen1Campfire", "tcGen1Chisel", "tcGen1Cloudsailor", "tcGen1Lodge", "tcGen1Murmus", "tcGen1MurmusFoil", "tcGen1Giant", "tcGen1LettersInFlight", "tcGen1SkyCafe", "tcGen1UnknownLunar", "tcGen1UnknownSolar", "tcGen1SecretSauce", "tcGen1GillroyFoil", "tcGen2DapperInPurple", "tcGen2DefinitelyFits", "tcGen2KnowsHowItWorks", "tcGen2Casual", "tcGen2Arcwild", "tcGen2Mysthull", "tcGen2Lelatoll", "tcGen2Skyhook", "tcGen2Goldspire", "tcGen2DukePepperbottom", "tcGen2StudioFoil", "randomScrap", "mermaidScale", "timerootBark", "spritzBottle", "livingIcicle", "stardustBag", "flaskSmall", "harvestedAstralDaisy", "harvestedVoidIvy", "harvestedCrystalOrchid", "harvestedBloodLily", "harvestedRainbowLotus", "harvestedDragonleaf", "harvestedAcidBlossom", "harvestedLightningLotus", "recipeLiquidWanderingIce", "recipeSolidLiquidWanderingIce", "recipeLightningInABottle", "recipeSoulWater", "recipeSilkwaterMist", "recipeQuantumSeed", "recipeFourthDimensionalPlantFood", "recipeBlankPlaceholder", "liquidWanderingIce", "soulWater", "silkwaterMist", "lightningInABottle", "crystalGeode", "treasureChest", "leafPile", "fallenStar", "frozenTreasureChest", "heartShapedBox", "shippingCrate", "giantsGift", "seedPouch", "tcBoosterPackGen1Common", "tcBoosterPackGen1Uncommon", "tcBoosterPackGen1Part2", "tcBoosterPackGen1Full", "tcBoosterPackGen2Drop1", "cosmicPinwheel", "discardedJacket", "trident", "goldLeaf", "doubloon", "harvestedObsidianRose", "harvestedSmoulderingRose", "harvestedRitualPumpkin", "harvestedTrophyThistle", "astralMango", "spectralPapaya", "mysticMorel", "otherworldlyOnion", "bansheeBerry", "secretSauce", "cosmicSocks", "compositionNotebook", "shatteredSpyglassLens", "shatteredSpyglassBody", "shatteredSpyglassEyepiece", "restoredSpyglass", "netheriteVoucher", "fatefulLoom", "bullhorn", "fleetingFeather", "celestialStone", "stellarvibePresentSmall2023", "stellarvibePresentMedium2023", "stellarvibePresentSmallGlowing2023", "stellarvibePresentMediumGlowing2023", "stellarvibePresent2024", "stellarvibePresentGlowing2024", "stellarvibePresent2024Max", "stellarvibePresent2024GlowingMax", "stellarvibePresentSmall", "stellarvibePresentSmallGlowing", "stellarvibePresentMedium", "stellarvibePresentMediumGlowing", "stellarvibePresentLarge", "stellarvibePresentLargeGlowing", "joyfultilizer", "maxJoyfultilizer", "joyrootSeed", "recipeJoyfultilizer", "recipeMaxJoyfultilizer", "scrollOfCultivation", "scrollOfGreaterCultivation", "quantumSeed", "mundaneSeed", "voidIvySeed", "crystalOrchidSeed", "bloodLilySeed", "obsidianRoseSeed", "rainbowLotusSeed", "dragonleafSeed", "smoulderingRoseSeed", "wanderingIceSeed", "stardustBlossomSeed", "celestialBulbSeed", "celestialBoonflowerSeed", "astralMangoTreeSeed", "spectralPapayaTreeSeed", "ritualPumpkinSeed", "trophyThistleSeed", "acidBlossomSeed"]>;
}, "strip", z.ZodTypeAny, {
    slug: "fourthDimensionalPlantFood" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "joyfultilizer" | "maxJoyfultilizer" | "quantumSeed" | "solidLiquidWanderingIce";
    title: string;
    description: string;
    image: string;
    brewTime: number;
    brewTimeLeniency: number;
    ingredients: ["silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed", number][];
    result: "silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed";
}, {
    slug: "fourthDimensionalPlantFood" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "joyfultilizer" | "maxJoyfultilizer" | "quantumSeed" | "solidLiquidWanderingIce";
    title: string;
    description: string;
    image: string;
    brewTime: number;
    brewTimeLeniency: number;
    ingredients: ["silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed", number][];
    result: "silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed";
}>;
export type ConcoctionRecipe = z.infer<typeof ConcoctionRecipeSchema>;
export declare const ConcoctionSchema: z.ZodObject<{
    id: z.ZodNumber;
    camperId: z.ZodNumber;
    slug: z.ZodEnum<["liquidWanderingIce", "solidLiquidWanderingIce", "lightningInABottle", "soulWater", "silkwaterMist", "joyfultilizer", "maxJoyfultilizer", "quantumSeed", "fourthDimensionalPlantFood"]>;
    turnsBrewing: z.ZodNumber;
    state: z.ZodString;
    recipe: z.ZodObject<{
        slug: z.ZodEnum<["liquidWanderingIce", "solidLiquidWanderingIce", "lightningInABottle", "soulWater", "silkwaterMist", "joyfultilizer", "maxJoyfultilizer", "quantumSeed", "fourthDimensionalPlantFood"]>;
        title: z.ZodString;
        description: z.ZodString;
        image: z.ZodString;
        brewTime: z.ZodNumber;
        brewTimeLeniency: z.ZodNumber;
        ingredients: z.ZodArray<z.ZodTuple<[z.ZodEnum<["silkwaterJug", "silkwaterJugLarge", "cracklingRainmeter", "swirlingStormwrangler", "fourthDimensionalPlantFood", "tcGen1Beeatrice", "tcGen1Campfire", "tcGen1Chisel", "tcGen1Cloudsailor", "tcGen1Lodge", "tcGen1Murmus", "tcGen1MurmusFoil", "tcGen1Giant", "tcGen1LettersInFlight", "tcGen1SkyCafe", "tcGen1UnknownLunar", "tcGen1UnknownSolar", "tcGen1SecretSauce", "tcGen1GillroyFoil", "tcGen2DapperInPurple", "tcGen2DefinitelyFits", "tcGen2KnowsHowItWorks", "tcGen2Casual", "tcGen2Arcwild", "tcGen2Mysthull", "tcGen2Lelatoll", "tcGen2Skyhook", "tcGen2Goldspire", "tcGen2DukePepperbottom", "tcGen2StudioFoil", "randomScrap", "mermaidScale", "timerootBark", "spritzBottle", "livingIcicle", "stardustBag", "flaskSmall", "harvestedAstralDaisy", "harvestedVoidIvy", "harvestedCrystalOrchid", "harvestedBloodLily", "harvestedRainbowLotus", "harvestedDragonleaf", "harvestedAcidBlossom", "harvestedLightningLotus", "recipeLiquidWanderingIce", "recipeSolidLiquidWanderingIce", "recipeLightningInABottle", "recipeSoulWater", "recipeSilkwaterMist", "recipeQuantumSeed", "recipeFourthDimensionalPlantFood", "recipeBlankPlaceholder", "liquidWanderingIce", "soulWater", "silkwaterMist", "lightningInABottle", "crystalGeode", "treasureChest", "leafPile", "fallenStar", "frozenTreasureChest", "heartShapedBox", "shippingCrate", "giantsGift", "seedPouch", "tcBoosterPackGen1Common", "tcBoosterPackGen1Uncommon", "tcBoosterPackGen1Part2", "tcBoosterPackGen1Full", "tcBoosterPackGen2Drop1", "cosmicPinwheel", "discardedJacket", "trident", "goldLeaf", "doubloon", "harvestedObsidianRose", "harvestedSmoulderingRose", "harvestedRitualPumpkin", "harvestedTrophyThistle", "astralMango", "spectralPapaya", "mysticMorel", "otherworldlyOnion", "bansheeBerry", "secretSauce", "cosmicSocks", "compositionNotebook", "shatteredSpyglassLens", "shatteredSpyglassBody", "shatteredSpyglassEyepiece", "restoredSpyglass", "netheriteVoucher", "fatefulLoom", "bullhorn", "fleetingFeather", "celestialStone", "stellarvibePresentSmall2023", "stellarvibePresentMedium2023", "stellarvibePresentSmallGlowing2023", "stellarvibePresentMediumGlowing2023", "stellarvibePresent2024", "stellarvibePresentGlowing2024", "stellarvibePresent2024Max", "stellarvibePresent2024GlowingMax", "stellarvibePresentSmall", "stellarvibePresentSmallGlowing", "stellarvibePresentMedium", "stellarvibePresentMediumGlowing", "stellarvibePresentLarge", "stellarvibePresentLargeGlowing", "joyfultilizer", "maxJoyfultilizer", "joyrootSeed", "recipeJoyfultilizer", "recipeMaxJoyfultilizer", "scrollOfCultivation", "scrollOfGreaterCultivation", "quantumSeed", "mundaneSeed", "voidIvySeed", "crystalOrchidSeed", "bloodLilySeed", "obsidianRoseSeed", "rainbowLotusSeed", "dragonleafSeed", "smoulderingRoseSeed", "wanderingIceSeed", "stardustBlossomSeed", "celestialBulbSeed", "celestialBoonflowerSeed", "astralMangoTreeSeed", "spectralPapayaTreeSeed", "ritualPumpkinSeed", "trophyThistleSeed", "acidBlossomSeed"]>, z.ZodNumber], null>, "many">;
        result: z.ZodEnum<["silkwaterJug", "silkwaterJugLarge", "cracklingRainmeter", "swirlingStormwrangler", "fourthDimensionalPlantFood", "tcGen1Beeatrice", "tcGen1Campfire", "tcGen1Chisel", "tcGen1Cloudsailor", "tcGen1Lodge", "tcGen1Murmus", "tcGen1MurmusFoil", "tcGen1Giant", "tcGen1LettersInFlight", "tcGen1SkyCafe", "tcGen1UnknownLunar", "tcGen1UnknownSolar", "tcGen1SecretSauce", "tcGen1GillroyFoil", "tcGen2DapperInPurple", "tcGen2DefinitelyFits", "tcGen2KnowsHowItWorks", "tcGen2Casual", "tcGen2Arcwild", "tcGen2Mysthull", "tcGen2Lelatoll", "tcGen2Skyhook", "tcGen2Goldspire", "tcGen2DukePepperbottom", "tcGen2StudioFoil", "randomScrap", "mermaidScale", "timerootBark", "spritzBottle", "livingIcicle", "stardustBag", "flaskSmall", "harvestedAstralDaisy", "harvestedVoidIvy", "harvestedCrystalOrchid", "harvestedBloodLily", "harvestedRainbowLotus", "harvestedDragonleaf", "harvestedAcidBlossom", "harvestedLightningLotus", "recipeLiquidWanderingIce", "recipeSolidLiquidWanderingIce", "recipeLightningInABottle", "recipeSoulWater", "recipeSilkwaterMist", "recipeQuantumSeed", "recipeFourthDimensionalPlantFood", "recipeBlankPlaceholder", "liquidWanderingIce", "soulWater", "silkwaterMist", "lightningInABottle", "crystalGeode", "treasureChest", "leafPile", "fallenStar", "frozenTreasureChest", "heartShapedBox", "shippingCrate", "giantsGift", "seedPouch", "tcBoosterPackGen1Common", "tcBoosterPackGen1Uncommon", "tcBoosterPackGen1Part2", "tcBoosterPackGen1Full", "tcBoosterPackGen2Drop1", "cosmicPinwheel", "discardedJacket", "trident", "goldLeaf", "doubloon", "harvestedObsidianRose", "harvestedSmoulderingRose", "harvestedRitualPumpkin", "harvestedTrophyThistle", "astralMango", "spectralPapaya", "mysticMorel", "otherworldlyOnion", "bansheeBerry", "secretSauce", "cosmicSocks", "compositionNotebook", "shatteredSpyglassLens", "shatteredSpyglassBody", "shatteredSpyglassEyepiece", "restoredSpyglass", "netheriteVoucher", "fatefulLoom", "bullhorn", "fleetingFeather", "celestialStone", "stellarvibePresentSmall2023", "stellarvibePresentMedium2023", "stellarvibePresentSmallGlowing2023", "stellarvibePresentMediumGlowing2023", "stellarvibePresent2024", "stellarvibePresentGlowing2024", "stellarvibePresent2024Max", "stellarvibePresent2024GlowingMax", "stellarvibePresentSmall", "stellarvibePresentSmallGlowing", "stellarvibePresentMedium", "stellarvibePresentMediumGlowing", "stellarvibePresentLarge", "stellarvibePresentLargeGlowing", "joyfultilizer", "maxJoyfultilizer", "joyrootSeed", "recipeJoyfultilizer", "recipeMaxJoyfultilizer", "scrollOfCultivation", "scrollOfGreaterCultivation", "quantumSeed", "mundaneSeed", "voidIvySeed", "crystalOrchidSeed", "bloodLilySeed", "obsidianRoseSeed", "rainbowLotusSeed", "dragonleafSeed", "smoulderingRoseSeed", "wanderingIceSeed", "stardustBlossomSeed", "celestialBulbSeed", "celestialBoonflowerSeed", "astralMangoTreeSeed", "spectralPapayaTreeSeed", "ritualPumpkinSeed", "trophyThistleSeed", "acidBlossomSeed"]>;
    }, "strip", z.ZodTypeAny, {
        slug: "fourthDimensionalPlantFood" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "joyfultilizer" | "maxJoyfultilizer" | "quantumSeed" | "solidLiquidWanderingIce";
        title: string;
        description: string;
        image: string;
        brewTime: number;
        brewTimeLeniency: number;
        ingredients: ["silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed", number][];
        result: "silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed";
    }, {
        slug: "fourthDimensionalPlantFood" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "joyfultilizer" | "maxJoyfultilizer" | "quantumSeed" | "solidLiquidWanderingIce";
        title: string;
        description: string;
        image: string;
        brewTime: number;
        brewTimeLeniency: number;
        ingredients: ["silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed", number][];
        result: "silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed";
    }>;
    isReady: z.ZodBoolean;
    autoStop: z.ZodBoolean;
}, "strip", z.ZodTypeAny, {
    id: number;
    slug: "fourthDimensionalPlantFood" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "joyfultilizer" | "maxJoyfultilizer" | "quantumSeed" | "solidLiquidWanderingIce";
    camperId: number;
    turnsBrewing: number;
    state: string;
    recipe: {
        slug: "fourthDimensionalPlantFood" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "joyfultilizer" | "maxJoyfultilizer" | "quantumSeed" | "solidLiquidWanderingIce";
        title: string;
        description: string;
        image: string;
        brewTime: number;
        brewTimeLeniency: number;
        ingredients: ["silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed", number][];
        result: "silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed";
    };
    isReady: boolean;
    autoStop: boolean;
}, {
    id: number;
    slug: "fourthDimensionalPlantFood" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "joyfultilizer" | "maxJoyfultilizer" | "quantumSeed" | "solidLiquidWanderingIce";
    camperId: number;
    turnsBrewing: number;
    state: string;
    recipe: {
        slug: "fourthDimensionalPlantFood" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "joyfultilizer" | "maxJoyfultilizer" | "quantumSeed" | "solidLiquidWanderingIce";
        title: string;
        description: string;
        image: string;
        brewTime: number;
        brewTimeLeniency: number;
        ingredients: ["silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed", number][];
        result: "silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed";
    };
    isReady: boolean;
    autoStop: boolean;
}>;
export type Concoction = z.infer<typeof ConcoctionSchema>;
export declare const ConcoctionStateSchema: z.ZodEnum<["early", "ready", "late", "destroyed"]>;
export type ConcoctionState = z.infer<typeof ConcoctionStateSchema>;
export declare const CONCOCTION_DEFINITIONS: Record<ConcoctionSlug, ConcoctionDefinition>;
export declare function getConcoctionDefinition(slug: ConcoctionSlug): ConcoctionDefinition;
export declare const RECIPE_MAPPING: Record<ConcoctionSlug, ItemSlug>;
export interface ExpandedConcoction extends ConcoctionDefinition {
    resultItem: ItemDefinition;
    recipeItem: ItemDefinition;
}
/**
 * Retrieves the expanded concoction definition associated with a given concoction slug.
 *
 * @param cocncoctionSlug - The slug of the concoction to find the expanded definition for.
 * @returns The expanded definition of the concoction associated with the given slug.
 * @throws Will throw an error if no concoction is found for the given slug.
 */
export declare function getExpandedConcoction(cocncoctionSlug: ConcoctionSlug): ExpandedConcoction;
/**
 * Retrieves an expanded concoction based on the provided source item definition and slug.
 *
 * @param source - The item definition which can be a recipe or a concoction.
 * @param sourceSlug - The slug of the source item.
 * @returns The expanded concoction derived from the source.
 * @throws Will throw an error if the source item is not a valid recipe or concoction.
 */
export declare function getExpandedRelatedConcoction(source: ItemDefinition): ExpandedConcoction;
