import { z } from "zod";
export declare const LodgeProfileSchema: z.ZodObject<{
    camper: z.ZodReadonly<z.ZodObject<z.objectUtil.extendShape<{
        id: z.ZodNumber;
        name: z.ZodBranded<z.ZodString, "CamperDisplayName">;
        handle: z.ZodBranded<z.ZodString, "CamperHandle">;
        color: z.ZodNullable<z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">>;
        pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
        avatarUrl: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
    }, {
        id: z.ZodNumber;
        handle: z.ZodBranded<z.ZodString, "CamperHandle">;
        name: z.ZodBranded<z.ZodString, "CamperDisplayName">;
        avatarUrl: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
        tagline: z.ZodNullable<z.ZodBranded<z.ZodString, "TaglineString">>;
        websiteUrl: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
        color: z.ZodNullable<z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">>;
        pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
        allowPings: z.ZodBoolean;
        syncDiscordDisplayName: z.ZodBoolean;
        createdAt: z.ZodBranded<z.ZodString, "TimestampString">;
        lastInteraction: z.ZodBranded<z.ZodString, "TimestampString">;
        role: z.ZodUnion<[z.ZodLiteral<import("./core").CamperAccessLevel.Banned>, z.ZodLiteral<import("./core").CamperAccessLevel.Normal>, z.ZodLiteral<import("./core").CamperAccessLevel.Firewatch>, z.ZodLiteral<import("./core").CamperAccessLevel.Moderator>, z.ZodLiteral<import("./core").CamperAccessLevel.Admin>]>;
    }>, "strip", z.ZodTypeAny, {
        color: (string & z.BRAND<"ColorString">) | null;
        allowPings: boolean;
        syncDiscordDisplayName: boolean;
        tagline: (string & z.BRAND<"TaglineString">) | null;
        handle: string & z.BRAND<"CamperHandle">;
        pronouns: (string & z.BRAND<"PronounString">) | null;
        id: number;
        name: string & z.BRAND<"CamperDisplayName">;
        avatarUrl: (string & z.BRAND<"URLString">) | null;
        websiteUrl: (string & z.BRAND<"URLString">) | null;
        createdAt: string & z.BRAND<"TimestampString">;
        lastInteraction: string & z.BRAND<"TimestampString">;
        role: import("./core").CamperAccessLevel;
    }, {
        color: string | null;
        allowPings: boolean;
        syncDiscordDisplayName: boolean;
        tagline: string | null;
        handle: string;
        pronouns: string | null;
        id: number;
        name: string;
        avatarUrl: string | null;
        websiteUrl: string | null;
        createdAt: string;
        lastInteraction: string;
        role: import("./core").CamperAccessLevel;
    }>>;
    sheet: z.ZodObject<{
        sheetId: z.ZodNumber;
        camperId: z.ZodNumber;
        resources: z.ZodObject<{
            conduits: z.ZodNumber;
            silkwater: z.ZodNumber;
        }, "strip", z.ZodTypeAny, {
            conduits: number;
            silkwater: number;
        }, {
            conduits: number;
            silkwater: number;
        }>;
        inventory: z.ZodArray<z.ZodObject<{
            itemId: z.ZodNumber;
            camperId: z.ZodNumber;
            slug: z.ZodEnum<["silkwaterJug", "silkwaterJugLarge", "cracklingRainmeter", "swirlingStormwrangler", "fourthDimensionalPlantFood", "tcGen1Beeatrice", "tcGen1Campfire", "tcGen1Chisel", "tcGen1Cloudsailor", "tcGen1Lodge", "tcGen1Murmus", "tcGen1MurmusFoil", "tcGen1Giant", "tcGen1LettersInFlight", "tcGen1SkyCafe", "tcGen1UnknownLunar", "tcGen1UnknownSolar", "tcGen1SecretSauce", "tcGen1GillroyFoil", "tcGen2DapperInPurple", "tcGen2DefinitelyFits", "tcGen2KnowsHowItWorks", "tcGen2Casual", "tcGen2Arcwild", "tcGen2Mysthull", "tcGen2Lelatoll", "tcGen2Skyhook", "tcGen2Goldspire", "tcGen2DukePepperbottom", "tcGen2StudioFoil", "randomScrap", "mermaidScale", "timerootBark", "spritzBottle", "livingIcicle", "stardustBag", "flaskSmall", "harvestedAstralDaisy", "harvestedVoidIvy", "harvestedCrystalOrchid", "harvestedBloodLily", "harvestedRainbowLotus", "harvestedDragonleaf", "harvestedAcidBlossom", "harvestedLightningLotus", "recipeLiquidWanderingIce", "recipeSolidLiquidWanderingIce", "recipeLightningInABottle", "recipeSoulWater", "recipeSilkwaterMist", "recipeQuantumSeed", "recipeFourthDimensionalPlantFood", "recipeBlankPlaceholder", "liquidWanderingIce", "soulWater", "silkwaterMist", "lightningInABottle", "crystalGeode", "treasureChest", "leafPile", "fallenStar", "frozenTreasureChest", "heartShapedBox", "shippingCrate", "giantsGift", "seedPouch", "tcBoosterPackGen1Common", "tcBoosterPackGen1Uncommon", "tcBoosterPackGen1Part2", "tcBoosterPackGen1Full", "tcBoosterPackGen2Drop1", "cosmicPinwheel", "discardedJacket", "trident", "goldLeaf", "doubloon", "harvestedObsidianRose", "harvestedSmoulderingRose", "harvestedRitualPumpkin", "harvestedTrophyThistle", "astralMango", "spectralPapaya", "mysticMorel", "otherworldlyOnion", "bansheeBerry", "secretSauce", "cosmicSocks", "compositionNotebook", "shatteredSpyglassLens", "shatteredSpyglassBody", "shatteredSpyglassEyepiece", "restoredSpyglass", "netheriteVoucher", "fatefulLoom", "bullhorn", "fleetingFeather", "celestialStone", "stellarvibePresentSmall2023", "stellarvibePresentMedium2023", "stellarvibePresentSmallGlowing2023", "stellarvibePresentMediumGlowing2023", "stellarvibePresent2024", "stellarvibePresentGlowing2024", "stellarvibePresent2024Max", "stellarvibePresent2024GlowingMax", "stellarvibePresentSmall", "stellarvibePresentSmallGlowing", "stellarvibePresentMedium", "stellarvibePresentMediumGlowing", "stellarvibePresentLarge", "stellarvibePresentLargeGlowing", "joyfultilizer", "maxJoyfultilizer", "joyrootSeed", "recipeJoyfultilizer", "recipeMaxJoyfultilizer", "scrollOfCultivation", "scrollOfGreaterCultivation", "quantumSeed", "mundaneSeed", "voidIvySeed", "crystalOrchidSeed", "bloodLilySeed", "obsidianRoseSeed", "rainbowLotusSeed", "dragonleafSeed", "smoulderingRoseSeed", "wanderingIceSeed", "stardustBlossomSeed", "celestialBulbSeed", "celestialBoonflowerSeed", "astralMangoTreeSeed", "spectralPapayaTreeSeed", "ritualPumpkinSeed", "trophyThistleSeed", "acidBlossomSeed"]>;
            name: z.ZodString;
            description: z.ZodString;
            flavorText: z.ZodString;
            icon: z.ZodString;
            value: z.ZodNumber;
            category: z.ZodEnum<["redeemable", "cosmetic", "container", "seed", "flower", "consumable", "card", "food", "relic", "scroll", "concoction", "recipe", "component"]>;
            categoryTitle: z.ZodString;
            preserveAfterUsing: z.ZodBoolean;
            canBeUsed: z.ZodBoolean;
            canUseInBotany: z.ZodBoolean;
            rarity: z.ZodEnum<["common", "uncommon", "rare", "relic"]>;
            relatedConcoction: z.ZodOptional<z.ZodEnum<["liquidWanderingIce", "solidLiquidWanderingIce", "lightningInABottle", "soulWater", "silkwaterMist", "joyfultilizer", "maxJoyfultilizer", "quantumSeed", "fourthDimensionalPlantFood"]>>;
        }, "strip", z.ZodTypeAny, {
            value: number;
            name: string;
            slug: "silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed";
            description: string;
            camperId: number;
            itemId: number;
            flavorText: string;
            icon: string;
            category: "recipe" | "redeemable" | "cosmetic" | "container" | "seed" | "flower" | "consumable" | "card" | "food" | "relic" | "scroll" | "concoction" | "component";
            categoryTitle: string;
            preserveAfterUsing: boolean;
            canBeUsed: boolean;
            canUseInBotany: boolean;
            rarity: "relic" | "common" | "uncommon" | "rare";
            relatedConcoction?: "fourthDimensionalPlantFood" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "joyfultilizer" | "maxJoyfultilizer" | "quantumSeed" | "solidLiquidWanderingIce" | undefined;
        }, {
            value: number;
            name: string;
            slug: "silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed";
            description: string;
            camperId: number;
            itemId: number;
            flavorText: string;
            icon: string;
            category: "recipe" | "redeemable" | "cosmetic" | "container" | "seed" | "flower" | "consumable" | "card" | "food" | "relic" | "scroll" | "concoction" | "component";
            categoryTitle: string;
            preserveAfterUsing: boolean;
            canBeUsed: boolean;
            canUseInBotany: boolean;
            rarity: "relic" | "common" | "uncommon" | "rare";
            relatedConcoction?: "fourthDimensionalPlantFood" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "joyfultilizer" | "maxJoyfultilizer" | "quantumSeed" | "solidLiquidWanderingIce" | undefined;
        }>, "many">;
        badges: z.ZodArray<z.ZodEnum<["minecrafter", "trial1complete", "trial1Exalted", "trial2complete", "trial2Exalted", "lodgeLaunch", "botanyPropagator", "botanyGreenThumb", "botanyGrowTogether", "visitedSkyCafe", "sparkleFoot", "stellarvibe2022", "stellarvibe2024", "stellarvibe2024Max", "thunderstruck", "selfthunderstruck", "potluckParticipant", "potluckHero", "sousChef", "starboarded", "seeds100", "seeds500", "seeds1000", "waterOther100", "waterOther1000", "waterOther10000", "waterOther100000", "fruitHarvest", "trophyThistleHarvest"]>, "many">;
        flowers: z.ZodArray<z.ZodObject<{
            slug: z.ZodEnum<["astralDaisy", "voidIvy", "crystalOrchid", "bloodLily", "obsidianRose", "rainbowLotus", "dragonleaf", "wanderingIce", "lightningLotus", "smoulderingRose", "stardustBlossom", "celestialBulb", "celestialBoonflower", "astralMangoTree", "spectralPapayaTree", "ritualPumpkin", "acidBlossom", "trophyThistle", "joyroot", "joyblossom", "joybrushTangle"]>;
            id: z.ZodNumber;
            ownerId: z.ZodNumber;
            plantedAt: z.ZodNumber;
            waterLevel: z.ZodNumber;
            waterMissing: z.ZodNumber;
            waterRate: z.ZodNumber;
            ticksRemaining: z.ZodNumber;
            name: z.ZodString;
            description: z.ZodString;
            icon: z.ZodString;
            isGrowing: z.ZodBoolean;
            isWaterable: z.ZodBoolean;
            isDead: z.ZodBoolean;
            isReady: z.ZodBoolean;
        }, "strip", z.ZodTypeAny, {
            id: number;
            name: string;
            slug: "astralDaisy" | "voidIvy" | "crystalOrchid" | "bloodLily" | "obsidianRose" | "rainbowLotus" | "dragonleaf" | "wanderingIce" | "lightningLotus" | "smoulderingRose" | "stardustBlossom" | "celestialBulb" | "celestialBoonflower" | "astralMangoTree" | "spectralPapayaTree" | "ritualPumpkin" | "acidBlossom" | "trophyThistle" | "joyroot" | "joyblossom" | "joybrushTangle";
            description: string;
            isReady: boolean;
            icon: string;
            ownerId: number;
            plantedAt: number;
            waterLevel: number;
            waterMissing: number;
            waterRate: number;
            ticksRemaining: number;
            isGrowing: boolean;
            isWaterable: boolean;
            isDead: boolean;
        }, {
            id: number;
            name: string;
            slug: "astralDaisy" | "voidIvy" | "crystalOrchid" | "bloodLily" | "obsidianRose" | "rainbowLotus" | "dragonleaf" | "wanderingIce" | "lightningLotus" | "smoulderingRose" | "stardustBlossom" | "celestialBulb" | "celestialBoonflower" | "astralMangoTree" | "spectralPapayaTree" | "ritualPumpkin" | "acidBlossom" | "trophyThistle" | "joyroot" | "joyblossom" | "joybrushTangle";
            description: string;
            isReady: boolean;
            icon: string;
            ownerId: number;
            plantedAt: number;
            waterLevel: number;
            waterMissing: number;
            waterRate: number;
            ticksRemaining: number;
            isGrowing: boolean;
            isWaterable: boolean;
            isDead: boolean;
        }>, "many">;
        concoctions: z.ZodArray<z.ZodObject<{
            id: z.ZodNumber;
            camperId: z.ZodNumber;
            slug: z.ZodEnum<["liquidWanderingIce", "solidLiquidWanderingIce", "lightningInABottle", "soulWater", "silkwaterMist", "joyfultilizer", "maxJoyfultilizer", "quantumSeed", "fourthDimensionalPlantFood"]>;
            turnsBrewing: z.ZodNumber;
            state: z.ZodString;
            recipe: z.ZodObject<{
                slug: z.ZodEnum<["liquidWanderingIce", "solidLiquidWanderingIce", "lightningInABottle", "soulWater", "silkwaterMist", "joyfultilizer", "maxJoyfultilizer", "quantumSeed", "fourthDimensionalPlantFood"]>;
                title: z.ZodString;
                description: z.ZodString;
                image: z.ZodString;
                brewTime: z.ZodNumber;
                brewTimeLeniency: z.ZodNumber;
                ingredients: z.ZodArray<z.ZodTuple<[z.ZodEnum<["silkwaterJug", "silkwaterJugLarge", "cracklingRainmeter", "swirlingStormwrangler", "fourthDimensionalPlantFood", "tcGen1Beeatrice", "tcGen1Campfire", "tcGen1Chisel", "tcGen1Cloudsailor", "tcGen1Lodge", "tcGen1Murmus", "tcGen1MurmusFoil", "tcGen1Giant", "tcGen1LettersInFlight", "tcGen1SkyCafe", "tcGen1UnknownLunar", "tcGen1UnknownSolar", "tcGen1SecretSauce", "tcGen1GillroyFoil", "tcGen2DapperInPurple", "tcGen2DefinitelyFits", "tcGen2KnowsHowItWorks", "tcGen2Casual", "tcGen2Arcwild", "tcGen2Mysthull", "tcGen2Lelatoll", "tcGen2Skyhook", "tcGen2Goldspire", "tcGen2DukePepperbottom", "tcGen2StudioFoil", "randomScrap", "mermaidScale", "timerootBark", "spritzBottle", "livingIcicle", "stardustBag", "flaskSmall", "harvestedAstralDaisy", "harvestedVoidIvy", "harvestedCrystalOrchid", "harvestedBloodLily", "harvestedRainbowLotus", "harvestedDragonleaf", "harvestedAcidBlossom", "harvestedLightningLotus", "recipeLiquidWanderingIce", "recipeSolidLiquidWanderingIce", "recipeLightningInABottle", "recipeSoulWater", "recipeSilkwaterMist", "recipeQuantumSeed", "recipeFourthDimensionalPlantFood", "recipeBlankPlaceholder", "liquidWanderingIce", "soulWater", "silkwaterMist", "lightningInABottle", "crystalGeode", "treasureChest", "leafPile", "fallenStar", "frozenTreasureChest", "heartShapedBox", "shippingCrate", "giantsGift", "seedPouch", "tcBoosterPackGen1Common", "tcBoosterPackGen1Uncommon", "tcBoosterPackGen1Part2", "tcBoosterPackGen1Full", "tcBoosterPackGen2Drop1", "cosmicPinwheel", "discardedJacket", "trident", "goldLeaf", "doubloon", "harvestedObsidianRose", "harvestedSmoulderingRose", "harvestedRitualPumpkin", "harvestedTrophyThistle", "astralMango", "spectralPapaya", "mysticMorel", "otherworldlyOnion", "bansheeBerry", "secretSauce", "cosmicSocks", "compositionNotebook", "shatteredSpyglassLens", "shatteredSpyglassBody", "shatteredSpyglassEyepiece", "restoredSpyglass", "netheriteVoucher", "fatefulLoom", "bullhorn", "fleetingFeather", "celestialStone", "stellarvibePresentSmall2023", "stellarvibePresentMedium2023", "stellarvibePresentSmallGlowing2023", "stellarvibePresentMediumGlowing2023", "stellarvibePresent2024", "stellarvibePresentGlowing2024", "stellarvibePresent2024Max", "stellarvibePresent2024GlowingMax", "stellarvibePresentSmall", "stellarvibePresentSmallGlowing", "stellarvibePresentMedium", "stellarvibePresentMediumGlowing", "stellarvibePresentLarge", "stellarvibePresentLargeGlowing", "joyfultilizer", "maxJoyfultilizer", "joyrootSeed", "recipeJoyfultilizer", "recipeMaxJoyfultilizer", "scrollOfCultivation", "scrollOfGreaterCultivation", "quantumSeed", "mundaneSeed", "voidIvySeed", "crystalOrchidSeed", "bloodLilySeed", "obsidianRoseSeed", "rainbowLotusSeed", "dragonleafSeed", "smoulderingRoseSeed", "wanderingIceSeed", "stardustBlossomSeed", "celestialBulbSeed", "celestialBoonflowerSeed", "astralMangoTreeSeed", "spectralPapayaTreeSeed", "ritualPumpkinSeed", "trophyThistleSeed", "acidBlossomSeed"]>, z.ZodNumber], null>, "many">;
                result: z.ZodEnum<["silkwaterJug", "silkwaterJugLarge", "cracklingRainmeter", "swirlingStormwrangler", "fourthDimensionalPlantFood", "tcGen1Beeatrice", "tcGen1Campfire", "tcGen1Chisel", "tcGen1Cloudsailor", "tcGen1Lodge", "tcGen1Murmus", "tcGen1MurmusFoil", "tcGen1Giant", "tcGen1LettersInFlight", "tcGen1SkyCafe", "tcGen1UnknownLunar", "tcGen1UnknownSolar", "tcGen1SecretSauce", "tcGen1GillroyFoil", "tcGen2DapperInPurple", "tcGen2DefinitelyFits", "tcGen2KnowsHowItWorks", "tcGen2Casual", "tcGen2Arcwild", "tcGen2Mysthull", "tcGen2Lelatoll", "tcGen2Skyhook", "tcGen2Goldspire", "tcGen2DukePepperbottom", "tcGen2StudioFoil", "randomScrap", "mermaidScale", "timerootBark", "spritzBottle", "livingIcicle", "stardustBag", "flaskSmall", "harvestedAstralDaisy", "harvestedVoidIvy", "harvestedCrystalOrchid", "harvestedBloodLily", "harvestedRainbowLotus", "harvestedDragonleaf", "harvestedAcidBlossom", "harvestedLightningLotus", "recipeLiquidWanderingIce", "recipeSolidLiquidWanderingIce", "recipeLightningInABottle", "recipeSoulWater", "recipeSilkwaterMist", "recipeQuantumSeed", "recipeFourthDimensionalPlantFood", "recipeBlankPlaceholder", "liquidWanderingIce", "soulWater", "silkwaterMist", "lightningInABottle", "crystalGeode", "treasureChest", "leafPile", "fallenStar", "frozenTreasureChest", "heartShapedBox", "shippingCrate", "giantsGift", "seedPouch", "tcBoosterPackGen1Common", "tcBoosterPackGen1Uncommon", "tcBoosterPackGen1Part2", "tcBoosterPackGen1Full", "tcBoosterPackGen2Drop1", "cosmicPinwheel", "discardedJacket", "trident", "goldLeaf", "doubloon", "harvestedObsidianRose", "harvestedSmoulderingRose", "harvestedRitualPumpkin", "harvestedTrophyThistle", "astralMango", "spectralPapaya", "mysticMorel", "otherworldlyOnion", "bansheeBerry", "secretSauce", "cosmicSocks", "compositionNotebook", "shatteredSpyglassLens", "shatteredSpyglassBody", "shatteredSpyglassEyepiece", "restoredSpyglass", "netheriteVoucher", "fatefulLoom", "bullhorn", "fleetingFeather", "celestialStone", "stellarvibePresentSmall2023", "stellarvibePresentMedium2023", "stellarvibePresentSmallGlowing2023", "stellarvibePresentMediumGlowing2023", "stellarvibePresent2024", "stellarvibePresentGlowing2024", "stellarvibePresent2024Max", "stellarvibePresent2024GlowingMax", "stellarvibePresentSmall", "stellarvibePresentSmallGlowing", "stellarvibePresentMedium", "stellarvibePresentMediumGlowing", "stellarvibePresentLarge", "stellarvibePresentLargeGlowing", "joyfultilizer", "maxJoyfultilizer", "joyrootSeed", "recipeJoyfultilizer", "recipeMaxJoyfultilizer", "scrollOfCultivation", "scrollOfGreaterCultivation", "quantumSeed", "mundaneSeed", "voidIvySeed", "crystalOrchidSeed", "bloodLilySeed", "obsidianRoseSeed", "rainbowLotusSeed", "dragonleafSeed", "smoulderingRoseSeed", "wanderingIceSeed", "stardustBlossomSeed", "celestialBulbSeed", "celestialBoonflowerSeed", "astralMangoTreeSeed", "spectralPapayaTreeSeed", "ritualPumpkinSeed", "trophyThistleSeed", "acidBlossomSeed"]>;
            }, "strip", z.ZodTypeAny, {
                slug: "fourthDimensionalPlantFood" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "joyfultilizer" | "maxJoyfultilizer" | "quantumSeed" | "solidLiquidWanderingIce";
                title: string;
                description: string;
                image: string;
                brewTime: number;
                brewTimeLeniency: number;
                ingredients: ["silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed", number][];
                result: "silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed";
            }, {
                slug: "fourthDimensionalPlantFood" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "joyfultilizer" | "maxJoyfultilizer" | "quantumSeed" | "solidLiquidWanderingIce";
                title: string;
                description: string;
                image: string;
                brewTime: number;
                brewTimeLeniency: number;
                ingredients: ["silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed", number][];
                result: "silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed";
            }>;
            isReady: z.ZodBoolean;
            autoStop: z.ZodBoolean;
        }, "strip", z.ZodTypeAny, {
            id: number;
            slug: "fourthDimensionalPlantFood" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "joyfultilizer" | "maxJoyfultilizer" | "quantumSeed" | "solidLiquidWanderingIce";
            camperId: number;
            turnsBrewing: number;
            state: string;
            recipe: {
                slug: "fourthDimensionalPlantFood" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "joyfultilizer" | "maxJoyfultilizer" | "quantumSeed" | "solidLiquidWanderingIce";
                title: string;
                description: string;
                image: string;
                brewTime: number;
                brewTimeLeniency: number;
                ingredients: ["silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed", number][];
                result: "silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed";
            };
            isReady: boolean;
            autoStop: boolean;
        }, {
            id: number;
            slug: "fourthDimensionalPlantFood" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "joyfultilizer" | "maxJoyfultilizer" | "quantumSeed" | "solidLiquidWanderingIce";
            camperId: number;
            turnsBrewing: number;
            state: string;
            recipe: {
                slug: "fourthDimensionalPlantFood" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "joyfultilizer" | "maxJoyfultilizer" | "quantumSeed" | "solidLiquidWanderingIce";
                title: string;
                description: string;
                image: string;
                brewTime: number;
                brewTimeLeniency: number;
                ingredients: ["silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed", number][];
                result: "silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed";
            };
            isReady: boolean;
            autoStop: boolean;
        }>, "many">;
        recipes: z.ZodArray<z.ZodObject<{
            slug: z.ZodEnum<["liquidWanderingIce", "solidLiquidWanderingIce", "lightningInABottle", "soulWater", "silkwaterMist", "joyfultilizer", "maxJoyfultilizer", "quantumSeed", "fourthDimensionalPlantFood"]>;
            title: z.ZodString;
            description: z.ZodString;
            image: z.ZodString;
            brewTime: z.ZodNumber;
            brewTimeLeniency: z.ZodNumber;
            ingredients: z.ZodArray<z.ZodTuple<[z.ZodEnum<["silkwaterJug", "silkwaterJugLarge", "cracklingRainmeter", "swirlingStormwrangler", "fourthDimensionalPlantFood", "tcGen1Beeatrice", "tcGen1Campfire", "tcGen1Chisel", "tcGen1Cloudsailor", "tcGen1Lodge", "tcGen1Murmus", "tcGen1MurmusFoil", "tcGen1Giant", "tcGen1LettersInFlight", "tcGen1SkyCafe", "tcGen1UnknownLunar", "tcGen1UnknownSolar", "tcGen1SecretSauce", "tcGen1GillroyFoil", "tcGen2DapperInPurple", "tcGen2DefinitelyFits", "tcGen2KnowsHowItWorks", "tcGen2Casual", "tcGen2Arcwild", "tcGen2Mysthull", "tcGen2Lelatoll", "tcGen2Skyhook", "tcGen2Goldspire", "tcGen2DukePepperbottom", "tcGen2StudioFoil", "randomScrap", "mermaidScale", "timerootBark", "spritzBottle", "livingIcicle", "stardustBag", "flaskSmall", "harvestedAstralDaisy", "harvestedVoidIvy", "harvestedCrystalOrchid", "harvestedBloodLily", "harvestedRainbowLotus", "harvestedDragonleaf", "harvestedAcidBlossom", "harvestedLightningLotus", "recipeLiquidWanderingIce", "recipeSolidLiquidWanderingIce", "recipeLightningInABottle", "recipeSoulWater", "recipeSilkwaterMist", "recipeQuantumSeed", "recipeFourthDimensionalPlantFood", "recipeBlankPlaceholder", "liquidWanderingIce", "soulWater", "silkwaterMist", "lightningInABottle", "crystalGeode", "treasureChest", "leafPile", "fallenStar", "frozenTreasureChest", "heartShapedBox", "shippingCrate", "giantsGift", "seedPouch", "tcBoosterPackGen1Common", "tcBoosterPackGen1Uncommon", "tcBoosterPackGen1Part2", "tcBoosterPackGen1Full", "tcBoosterPackGen2Drop1", "cosmicPinwheel", "discardedJacket", "trident", "goldLeaf", "doubloon", "harvestedObsidianRose", "harvestedSmoulderingRose", "harvestedRitualPumpkin", "harvestedTrophyThistle", "astralMango", "spectralPapaya", "mysticMorel", "otherworldlyOnion", "bansheeBerry", "secretSauce", "cosmicSocks", "compositionNotebook", "shatteredSpyglassLens", "shatteredSpyglassBody", "shatteredSpyglassEyepiece", "restoredSpyglass", "netheriteVoucher", "fatefulLoom", "bullhorn", "fleetingFeather", "celestialStone", "stellarvibePresentSmall2023", "stellarvibePresentMedium2023", "stellarvibePresentSmallGlowing2023", "stellarvibePresentMediumGlowing2023", "stellarvibePresent2024", "stellarvibePresentGlowing2024", "stellarvibePresent2024Max", "stellarvibePresent2024GlowingMax", "stellarvibePresentSmall", "stellarvibePresentSmallGlowing", "stellarvibePresentMedium", "stellarvibePresentMediumGlowing", "stellarvibePresentLarge", "stellarvibePresentLargeGlowing", "joyfultilizer", "maxJoyfultilizer", "joyrootSeed", "recipeJoyfultilizer", "recipeMaxJoyfultilizer", "scrollOfCultivation", "scrollOfGreaterCultivation", "quantumSeed", "mundaneSeed", "voidIvySeed", "crystalOrchidSeed", "bloodLilySeed", "obsidianRoseSeed", "rainbowLotusSeed", "dragonleafSeed", "smoulderingRoseSeed", "wanderingIceSeed", "stardustBlossomSeed", "celestialBulbSeed", "celestialBoonflowerSeed", "astralMangoTreeSeed", "spectralPapayaTreeSeed", "ritualPumpkinSeed", "trophyThistleSeed", "acidBlossomSeed"]>, z.ZodNumber], null>, "many">;
            result: z.ZodEnum<["silkwaterJug", "silkwaterJugLarge", "cracklingRainmeter", "swirlingStormwrangler", "fourthDimensionalPlantFood", "tcGen1Beeatrice", "tcGen1Campfire", "tcGen1Chisel", "tcGen1Cloudsailor", "tcGen1Lodge", "tcGen1Murmus", "tcGen1MurmusFoil", "tcGen1Giant", "tcGen1LettersInFlight", "tcGen1SkyCafe", "tcGen1UnknownLunar", "tcGen1UnknownSolar", "tcGen1SecretSauce", "tcGen1GillroyFoil", "tcGen2DapperInPurple", "tcGen2DefinitelyFits", "tcGen2KnowsHowItWorks", "tcGen2Casual", "tcGen2Arcwild", "tcGen2Mysthull", "tcGen2Lelatoll", "tcGen2Skyhook", "tcGen2Goldspire", "tcGen2DukePepperbottom", "tcGen2StudioFoil", "randomScrap", "mermaidScale", "timerootBark", "spritzBottle", "livingIcicle", "stardustBag", "flaskSmall", "harvestedAstralDaisy", "harvestedVoidIvy", "harvestedCrystalOrchid", "harvestedBloodLily", "harvestedRainbowLotus", "harvestedDragonleaf", "harvestedAcidBlossom", "harvestedLightningLotus", "recipeLiquidWanderingIce", "recipeSolidLiquidWanderingIce", "recipeLightningInABottle", "recipeSoulWater", "recipeSilkwaterMist", "recipeQuantumSeed", "recipeFourthDimensionalPlantFood", "recipeBlankPlaceholder", "liquidWanderingIce", "soulWater", "silkwaterMist", "lightningInABottle", "crystalGeode", "treasureChest", "leafPile", "fallenStar", "frozenTreasureChest", "heartShapedBox", "shippingCrate", "giantsGift", "seedPouch", "tcBoosterPackGen1Common", "tcBoosterPackGen1Uncommon", "tcBoosterPackGen1Part2", "tcBoosterPackGen1Full", "tcBoosterPackGen2Drop1", "cosmicPinwheel", "discardedJacket", "trident", "goldLeaf", "doubloon", "harvestedObsidianRose", "harvestedSmoulderingRose", "harvestedRitualPumpkin", "harvestedTrophyThistle", "astralMango", "spectralPapaya", "mysticMorel", "otherworldlyOnion", "bansheeBerry", "secretSauce", "cosmicSocks", "compositionNotebook", "shatteredSpyglassLens", "shatteredSpyglassBody", "shatteredSpyglassEyepiece", "restoredSpyglass", "netheriteVoucher", "fatefulLoom", "bullhorn", "fleetingFeather", "celestialStone", "stellarvibePresentSmall2023", "stellarvibePresentMedium2023", "stellarvibePresentSmallGlowing2023", "stellarvibePresentMediumGlowing2023", "stellarvibePresent2024", "stellarvibePresentGlowing2024", "stellarvibePresent2024Max", "stellarvibePresent2024GlowingMax", "stellarvibePresentSmall", "stellarvibePresentSmallGlowing", "stellarvibePresentMedium", "stellarvibePresentMediumGlowing", "stellarvibePresentLarge", "stellarvibePresentLargeGlowing", "joyfultilizer", "maxJoyfultilizer", "joyrootSeed", "recipeJoyfultilizer", "recipeMaxJoyfultilizer", "scrollOfCultivation", "scrollOfGreaterCultivation", "quantumSeed", "mundaneSeed", "voidIvySeed", "crystalOrchidSeed", "bloodLilySeed", "obsidianRoseSeed", "rainbowLotusSeed", "dragonleafSeed", "smoulderingRoseSeed", "wanderingIceSeed", "stardustBlossomSeed", "celestialBulbSeed", "celestialBoonflowerSeed", "astralMangoTreeSeed", "spectralPapayaTreeSeed", "ritualPumpkinSeed", "trophyThistleSeed", "acidBlossomSeed"]>;
        }, "strip", z.ZodTypeAny, {
            slug: "fourthDimensionalPlantFood" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "joyfultilizer" | "maxJoyfultilizer" | "quantumSeed" | "solidLiquidWanderingIce";
            title: string;
            description: string;
            image: string;
            brewTime: number;
            brewTimeLeniency: number;
            ingredients: ["silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed", number][];
            result: "silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed";
        }, {
            slug: "fourthDimensionalPlantFood" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "joyfultilizer" | "maxJoyfultilizer" | "quantumSeed" | "solidLiquidWanderingIce";
            title: string;
            description: string;
            image: string;
            brewTime: number;
            brewTimeLeniency: number;
            ingredients: ["silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed", number][];
            result: "silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed";
        }>, "many">;
    }, "strip", z.ZodTypeAny, {
        camperId: number;
        sheetId: number;
        resources: {
            conduits: number;
            silkwater: number;
        };
        inventory: {
            value: number;
            name: string;
            slug: "silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed";
            description: string;
            camperId: number;
            itemId: number;
            flavorText: string;
            icon: string;
            category: "recipe" | "redeemable" | "cosmetic" | "container" | "seed" | "flower" | "consumable" | "card" | "food" | "relic" | "scroll" | "concoction" | "component";
            categoryTitle: string;
            preserveAfterUsing: boolean;
            canBeUsed: boolean;
            canUseInBotany: boolean;
            rarity: "relic" | "common" | "uncommon" | "rare";
            relatedConcoction?: "fourthDimensionalPlantFood" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "joyfultilizer" | "maxJoyfultilizer" | "quantumSeed" | "solidLiquidWanderingIce" | undefined;
        }[];
        badges: ("minecrafter" | "trial1complete" | "trial1Exalted" | "trial2complete" | "trial2Exalted" | "lodgeLaunch" | "botanyPropagator" | "botanyGreenThumb" | "botanyGrowTogether" | "visitedSkyCafe" | "sparkleFoot" | "stellarvibe2022" | "stellarvibe2024" | "stellarvibe2024Max" | "thunderstruck" | "selfthunderstruck" | "potluckParticipant" | "potluckHero" | "sousChef" | "starboarded" | "seeds100" | "seeds500" | "seeds1000" | "waterOther100" | "waterOther1000" | "waterOther10000" | "waterOther100000" | "fruitHarvest" | "trophyThistleHarvest")[];
        flowers: {
            id: number;
            name: string;
            slug: "astralDaisy" | "voidIvy" | "crystalOrchid" | "bloodLily" | "obsidianRose" | "rainbowLotus" | "dragonleaf" | "wanderingIce" | "lightningLotus" | "smoulderingRose" | "stardustBlossom" | "celestialBulb" | "celestialBoonflower" | "astralMangoTree" | "spectralPapayaTree" | "ritualPumpkin" | "acidBlossom" | "trophyThistle" | "joyroot" | "joyblossom" | "joybrushTangle";
            description: string;
            isReady: boolean;
            icon: string;
            ownerId: number;
            plantedAt: number;
            waterLevel: number;
            waterMissing: number;
            waterRate: number;
            ticksRemaining: number;
            isGrowing: boolean;
            isWaterable: boolean;
            isDead: boolean;
        }[];
        concoctions: {
            id: number;
            slug: "fourthDimensionalPlantFood" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "joyfultilizer" | "maxJoyfultilizer" | "quantumSeed" | "solidLiquidWanderingIce";
            camperId: number;
            turnsBrewing: number;
            state: string;
            recipe: {
                slug: "fourthDimensionalPlantFood" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "joyfultilizer" | "maxJoyfultilizer" | "quantumSeed" | "solidLiquidWanderingIce";
                title: string;
                description: string;
                image: string;
                brewTime: number;
                brewTimeLeniency: number;
                ingredients: ["silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed", number][];
                result: "silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed";
            };
            isReady: boolean;
            autoStop: boolean;
        }[];
        recipes: {
            slug: "fourthDimensionalPlantFood" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "joyfultilizer" | "maxJoyfultilizer" | "quantumSeed" | "solidLiquidWanderingIce";
            title: string;
            description: string;
            image: string;
            brewTime: number;
            brewTimeLeniency: number;
            ingredients: ["silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed", number][];
            result: "silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed";
        }[];
    }, {
        camperId: number;
        sheetId: number;
        resources: {
            conduits: number;
            silkwater: number;
        };
        inventory: {
            value: number;
            name: string;
            slug: "silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed";
            description: string;
            camperId: number;
            itemId: number;
            flavorText: string;
            icon: string;
            category: "recipe" | "redeemable" | "cosmetic" | "container" | "seed" | "flower" | "consumable" | "card" | "food" | "relic" | "scroll" | "concoction" | "component";
            categoryTitle: string;
            preserveAfterUsing: boolean;
            canBeUsed: boolean;
            canUseInBotany: boolean;
            rarity: "relic" | "common" | "uncommon" | "rare";
            relatedConcoction?: "fourthDimensionalPlantFood" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "joyfultilizer" | "maxJoyfultilizer" | "quantumSeed" | "solidLiquidWanderingIce" | undefined;
        }[];
        badges: ("minecrafter" | "trial1complete" | "trial1Exalted" | "trial2complete" | "trial2Exalted" | "lodgeLaunch" | "botanyPropagator" | "botanyGreenThumb" | "botanyGrowTogether" | "visitedSkyCafe" | "sparkleFoot" | "stellarvibe2022" | "stellarvibe2024" | "stellarvibe2024Max" | "thunderstruck" | "selfthunderstruck" | "potluckParticipant" | "potluckHero" | "sousChef" | "starboarded" | "seeds100" | "seeds500" | "seeds1000" | "waterOther100" | "waterOther1000" | "waterOther10000" | "waterOther100000" | "fruitHarvest" | "trophyThistleHarvest")[];
        flowers: {
            id: number;
            name: string;
            slug: "astralDaisy" | "voidIvy" | "crystalOrchid" | "bloodLily" | "obsidianRose" | "rainbowLotus" | "dragonleaf" | "wanderingIce" | "lightningLotus" | "smoulderingRose" | "stardustBlossom" | "celestialBulb" | "celestialBoonflower" | "astralMangoTree" | "spectralPapayaTree" | "ritualPumpkin" | "acidBlossom" | "trophyThistle" | "joyroot" | "joyblossom" | "joybrushTangle";
            description: string;
            isReady: boolean;
            icon: string;
            ownerId: number;
            plantedAt: number;
            waterLevel: number;
            waterMissing: number;
            waterRate: number;
            ticksRemaining: number;
            isGrowing: boolean;
            isWaterable: boolean;
            isDead: boolean;
        }[];
        concoctions: {
            id: number;
            slug: "fourthDimensionalPlantFood" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "joyfultilizer" | "maxJoyfultilizer" | "quantumSeed" | "solidLiquidWanderingIce";
            camperId: number;
            turnsBrewing: number;
            state: string;
            recipe: {
                slug: "fourthDimensionalPlantFood" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "joyfultilizer" | "maxJoyfultilizer" | "quantumSeed" | "solidLiquidWanderingIce";
                title: string;
                description: string;
                image: string;
                brewTime: number;
                brewTimeLeniency: number;
                ingredients: ["silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed", number][];
                result: "silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed";
            };
            isReady: boolean;
            autoStop: boolean;
        }[];
        recipes: {
            slug: "fourthDimensionalPlantFood" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "joyfultilizer" | "maxJoyfultilizer" | "quantumSeed" | "solidLiquidWanderingIce";
            title: string;
            description: string;
            image: string;
            brewTime: number;
            brewTimeLeniency: number;
            ingredients: ["silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed", number][];
            result: "silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed";
        }[];
    }>;
    prose: z.ZodNullable<z.ZodString>;
    mastodon: z.ZodNullable<z.ZodString>;
    twitch: z.ZodNullable<z.ZodReadonly<z.ZodObject<{
        twitchIdentityId: z.ZodNumber;
        twitchId: z.ZodString;
        camper: z.ZodNullable<z.ZodObject<{
            id: z.ZodNumber;
            name: z.ZodBranded<z.ZodString, "CamperDisplayName">;
            handle: z.ZodBranded<z.ZodString, "CamperHandle">;
            color: z.ZodNullable<z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">>;
            pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
            avatarUrl: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
        }, "strip", z.ZodTypeAny, {
            color: (string & z.BRAND<"ColorString">) | null;
            handle: string & z.BRAND<"CamperHandle">;
            pronouns: (string & z.BRAND<"PronounString">) | null;
            id: number;
            name: string & z.BRAND<"CamperDisplayName">;
            avatarUrl: (string & z.BRAND<"URLString">) | null;
        }, {
            color: string | null;
            handle: string;
            pronouns: string | null;
            id: number;
            name: string;
            avatarUrl: string | null;
        }>>;
        twitchHandle: z.ZodString;
        twitchDisplayName: z.ZodString;
        twitchNameColor: z.ZodString;
        twitchChannelURL: z.ZodString;
        info: z.ZodObject<{
            name: z.ZodString;
            color: z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">;
            pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
            avatarURL: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
        }, "strip", z.ZodTypeAny, {
            color: string & z.BRAND<"ColorString">;
            pronouns: (string & z.BRAND<"PronounString">) | null;
            name: string;
            avatarURL: (string & z.BRAND<"URLString">) | null;
        }, {
            color: string;
            pronouns: string | null;
            name: string;
            avatarURL: string | null;
        }>;
    }, "strip", z.ZodTypeAny, {
        camper: {
            color: (string & z.BRAND<"ColorString">) | null;
            handle: string & z.BRAND<"CamperHandle">;
            pronouns: (string & z.BRAND<"PronounString">) | null;
            id: number;
            name: string & z.BRAND<"CamperDisplayName">;
            avatarUrl: (string & z.BRAND<"URLString">) | null;
        } | null;
        twitchIdentityId: number;
        twitchId: string;
        twitchHandle: string;
        twitchDisplayName: string;
        twitchNameColor: string;
        twitchChannelURL: string;
        info: {
            color: string & z.BRAND<"ColorString">;
            pronouns: (string & z.BRAND<"PronounString">) | null;
            name: string;
            avatarURL: (string & z.BRAND<"URLString">) | null;
        };
    }, {
        camper: {
            color: string | null;
            handle: string;
            pronouns: string | null;
            id: number;
            name: string;
            avatarUrl: string | null;
        } | null;
        twitchIdentityId: number;
        twitchId: string;
        twitchHandle: string;
        twitchDisplayName: string;
        twitchNameColor: string;
        twitchChannelURL: string;
        info: {
            color: string;
            pronouns: string | null;
            name: string;
            avatarURL: string | null;
        };
    }>>>;
    discord: z.ZodNullable<z.ZodObject<{
        camper: z.ZodObject<{
            id: z.ZodNumber;
            name: z.ZodBranded<z.ZodString, "CamperDisplayName">;
            handle: z.ZodBranded<z.ZodString, "CamperHandle">;
            color: z.ZodNullable<z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">>;
            pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
            avatarUrl: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
        }, "strip", z.ZodTypeAny, {
            color: (string & z.BRAND<"ColorString">) | null;
            handle: string & z.BRAND<"CamperHandle">;
            pronouns: (string & z.BRAND<"PronounString">) | null;
            id: number;
            name: string & z.BRAND<"CamperDisplayName">;
            avatarUrl: (string & z.BRAND<"URLString">) | null;
        }, {
            color: string | null;
            handle: string;
            pronouns: string | null;
            id: number;
            name: string;
            avatarUrl: string | null;
        }>;
        discordId: z.ZodString;
        discordUsername: z.ZodString;
        discordDisplayName: z.ZodString;
        discordAvatar: z.ZodBranded<z.ZodString, "URLString">;
    }, "strip", z.ZodTypeAny, {
        camper: {
            color: (string & z.BRAND<"ColorString">) | null;
            handle: string & z.BRAND<"CamperHandle">;
            pronouns: (string & z.BRAND<"PronounString">) | null;
            id: number;
            name: string & z.BRAND<"CamperDisplayName">;
            avatarUrl: (string & z.BRAND<"URLString">) | null;
        };
        discordId: string;
        discordUsername: string;
        discordDisplayName: string;
        discordAvatar: string & z.BRAND<"URLString">;
    }, {
        camper: {
            color: string | null;
            handle: string;
            pronouns: string | null;
            id: number;
            name: string;
            avatarUrl: string | null;
        };
        discordId: string;
        discordUsername: string;
        discordDisplayName: string;
        discordAvatar: string;
    }>>;
}, "strip", z.ZodTypeAny, {
    camper: Readonly<{
        color: (string & z.BRAND<"ColorString">) | null;
        allowPings: boolean;
        syncDiscordDisplayName: boolean;
        tagline: (string & z.BRAND<"TaglineString">) | null;
        handle: string & z.BRAND<"CamperHandle">;
        pronouns: (string & z.BRAND<"PronounString">) | null;
        id: number;
        name: string & z.BRAND<"CamperDisplayName">;
        avatarUrl: (string & z.BRAND<"URLString">) | null;
        websiteUrl: (string & z.BRAND<"URLString">) | null;
        createdAt: string & z.BRAND<"TimestampString">;
        lastInteraction: string & z.BRAND<"TimestampString">;
        role: import("./core").CamperAccessLevel;
    }>;
    sheet: {
        camperId: number;
        sheetId: number;
        resources: {
            conduits: number;
            silkwater: number;
        };
        inventory: {
            value: number;
            name: string;
            slug: "silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed";
            description: string;
            camperId: number;
            itemId: number;
            flavorText: string;
            icon: string;
            category: "recipe" | "redeemable" | "cosmetic" | "container" | "seed" | "flower" | "consumable" | "card" | "food" | "relic" | "scroll" | "concoction" | "component";
            categoryTitle: string;
            preserveAfterUsing: boolean;
            canBeUsed: boolean;
            canUseInBotany: boolean;
            rarity: "relic" | "common" | "uncommon" | "rare";
            relatedConcoction?: "fourthDimensionalPlantFood" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "joyfultilizer" | "maxJoyfultilizer" | "quantumSeed" | "solidLiquidWanderingIce" | undefined;
        }[];
        badges: ("minecrafter" | "trial1complete" | "trial1Exalted" | "trial2complete" | "trial2Exalted" | "lodgeLaunch" | "botanyPropagator" | "botanyGreenThumb" | "botanyGrowTogether" | "visitedSkyCafe" | "sparkleFoot" | "stellarvibe2022" | "stellarvibe2024" | "stellarvibe2024Max" | "thunderstruck" | "selfthunderstruck" | "potluckParticipant" | "potluckHero" | "sousChef" | "starboarded" | "seeds100" | "seeds500" | "seeds1000" | "waterOther100" | "waterOther1000" | "waterOther10000" | "waterOther100000" | "fruitHarvest" | "trophyThistleHarvest")[];
        flowers: {
            id: number;
            name: string;
            slug: "astralDaisy" | "voidIvy" | "crystalOrchid" | "bloodLily" | "obsidianRose" | "rainbowLotus" | "dragonleaf" | "wanderingIce" | "lightningLotus" | "smoulderingRose" | "stardustBlossom" | "celestialBulb" | "celestialBoonflower" | "astralMangoTree" | "spectralPapayaTree" | "ritualPumpkin" | "acidBlossom" | "trophyThistle" | "joyroot" | "joyblossom" | "joybrushTangle";
            description: string;
            isReady: boolean;
            icon: string;
            ownerId: number;
            plantedAt: number;
            waterLevel: number;
            waterMissing: number;
            waterRate: number;
            ticksRemaining: number;
            isGrowing: boolean;
            isWaterable: boolean;
            isDead: boolean;
        }[];
        concoctions: {
            id: number;
            slug: "fourthDimensionalPlantFood" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "joyfultilizer" | "maxJoyfultilizer" | "quantumSeed" | "solidLiquidWanderingIce";
            camperId: number;
            turnsBrewing: number;
            state: string;
            recipe: {
                slug: "fourthDimensionalPlantFood" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "joyfultilizer" | "maxJoyfultilizer" | "quantumSeed" | "solidLiquidWanderingIce";
                title: string;
                description: string;
                image: string;
                brewTime: number;
                brewTimeLeniency: number;
                ingredients: ["silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed", number][];
                result: "silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed";
            };
            isReady: boolean;
            autoStop: boolean;
        }[];
        recipes: {
            slug: "fourthDimensionalPlantFood" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "joyfultilizer" | "maxJoyfultilizer" | "quantumSeed" | "solidLiquidWanderingIce";
            title: string;
            description: string;
            image: string;
            brewTime: number;
            brewTimeLeniency: number;
            ingredients: ["silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed", number][];
            result: "silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed";
        }[];
    };
    prose: string | null;
    mastodon: string | null;
    twitch: Readonly<{
        camper: {
            color: (string & z.BRAND<"ColorString">) | null;
            handle: string & z.BRAND<"CamperHandle">;
            pronouns: (string & z.BRAND<"PronounString">) | null;
            id: number;
            name: string & z.BRAND<"CamperDisplayName">;
            avatarUrl: (string & z.BRAND<"URLString">) | null;
        } | null;
        twitchIdentityId: number;
        twitchId: string;
        twitchHandle: string;
        twitchDisplayName: string;
        twitchNameColor: string;
        twitchChannelURL: string;
        info: {
            color: string & z.BRAND<"ColorString">;
            pronouns: (string & z.BRAND<"PronounString">) | null;
            name: string;
            avatarURL: (string & z.BRAND<"URLString">) | null;
        };
    }> | null;
    discord: {
        camper: {
            color: (string & z.BRAND<"ColorString">) | null;
            handle: string & z.BRAND<"CamperHandle">;
            pronouns: (string & z.BRAND<"PronounString">) | null;
            id: number;
            name: string & z.BRAND<"CamperDisplayName">;
            avatarUrl: (string & z.BRAND<"URLString">) | null;
        };
        discordId: string;
        discordUsername: string;
        discordDisplayName: string;
        discordAvatar: string & z.BRAND<"URLString">;
    } | null;
}, {
    camper: Readonly<{
        color: string | null;
        allowPings: boolean;
        syncDiscordDisplayName: boolean;
        tagline: string | null;
        handle: string;
        pronouns: string | null;
        id: number;
        name: string;
        avatarUrl: string | null;
        websiteUrl: string | null;
        createdAt: string;
        lastInteraction: string;
        role: import("./core").CamperAccessLevel;
    }>;
    sheet: {
        camperId: number;
        sheetId: number;
        resources: {
            conduits: number;
            silkwater: number;
        };
        inventory: {
            value: number;
            name: string;
            slug: "silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed";
            description: string;
            camperId: number;
            itemId: number;
            flavorText: string;
            icon: string;
            category: "recipe" | "redeemable" | "cosmetic" | "container" | "seed" | "flower" | "consumable" | "card" | "food" | "relic" | "scroll" | "concoction" | "component";
            categoryTitle: string;
            preserveAfterUsing: boolean;
            canBeUsed: boolean;
            canUseInBotany: boolean;
            rarity: "relic" | "common" | "uncommon" | "rare";
            relatedConcoction?: "fourthDimensionalPlantFood" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "joyfultilizer" | "maxJoyfultilizer" | "quantumSeed" | "solidLiquidWanderingIce" | undefined;
        }[];
        badges: ("minecrafter" | "trial1complete" | "trial1Exalted" | "trial2complete" | "trial2Exalted" | "lodgeLaunch" | "botanyPropagator" | "botanyGreenThumb" | "botanyGrowTogether" | "visitedSkyCafe" | "sparkleFoot" | "stellarvibe2022" | "stellarvibe2024" | "stellarvibe2024Max" | "thunderstruck" | "selfthunderstruck" | "potluckParticipant" | "potluckHero" | "sousChef" | "starboarded" | "seeds100" | "seeds500" | "seeds1000" | "waterOther100" | "waterOther1000" | "waterOther10000" | "waterOther100000" | "fruitHarvest" | "trophyThistleHarvest")[];
        flowers: {
            id: number;
            name: string;
            slug: "astralDaisy" | "voidIvy" | "crystalOrchid" | "bloodLily" | "obsidianRose" | "rainbowLotus" | "dragonleaf" | "wanderingIce" | "lightningLotus" | "smoulderingRose" | "stardustBlossom" | "celestialBulb" | "celestialBoonflower" | "astralMangoTree" | "spectralPapayaTree" | "ritualPumpkin" | "acidBlossom" | "trophyThistle" | "joyroot" | "joyblossom" | "joybrushTangle";
            description: string;
            isReady: boolean;
            icon: string;
            ownerId: number;
            plantedAt: number;
            waterLevel: number;
            waterMissing: number;
            waterRate: number;
            ticksRemaining: number;
            isGrowing: boolean;
            isWaterable: boolean;
            isDead: boolean;
        }[];
        concoctions: {
            id: number;
            slug: "fourthDimensionalPlantFood" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "joyfultilizer" | "maxJoyfultilizer" | "quantumSeed" | "solidLiquidWanderingIce";
            camperId: number;
            turnsBrewing: number;
            state: string;
            recipe: {
                slug: "fourthDimensionalPlantFood" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "joyfultilizer" | "maxJoyfultilizer" | "quantumSeed" | "solidLiquidWanderingIce";
                title: string;
                description: string;
                image: string;
                brewTime: number;
                brewTimeLeniency: number;
                ingredients: ["silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed", number][];
                result: "silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed";
            };
            isReady: boolean;
            autoStop: boolean;
        }[];
        recipes: {
            slug: "fourthDimensionalPlantFood" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "joyfultilizer" | "maxJoyfultilizer" | "quantumSeed" | "solidLiquidWanderingIce";
            title: string;
            description: string;
            image: string;
            brewTime: number;
            brewTimeLeniency: number;
            ingredients: ["silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed", number][];
            result: "silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed";
        }[];
    };
    prose: string | null;
    mastodon: string | null;
    twitch: Readonly<{
        camper: {
            color: string | null;
            handle: string;
            pronouns: string | null;
            id: number;
            name: string;
            avatarUrl: string | null;
        } | null;
        twitchIdentityId: number;
        twitchId: string;
        twitchHandle: string;
        twitchDisplayName: string;
        twitchNameColor: string;
        twitchChannelURL: string;
        info: {
            color: string;
            pronouns: string | null;
            name: string;
            avatarURL: string | null;
        };
    }> | null;
    discord: {
        camper: {
            color: string | null;
            handle: string;
            pronouns: string | null;
            id: number;
            name: string;
            avatarUrl: string | null;
        };
        discordId: string;
        discordUsername: string;
        discordDisplayName: string;
        discordAvatar: string;
    } | null;
}>;
export type LodgeProfile = z.infer<typeof LodgeProfileSchema>;
export declare const LodgeCommonPayloadSchema: z.ZodObject<{
    camper: z.ZodReadonly<z.ZodObject<z.objectUtil.extendShape<{
        id: z.ZodNumber;
        name: z.ZodBranded<z.ZodString, "CamperDisplayName">;
        handle: z.ZodBranded<z.ZodString, "CamperHandle">;
        color: z.ZodNullable<z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">>;
        pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
        avatarUrl: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
    }, {
        id: z.ZodNumber;
        handle: z.ZodBranded<z.ZodString, "CamperHandle">;
        name: z.ZodBranded<z.ZodString, "CamperDisplayName">;
        avatarUrl: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
        tagline: z.ZodNullable<z.ZodBranded<z.ZodString, "TaglineString">>;
        websiteUrl: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
        color: z.ZodNullable<z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">>;
        pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
        allowPings: z.ZodBoolean;
        syncDiscordDisplayName: z.ZodBoolean;
        createdAt: z.ZodBranded<z.ZodString, "TimestampString">;
        lastInteraction: z.ZodBranded<z.ZodString, "TimestampString">;
        role: z.ZodUnion<[z.ZodLiteral<import("./core").CamperAccessLevel.Banned>, z.ZodLiteral<import("./core").CamperAccessLevel.Normal>, z.ZodLiteral<import("./core").CamperAccessLevel.Firewatch>, z.ZodLiteral<import("./core").CamperAccessLevel.Moderator>, z.ZodLiteral<import("./core").CamperAccessLevel.Admin>]>;
    }>, "strip", z.ZodTypeAny, {
        color: (string & z.BRAND<"ColorString">) | null;
        allowPings: boolean;
        syncDiscordDisplayName: boolean;
        tagline: (string & z.BRAND<"TaglineString">) | null;
        handle: string & z.BRAND<"CamperHandle">;
        pronouns: (string & z.BRAND<"PronounString">) | null;
        id: number;
        name: string & z.BRAND<"CamperDisplayName">;
        avatarUrl: (string & z.BRAND<"URLString">) | null;
        websiteUrl: (string & z.BRAND<"URLString">) | null;
        createdAt: string & z.BRAND<"TimestampString">;
        lastInteraction: string & z.BRAND<"TimestampString">;
        role: import("./core").CamperAccessLevel;
    }, {
        color: string | null;
        allowPings: boolean;
        syncDiscordDisplayName: boolean;
        tagline: string | null;
        handle: string;
        pronouns: string | null;
        id: number;
        name: string;
        avatarUrl: string | null;
        websiteUrl: string | null;
        createdAt: string;
        lastInteraction: string;
        role: import("./core").CamperAccessLevel;
    }>>;
    sheet: z.ZodObject<{
        sheetId: z.ZodNumber;
        camperId: z.ZodNumber;
        resources: z.ZodObject<{
            conduits: z.ZodNumber;
            silkwater: z.ZodNumber;
        }, "strip", z.ZodTypeAny, {
            conduits: number;
            silkwater: number;
        }, {
            conduits: number;
            silkwater: number;
        }>;
        inventory: z.ZodArray<z.ZodObject<{
            itemId: z.ZodNumber;
            camperId: z.ZodNumber;
            slug: z.ZodEnum<["silkwaterJug", "silkwaterJugLarge", "cracklingRainmeter", "swirlingStormwrangler", "fourthDimensionalPlantFood", "tcGen1Beeatrice", "tcGen1Campfire", "tcGen1Chisel", "tcGen1Cloudsailor", "tcGen1Lodge", "tcGen1Murmus", "tcGen1MurmusFoil", "tcGen1Giant", "tcGen1LettersInFlight", "tcGen1SkyCafe", "tcGen1UnknownLunar", "tcGen1UnknownSolar", "tcGen1SecretSauce", "tcGen1GillroyFoil", "tcGen2DapperInPurple", "tcGen2DefinitelyFits", "tcGen2KnowsHowItWorks", "tcGen2Casual", "tcGen2Arcwild", "tcGen2Mysthull", "tcGen2Lelatoll", "tcGen2Skyhook", "tcGen2Goldspire", "tcGen2DukePepperbottom", "tcGen2StudioFoil", "randomScrap", "mermaidScale", "timerootBark", "spritzBottle", "livingIcicle", "stardustBag", "flaskSmall", "harvestedAstralDaisy", "harvestedVoidIvy", "harvestedCrystalOrchid", "harvestedBloodLily", "harvestedRainbowLotus", "harvestedDragonleaf", "harvestedAcidBlossom", "harvestedLightningLotus", "recipeLiquidWanderingIce", "recipeSolidLiquidWanderingIce", "recipeLightningInABottle", "recipeSoulWater", "recipeSilkwaterMist", "recipeQuantumSeed", "recipeFourthDimensionalPlantFood", "recipeBlankPlaceholder", "liquidWanderingIce", "soulWater", "silkwaterMist", "lightningInABottle", "crystalGeode", "treasureChest", "leafPile", "fallenStar", "frozenTreasureChest", "heartShapedBox", "shippingCrate", "giantsGift", "seedPouch", "tcBoosterPackGen1Common", "tcBoosterPackGen1Uncommon", "tcBoosterPackGen1Part2", "tcBoosterPackGen1Full", "tcBoosterPackGen2Drop1", "cosmicPinwheel", "discardedJacket", "trident", "goldLeaf", "doubloon", "harvestedObsidianRose", "harvestedSmoulderingRose", "harvestedRitualPumpkin", "harvestedTrophyThistle", "astralMango", "spectralPapaya", "mysticMorel", "otherworldlyOnion", "bansheeBerry", "secretSauce", "cosmicSocks", "compositionNotebook", "shatteredSpyglassLens", "shatteredSpyglassBody", "shatteredSpyglassEyepiece", "restoredSpyglass", "netheriteVoucher", "fatefulLoom", "bullhorn", "fleetingFeather", "celestialStone", "stellarvibePresentSmall2023", "stellarvibePresentMedium2023", "stellarvibePresentSmallGlowing2023", "stellarvibePresentMediumGlowing2023", "stellarvibePresent2024", "stellarvibePresentGlowing2024", "stellarvibePresent2024Max", "stellarvibePresent2024GlowingMax", "stellarvibePresentSmall", "stellarvibePresentSmallGlowing", "stellarvibePresentMedium", "stellarvibePresentMediumGlowing", "stellarvibePresentLarge", "stellarvibePresentLargeGlowing", "joyfultilizer", "maxJoyfultilizer", "joyrootSeed", "recipeJoyfultilizer", "recipeMaxJoyfultilizer", "scrollOfCultivation", "scrollOfGreaterCultivation", "quantumSeed", "mundaneSeed", "voidIvySeed", "crystalOrchidSeed", "bloodLilySeed", "obsidianRoseSeed", "rainbowLotusSeed", "dragonleafSeed", "smoulderingRoseSeed", "wanderingIceSeed", "stardustBlossomSeed", "celestialBulbSeed", "celestialBoonflowerSeed", "astralMangoTreeSeed", "spectralPapayaTreeSeed", "ritualPumpkinSeed", "trophyThistleSeed", "acidBlossomSeed"]>;
            name: z.ZodString;
            description: z.ZodString;
            flavorText: z.ZodString;
            icon: z.ZodString;
            value: z.ZodNumber;
            category: z.ZodEnum<["redeemable", "cosmetic", "container", "seed", "flower", "consumable", "card", "food", "relic", "scroll", "concoction", "recipe", "component"]>;
            categoryTitle: z.ZodString;
            preserveAfterUsing: z.ZodBoolean;
            canBeUsed: z.ZodBoolean;
            canUseInBotany: z.ZodBoolean;
            rarity: z.ZodEnum<["common", "uncommon", "rare", "relic"]>;
            relatedConcoction: z.ZodOptional<z.ZodEnum<["liquidWanderingIce", "solidLiquidWanderingIce", "lightningInABottle", "soulWater", "silkwaterMist", "joyfultilizer", "maxJoyfultilizer", "quantumSeed", "fourthDimensionalPlantFood"]>>;
        }, "strip", z.ZodTypeAny, {
            value: number;
            name: string;
            slug: "silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed";
            description: string;
            camperId: number;
            itemId: number;
            flavorText: string;
            icon: string;
            category: "recipe" | "redeemable" | "cosmetic" | "container" | "seed" | "flower" | "consumable" | "card" | "food" | "relic" | "scroll" | "concoction" | "component";
            categoryTitle: string;
            preserveAfterUsing: boolean;
            canBeUsed: boolean;
            canUseInBotany: boolean;
            rarity: "relic" | "common" | "uncommon" | "rare";
            relatedConcoction?: "fourthDimensionalPlantFood" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "joyfultilizer" | "maxJoyfultilizer" | "quantumSeed" | "solidLiquidWanderingIce" | undefined;
        }, {
            value: number;
            name: string;
            slug: "silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed";
            description: string;
            camperId: number;
            itemId: number;
            flavorText: string;
            icon: string;
            category: "recipe" | "redeemable" | "cosmetic" | "container" | "seed" | "flower" | "consumable" | "card" | "food" | "relic" | "scroll" | "concoction" | "component";
            categoryTitle: string;
            preserveAfterUsing: boolean;
            canBeUsed: boolean;
            canUseInBotany: boolean;
            rarity: "relic" | "common" | "uncommon" | "rare";
            relatedConcoction?: "fourthDimensionalPlantFood" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "joyfultilizer" | "maxJoyfultilizer" | "quantumSeed" | "solidLiquidWanderingIce" | undefined;
        }>, "many">;
        badges: z.ZodArray<z.ZodEnum<["minecrafter", "trial1complete", "trial1Exalted", "trial2complete", "trial2Exalted", "lodgeLaunch", "botanyPropagator", "botanyGreenThumb", "botanyGrowTogether", "visitedSkyCafe", "sparkleFoot", "stellarvibe2022", "stellarvibe2024", "stellarvibe2024Max", "thunderstruck", "selfthunderstruck", "potluckParticipant", "potluckHero", "sousChef", "starboarded", "seeds100", "seeds500", "seeds1000", "waterOther100", "waterOther1000", "waterOther10000", "waterOther100000", "fruitHarvest", "trophyThistleHarvest"]>, "many">;
        flowers: z.ZodArray<z.ZodObject<{
            slug: z.ZodEnum<["astralDaisy", "voidIvy", "crystalOrchid", "bloodLily", "obsidianRose", "rainbowLotus", "dragonleaf", "wanderingIce", "lightningLotus", "smoulderingRose", "stardustBlossom", "celestialBulb", "celestialBoonflower", "astralMangoTree", "spectralPapayaTree", "ritualPumpkin", "acidBlossom", "trophyThistle", "joyroot", "joyblossom", "joybrushTangle"]>;
            id: z.ZodNumber;
            ownerId: z.ZodNumber;
            plantedAt: z.ZodNumber;
            waterLevel: z.ZodNumber;
            waterMissing: z.ZodNumber;
            waterRate: z.ZodNumber;
            ticksRemaining: z.ZodNumber;
            name: z.ZodString;
            description: z.ZodString;
            icon: z.ZodString;
            isGrowing: z.ZodBoolean;
            isWaterable: z.ZodBoolean;
            isDead: z.ZodBoolean;
            isReady: z.ZodBoolean;
        }, "strip", z.ZodTypeAny, {
            id: number;
            name: string;
            slug: "astralDaisy" | "voidIvy" | "crystalOrchid" | "bloodLily" | "obsidianRose" | "rainbowLotus" | "dragonleaf" | "wanderingIce" | "lightningLotus" | "smoulderingRose" | "stardustBlossom" | "celestialBulb" | "celestialBoonflower" | "astralMangoTree" | "spectralPapayaTree" | "ritualPumpkin" | "acidBlossom" | "trophyThistle" | "joyroot" | "joyblossom" | "joybrushTangle";
            description: string;
            isReady: boolean;
            icon: string;
            ownerId: number;
            plantedAt: number;
            waterLevel: number;
            waterMissing: number;
            waterRate: number;
            ticksRemaining: number;
            isGrowing: boolean;
            isWaterable: boolean;
            isDead: boolean;
        }, {
            id: number;
            name: string;
            slug: "astralDaisy" | "voidIvy" | "crystalOrchid" | "bloodLily" | "obsidianRose" | "rainbowLotus" | "dragonleaf" | "wanderingIce" | "lightningLotus" | "smoulderingRose" | "stardustBlossom" | "celestialBulb" | "celestialBoonflower" | "astralMangoTree" | "spectralPapayaTree" | "ritualPumpkin" | "acidBlossom" | "trophyThistle" | "joyroot" | "joyblossom" | "joybrushTangle";
            description: string;
            isReady: boolean;
            icon: string;
            ownerId: number;
            plantedAt: number;
            waterLevel: number;
            waterMissing: number;
            waterRate: number;
            ticksRemaining: number;
            isGrowing: boolean;
            isWaterable: boolean;
            isDead: boolean;
        }>, "many">;
        concoctions: z.ZodArray<z.ZodObject<{
            id: z.ZodNumber;
            camperId: z.ZodNumber;
            slug: z.ZodEnum<["liquidWanderingIce", "solidLiquidWanderingIce", "lightningInABottle", "soulWater", "silkwaterMist", "joyfultilizer", "maxJoyfultilizer", "quantumSeed", "fourthDimensionalPlantFood"]>;
            turnsBrewing: z.ZodNumber;
            state: z.ZodString;
            recipe: z.ZodObject<{
                slug: z.ZodEnum<["liquidWanderingIce", "solidLiquidWanderingIce", "lightningInABottle", "soulWater", "silkwaterMist", "joyfultilizer", "maxJoyfultilizer", "quantumSeed", "fourthDimensionalPlantFood"]>;
                title: z.ZodString;
                description: z.ZodString;
                image: z.ZodString;
                brewTime: z.ZodNumber;
                brewTimeLeniency: z.ZodNumber;
                ingredients: z.ZodArray<z.ZodTuple<[z.ZodEnum<["silkwaterJug", "silkwaterJugLarge", "cracklingRainmeter", "swirlingStormwrangler", "fourthDimensionalPlantFood", "tcGen1Beeatrice", "tcGen1Campfire", "tcGen1Chisel", "tcGen1Cloudsailor", "tcGen1Lodge", "tcGen1Murmus", "tcGen1MurmusFoil", "tcGen1Giant", "tcGen1LettersInFlight", "tcGen1SkyCafe", "tcGen1UnknownLunar", "tcGen1UnknownSolar", "tcGen1SecretSauce", "tcGen1GillroyFoil", "tcGen2DapperInPurple", "tcGen2DefinitelyFits", "tcGen2KnowsHowItWorks", "tcGen2Casual", "tcGen2Arcwild", "tcGen2Mysthull", "tcGen2Lelatoll", "tcGen2Skyhook", "tcGen2Goldspire", "tcGen2DukePepperbottom", "tcGen2StudioFoil", "randomScrap", "mermaidScale", "timerootBark", "spritzBottle", "livingIcicle", "stardustBag", "flaskSmall", "harvestedAstralDaisy", "harvestedVoidIvy", "harvestedCrystalOrchid", "harvestedBloodLily", "harvestedRainbowLotus", "harvestedDragonleaf", "harvestedAcidBlossom", "harvestedLightningLotus", "recipeLiquidWanderingIce", "recipeSolidLiquidWanderingIce", "recipeLightningInABottle", "recipeSoulWater", "recipeSilkwaterMist", "recipeQuantumSeed", "recipeFourthDimensionalPlantFood", "recipeBlankPlaceholder", "liquidWanderingIce", "soulWater", "silkwaterMist", "lightningInABottle", "crystalGeode", "treasureChest", "leafPile", "fallenStar", "frozenTreasureChest", "heartShapedBox", "shippingCrate", "giantsGift", "seedPouch", "tcBoosterPackGen1Common", "tcBoosterPackGen1Uncommon", "tcBoosterPackGen1Part2", "tcBoosterPackGen1Full", "tcBoosterPackGen2Drop1", "cosmicPinwheel", "discardedJacket", "trident", "goldLeaf", "doubloon", "harvestedObsidianRose", "harvestedSmoulderingRose", "harvestedRitualPumpkin", "harvestedTrophyThistle", "astralMango", "spectralPapaya", "mysticMorel", "otherworldlyOnion", "bansheeBerry", "secretSauce", "cosmicSocks", "compositionNotebook", "shatteredSpyglassLens", "shatteredSpyglassBody", "shatteredSpyglassEyepiece", "restoredSpyglass", "netheriteVoucher", "fatefulLoom", "bullhorn", "fleetingFeather", "celestialStone", "stellarvibePresentSmall2023", "stellarvibePresentMedium2023", "stellarvibePresentSmallGlowing2023", "stellarvibePresentMediumGlowing2023", "stellarvibePresent2024", "stellarvibePresentGlowing2024", "stellarvibePresent2024Max", "stellarvibePresent2024GlowingMax", "stellarvibePresentSmall", "stellarvibePresentSmallGlowing", "stellarvibePresentMedium", "stellarvibePresentMediumGlowing", "stellarvibePresentLarge", "stellarvibePresentLargeGlowing", "joyfultilizer", "maxJoyfultilizer", "joyrootSeed", "recipeJoyfultilizer", "recipeMaxJoyfultilizer", "scrollOfCultivation", "scrollOfGreaterCultivation", "quantumSeed", "mundaneSeed", "voidIvySeed", "crystalOrchidSeed", "bloodLilySeed", "obsidianRoseSeed", "rainbowLotusSeed", "dragonleafSeed", "smoulderingRoseSeed", "wanderingIceSeed", "stardustBlossomSeed", "celestialBulbSeed", "celestialBoonflowerSeed", "astralMangoTreeSeed", "spectralPapayaTreeSeed", "ritualPumpkinSeed", "trophyThistleSeed", "acidBlossomSeed"]>, z.ZodNumber], null>, "many">;
                result: z.ZodEnum<["silkwaterJug", "silkwaterJugLarge", "cracklingRainmeter", "swirlingStormwrangler", "fourthDimensionalPlantFood", "tcGen1Beeatrice", "tcGen1Campfire", "tcGen1Chisel", "tcGen1Cloudsailor", "tcGen1Lodge", "tcGen1Murmus", "tcGen1MurmusFoil", "tcGen1Giant", "tcGen1LettersInFlight", "tcGen1SkyCafe", "tcGen1UnknownLunar", "tcGen1UnknownSolar", "tcGen1SecretSauce", "tcGen1GillroyFoil", "tcGen2DapperInPurple", "tcGen2DefinitelyFits", "tcGen2KnowsHowItWorks", "tcGen2Casual", "tcGen2Arcwild", "tcGen2Mysthull", "tcGen2Lelatoll", "tcGen2Skyhook", "tcGen2Goldspire", "tcGen2DukePepperbottom", "tcGen2StudioFoil", "randomScrap", "mermaidScale", "timerootBark", "spritzBottle", "livingIcicle", "stardustBag", "flaskSmall", "harvestedAstralDaisy", "harvestedVoidIvy", "harvestedCrystalOrchid", "harvestedBloodLily", "harvestedRainbowLotus", "harvestedDragonleaf", "harvestedAcidBlossom", "harvestedLightningLotus", "recipeLiquidWanderingIce", "recipeSolidLiquidWanderingIce", "recipeLightningInABottle", "recipeSoulWater", "recipeSilkwaterMist", "recipeQuantumSeed", "recipeFourthDimensionalPlantFood", "recipeBlankPlaceholder", "liquidWanderingIce", "soulWater", "silkwaterMist", "lightningInABottle", "crystalGeode", "treasureChest", "leafPile", "fallenStar", "frozenTreasureChest", "heartShapedBox", "shippingCrate", "giantsGift", "seedPouch", "tcBoosterPackGen1Common", "tcBoosterPackGen1Uncommon", "tcBoosterPackGen1Part2", "tcBoosterPackGen1Full", "tcBoosterPackGen2Drop1", "cosmicPinwheel", "discardedJacket", "trident", "goldLeaf", "doubloon", "harvestedObsidianRose", "harvestedSmoulderingRose", "harvestedRitualPumpkin", "harvestedTrophyThistle", "astralMango", "spectralPapaya", "mysticMorel", "otherworldlyOnion", "bansheeBerry", "secretSauce", "cosmicSocks", "compositionNotebook", "shatteredSpyglassLens", "shatteredSpyglassBody", "shatteredSpyglassEyepiece", "restoredSpyglass", "netheriteVoucher", "fatefulLoom", "bullhorn", "fleetingFeather", "celestialStone", "stellarvibePresentSmall2023", "stellarvibePresentMedium2023", "stellarvibePresentSmallGlowing2023", "stellarvibePresentMediumGlowing2023", "stellarvibePresent2024", "stellarvibePresentGlowing2024", "stellarvibePresent2024Max", "stellarvibePresent2024GlowingMax", "stellarvibePresentSmall", "stellarvibePresentSmallGlowing", "stellarvibePresentMedium", "stellarvibePresentMediumGlowing", "stellarvibePresentLarge", "stellarvibePresentLargeGlowing", "joyfultilizer", "maxJoyfultilizer", "joyrootSeed", "recipeJoyfultilizer", "recipeMaxJoyfultilizer", "scrollOfCultivation", "scrollOfGreaterCultivation", "quantumSeed", "mundaneSeed", "voidIvySeed", "crystalOrchidSeed", "bloodLilySeed", "obsidianRoseSeed", "rainbowLotusSeed", "dragonleafSeed", "smoulderingRoseSeed", "wanderingIceSeed", "stardustBlossomSeed", "celestialBulbSeed", "celestialBoonflowerSeed", "astralMangoTreeSeed", "spectralPapayaTreeSeed", "ritualPumpkinSeed", "trophyThistleSeed", "acidBlossomSeed"]>;
            }, "strip", z.ZodTypeAny, {
                slug: "fourthDimensionalPlantFood" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "joyfultilizer" | "maxJoyfultilizer" | "quantumSeed" | "solidLiquidWanderingIce";
                title: string;
                description: string;
                image: string;
                brewTime: number;
                brewTimeLeniency: number;
                ingredients: ["silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed", number][];
                result: "silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed";
            }, {
                slug: "fourthDimensionalPlantFood" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "joyfultilizer" | "maxJoyfultilizer" | "quantumSeed" | "solidLiquidWanderingIce";
                title: string;
                description: string;
                image: string;
                brewTime: number;
                brewTimeLeniency: number;
                ingredients: ["silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed", number][];
                result: "silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed";
            }>;
            isReady: z.ZodBoolean;
            autoStop: z.ZodBoolean;
        }, "strip", z.ZodTypeAny, {
            id: number;
            slug: "fourthDimensionalPlantFood" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "joyfultilizer" | "maxJoyfultilizer" | "quantumSeed" | "solidLiquidWanderingIce";
            camperId: number;
            turnsBrewing: number;
            state: string;
            recipe: {
                slug: "fourthDimensionalPlantFood" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "joyfultilizer" | "maxJoyfultilizer" | "quantumSeed" | "solidLiquidWanderingIce";
                title: string;
                description: string;
                image: string;
                brewTime: number;
                brewTimeLeniency: number;
                ingredients: ["silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed", number][];
                result: "silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed";
            };
            isReady: boolean;
            autoStop: boolean;
        }, {
            id: number;
            slug: "fourthDimensionalPlantFood" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "joyfultilizer" | "maxJoyfultilizer" | "quantumSeed" | "solidLiquidWanderingIce";
            camperId: number;
            turnsBrewing: number;
            state: string;
            recipe: {
                slug: "fourthDimensionalPlantFood" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "joyfultilizer" | "maxJoyfultilizer" | "quantumSeed" | "solidLiquidWanderingIce";
                title: string;
                description: string;
                image: string;
                brewTime: number;
                brewTimeLeniency: number;
                ingredients: ["silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed", number][];
                result: "silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed";
            };
            isReady: boolean;
            autoStop: boolean;
        }>, "many">;
        recipes: z.ZodArray<z.ZodObject<{
            slug: z.ZodEnum<["liquidWanderingIce", "solidLiquidWanderingIce", "lightningInABottle", "soulWater", "silkwaterMist", "joyfultilizer", "maxJoyfultilizer", "quantumSeed", "fourthDimensionalPlantFood"]>;
            title: z.ZodString;
            description: z.ZodString;
            image: z.ZodString;
            brewTime: z.ZodNumber;
            brewTimeLeniency: z.ZodNumber;
            ingredients: z.ZodArray<z.ZodTuple<[z.ZodEnum<["silkwaterJug", "silkwaterJugLarge", "cracklingRainmeter", "swirlingStormwrangler", "fourthDimensionalPlantFood", "tcGen1Beeatrice", "tcGen1Campfire", "tcGen1Chisel", "tcGen1Cloudsailor", "tcGen1Lodge", "tcGen1Murmus", "tcGen1MurmusFoil", "tcGen1Giant", "tcGen1LettersInFlight", "tcGen1SkyCafe", "tcGen1UnknownLunar", "tcGen1UnknownSolar", "tcGen1SecretSauce", "tcGen1GillroyFoil", "tcGen2DapperInPurple", "tcGen2DefinitelyFits", "tcGen2KnowsHowItWorks", "tcGen2Casual", "tcGen2Arcwild", "tcGen2Mysthull", "tcGen2Lelatoll", "tcGen2Skyhook", "tcGen2Goldspire", "tcGen2DukePepperbottom", "tcGen2StudioFoil", "randomScrap", "mermaidScale", "timerootBark", "spritzBottle", "livingIcicle", "stardustBag", "flaskSmall", "harvestedAstralDaisy", "harvestedVoidIvy", "harvestedCrystalOrchid", "harvestedBloodLily", "harvestedRainbowLotus", "harvestedDragonleaf", "harvestedAcidBlossom", "harvestedLightningLotus", "recipeLiquidWanderingIce", "recipeSolidLiquidWanderingIce", "recipeLightningInABottle", "recipeSoulWater", "recipeSilkwaterMist", "recipeQuantumSeed", "recipeFourthDimensionalPlantFood", "recipeBlankPlaceholder", "liquidWanderingIce", "soulWater", "silkwaterMist", "lightningInABottle", "crystalGeode", "treasureChest", "leafPile", "fallenStar", "frozenTreasureChest", "heartShapedBox", "shippingCrate", "giantsGift", "seedPouch", "tcBoosterPackGen1Common", "tcBoosterPackGen1Uncommon", "tcBoosterPackGen1Part2", "tcBoosterPackGen1Full", "tcBoosterPackGen2Drop1", "cosmicPinwheel", "discardedJacket", "trident", "goldLeaf", "doubloon", "harvestedObsidianRose", "harvestedSmoulderingRose", "harvestedRitualPumpkin", "harvestedTrophyThistle", "astralMango", "spectralPapaya", "mysticMorel", "otherworldlyOnion", "bansheeBerry", "secretSauce", "cosmicSocks", "compositionNotebook", "shatteredSpyglassLens", "shatteredSpyglassBody", "shatteredSpyglassEyepiece", "restoredSpyglass", "netheriteVoucher", "fatefulLoom", "bullhorn", "fleetingFeather", "celestialStone", "stellarvibePresentSmall2023", "stellarvibePresentMedium2023", "stellarvibePresentSmallGlowing2023", "stellarvibePresentMediumGlowing2023", "stellarvibePresent2024", "stellarvibePresentGlowing2024", "stellarvibePresent2024Max", "stellarvibePresent2024GlowingMax", "stellarvibePresentSmall", "stellarvibePresentSmallGlowing", "stellarvibePresentMedium", "stellarvibePresentMediumGlowing", "stellarvibePresentLarge", "stellarvibePresentLargeGlowing", "joyfultilizer", "maxJoyfultilizer", "joyrootSeed", "recipeJoyfultilizer", "recipeMaxJoyfultilizer", "scrollOfCultivation", "scrollOfGreaterCultivation", "quantumSeed", "mundaneSeed", "voidIvySeed", "crystalOrchidSeed", "bloodLilySeed", "obsidianRoseSeed", "rainbowLotusSeed", "dragonleafSeed", "smoulderingRoseSeed", "wanderingIceSeed", "stardustBlossomSeed", "celestialBulbSeed", "celestialBoonflowerSeed", "astralMangoTreeSeed", "spectralPapayaTreeSeed", "ritualPumpkinSeed", "trophyThistleSeed", "acidBlossomSeed"]>, z.ZodNumber], null>, "many">;
            result: z.ZodEnum<["silkwaterJug", "silkwaterJugLarge", "cracklingRainmeter", "swirlingStormwrangler", "fourthDimensionalPlantFood", "tcGen1Beeatrice", "tcGen1Campfire", "tcGen1Chisel", "tcGen1Cloudsailor", "tcGen1Lodge", "tcGen1Murmus", "tcGen1MurmusFoil", "tcGen1Giant", "tcGen1LettersInFlight", "tcGen1SkyCafe", "tcGen1UnknownLunar", "tcGen1UnknownSolar", "tcGen1SecretSauce", "tcGen1GillroyFoil", "tcGen2DapperInPurple", "tcGen2DefinitelyFits", "tcGen2KnowsHowItWorks", "tcGen2Casual", "tcGen2Arcwild", "tcGen2Mysthull", "tcGen2Lelatoll", "tcGen2Skyhook", "tcGen2Goldspire", "tcGen2DukePepperbottom", "tcGen2StudioFoil", "randomScrap", "mermaidScale", "timerootBark", "spritzBottle", "livingIcicle", "stardustBag", "flaskSmall", "harvestedAstralDaisy", "harvestedVoidIvy", "harvestedCrystalOrchid", "harvestedBloodLily", "harvestedRainbowLotus", "harvestedDragonleaf", "harvestedAcidBlossom", "harvestedLightningLotus", "recipeLiquidWanderingIce", "recipeSolidLiquidWanderingIce", "recipeLightningInABottle", "recipeSoulWater", "recipeSilkwaterMist", "recipeQuantumSeed", "recipeFourthDimensionalPlantFood", "recipeBlankPlaceholder", "liquidWanderingIce", "soulWater", "silkwaterMist", "lightningInABottle", "crystalGeode", "treasureChest", "leafPile", "fallenStar", "frozenTreasureChest", "heartShapedBox", "shippingCrate", "giantsGift", "seedPouch", "tcBoosterPackGen1Common", "tcBoosterPackGen1Uncommon", "tcBoosterPackGen1Part2", "tcBoosterPackGen1Full", "tcBoosterPackGen2Drop1", "cosmicPinwheel", "discardedJacket", "trident", "goldLeaf", "doubloon", "harvestedObsidianRose", "harvestedSmoulderingRose", "harvestedRitualPumpkin", "harvestedTrophyThistle", "astralMango", "spectralPapaya", "mysticMorel", "otherworldlyOnion", "bansheeBerry", "secretSauce", "cosmicSocks", "compositionNotebook", "shatteredSpyglassLens", "shatteredSpyglassBody", "shatteredSpyglassEyepiece", "restoredSpyglass", "netheriteVoucher", "fatefulLoom", "bullhorn", "fleetingFeather", "celestialStone", "stellarvibePresentSmall2023", "stellarvibePresentMedium2023", "stellarvibePresentSmallGlowing2023", "stellarvibePresentMediumGlowing2023", "stellarvibePresent2024", "stellarvibePresentGlowing2024", "stellarvibePresent2024Max", "stellarvibePresent2024GlowingMax", "stellarvibePresentSmall", "stellarvibePresentSmallGlowing", "stellarvibePresentMedium", "stellarvibePresentMediumGlowing", "stellarvibePresentLarge", "stellarvibePresentLargeGlowing", "joyfultilizer", "maxJoyfultilizer", "joyrootSeed", "recipeJoyfultilizer", "recipeMaxJoyfultilizer", "scrollOfCultivation", "scrollOfGreaterCultivation", "quantumSeed", "mundaneSeed", "voidIvySeed", "crystalOrchidSeed", "bloodLilySeed", "obsidianRoseSeed", "rainbowLotusSeed", "dragonleafSeed", "smoulderingRoseSeed", "wanderingIceSeed", "stardustBlossomSeed", "celestialBulbSeed", "celestialBoonflowerSeed", "astralMangoTreeSeed", "spectralPapayaTreeSeed", "ritualPumpkinSeed", "trophyThistleSeed", "acidBlossomSeed"]>;
        }, "strip", z.ZodTypeAny, {
            slug: "fourthDimensionalPlantFood" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "joyfultilizer" | "maxJoyfultilizer" | "quantumSeed" | "solidLiquidWanderingIce";
            title: string;
            description: string;
            image: string;
            brewTime: number;
            brewTimeLeniency: number;
            ingredients: ["silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed", number][];
            result: "silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed";
        }, {
            slug: "fourthDimensionalPlantFood" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "joyfultilizer" | "maxJoyfultilizer" | "quantumSeed" | "solidLiquidWanderingIce";
            title: string;
            description: string;
            image: string;
            brewTime: number;
            brewTimeLeniency: number;
            ingredients: ["silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed", number][];
            result: "silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed";
        }>, "many">;
    }, "strip", z.ZodTypeAny, {
        camperId: number;
        sheetId: number;
        resources: {
            conduits: number;
            silkwater: number;
        };
        inventory: {
            value: number;
            name: string;
            slug: "silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed";
            description: string;
            camperId: number;
            itemId: number;
            flavorText: string;
            icon: string;
            category: "recipe" | "redeemable" | "cosmetic" | "container" | "seed" | "flower" | "consumable" | "card" | "food" | "relic" | "scroll" | "concoction" | "component";
            categoryTitle: string;
            preserveAfterUsing: boolean;
            canBeUsed: boolean;
            canUseInBotany: boolean;
            rarity: "relic" | "common" | "uncommon" | "rare";
            relatedConcoction?: "fourthDimensionalPlantFood" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "joyfultilizer" | "maxJoyfultilizer" | "quantumSeed" | "solidLiquidWanderingIce" | undefined;
        }[];
        badges: ("minecrafter" | "trial1complete" | "trial1Exalted" | "trial2complete" | "trial2Exalted" | "lodgeLaunch" | "botanyPropagator" | "botanyGreenThumb" | "botanyGrowTogether" | "visitedSkyCafe" | "sparkleFoot" | "stellarvibe2022" | "stellarvibe2024" | "stellarvibe2024Max" | "thunderstruck" | "selfthunderstruck" | "potluckParticipant" | "potluckHero" | "sousChef" | "starboarded" | "seeds100" | "seeds500" | "seeds1000" | "waterOther100" | "waterOther1000" | "waterOther10000" | "waterOther100000" | "fruitHarvest" | "trophyThistleHarvest")[];
        flowers: {
            id: number;
            name: string;
            slug: "astralDaisy" | "voidIvy" | "crystalOrchid" | "bloodLily" | "obsidianRose" | "rainbowLotus" | "dragonleaf" | "wanderingIce" | "lightningLotus" | "smoulderingRose" | "stardustBlossom" | "celestialBulb" | "celestialBoonflower" | "astralMangoTree" | "spectralPapayaTree" | "ritualPumpkin" | "acidBlossom" | "trophyThistle" | "joyroot" | "joyblossom" | "joybrushTangle";
            description: string;
            isReady: boolean;
            icon: string;
            ownerId: number;
            plantedAt: number;
            waterLevel: number;
            waterMissing: number;
            waterRate: number;
            ticksRemaining: number;
            isGrowing: boolean;
            isWaterable: boolean;
            isDead: boolean;
        }[];
        concoctions: {
            id: number;
            slug: "fourthDimensionalPlantFood" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "joyfultilizer" | "maxJoyfultilizer" | "quantumSeed" | "solidLiquidWanderingIce";
            camperId: number;
            turnsBrewing: number;
            state: string;
            recipe: {
                slug: "fourthDimensionalPlantFood" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "joyfultilizer" | "maxJoyfultilizer" | "quantumSeed" | "solidLiquidWanderingIce";
                title: string;
                description: string;
                image: string;
                brewTime: number;
                brewTimeLeniency: number;
                ingredients: ["silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed", number][];
                result: "silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed";
            };
            isReady: boolean;
            autoStop: boolean;
        }[];
        recipes: {
            slug: "fourthDimensionalPlantFood" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "joyfultilizer" | "maxJoyfultilizer" | "quantumSeed" | "solidLiquidWanderingIce";
            title: string;
            description: string;
            image: string;
            brewTime: number;
            brewTimeLeniency: number;
            ingredients: ["silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed", number][];
            result: "silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed";
        }[];
    }, {
        camperId: number;
        sheetId: number;
        resources: {
            conduits: number;
            silkwater: number;
        };
        inventory: {
            value: number;
            name: string;
            slug: "silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed";
            description: string;
            camperId: number;
            itemId: number;
            flavorText: string;
            icon: string;
            category: "recipe" | "redeemable" | "cosmetic" | "container" | "seed" | "flower" | "consumable" | "card" | "food" | "relic" | "scroll" | "concoction" | "component";
            categoryTitle: string;
            preserveAfterUsing: boolean;
            canBeUsed: boolean;
            canUseInBotany: boolean;
            rarity: "relic" | "common" | "uncommon" | "rare";
            relatedConcoction?: "fourthDimensionalPlantFood" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "joyfultilizer" | "maxJoyfultilizer" | "quantumSeed" | "solidLiquidWanderingIce" | undefined;
        }[];
        badges: ("minecrafter" | "trial1complete" | "trial1Exalted" | "trial2complete" | "trial2Exalted" | "lodgeLaunch" | "botanyPropagator" | "botanyGreenThumb" | "botanyGrowTogether" | "visitedSkyCafe" | "sparkleFoot" | "stellarvibe2022" | "stellarvibe2024" | "stellarvibe2024Max" | "thunderstruck" | "selfthunderstruck" | "potluckParticipant" | "potluckHero" | "sousChef" | "starboarded" | "seeds100" | "seeds500" | "seeds1000" | "waterOther100" | "waterOther1000" | "waterOther10000" | "waterOther100000" | "fruitHarvest" | "trophyThistleHarvest")[];
        flowers: {
            id: number;
            name: string;
            slug: "astralDaisy" | "voidIvy" | "crystalOrchid" | "bloodLily" | "obsidianRose" | "rainbowLotus" | "dragonleaf" | "wanderingIce" | "lightningLotus" | "smoulderingRose" | "stardustBlossom" | "celestialBulb" | "celestialBoonflower" | "astralMangoTree" | "spectralPapayaTree" | "ritualPumpkin" | "acidBlossom" | "trophyThistle" | "joyroot" | "joyblossom" | "joybrushTangle";
            description: string;
            isReady: boolean;
            icon: string;
            ownerId: number;
            plantedAt: number;
            waterLevel: number;
            waterMissing: number;
            waterRate: number;
            ticksRemaining: number;
            isGrowing: boolean;
            isWaterable: boolean;
            isDead: boolean;
        }[];
        concoctions: {
            id: number;
            slug: "fourthDimensionalPlantFood" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "joyfultilizer" | "maxJoyfultilizer" | "quantumSeed" | "solidLiquidWanderingIce";
            camperId: number;
            turnsBrewing: number;
            state: string;
            recipe: {
                slug: "fourthDimensionalPlantFood" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "joyfultilizer" | "maxJoyfultilizer" | "quantumSeed" | "solidLiquidWanderingIce";
                title: string;
                description: string;
                image: string;
                brewTime: number;
                brewTimeLeniency: number;
                ingredients: ["silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed", number][];
                result: "silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed";
            };
            isReady: boolean;
            autoStop: boolean;
        }[];
        recipes: {
            slug: "fourthDimensionalPlantFood" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "joyfultilizer" | "maxJoyfultilizer" | "quantumSeed" | "solidLiquidWanderingIce";
            title: string;
            description: string;
            image: string;
            brewTime: number;
            brewTimeLeniency: number;
            ingredients: ["silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed", number][];
            result: "silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed";
        }[];
    }>;
    world: z.ZodObject<{
        weather: z.ZodObject<{
            current: z.ZodObject<{
                conditions: z.ZodEnum<["blue lightning", "starfall", "full skies", "no sky", "moths... lots of moths", "cloudfall", "ducks", "a full moon", "ten full moons", "sunshine from a star long since forgotten", "dogs", "cats", "literally just rain", "moonbeams", "sunbeams", "auroras", "ghost showers", "red lightning", "purple lightning", "a bloodmoon", "twelve angry men", "reverse showers", "pumpkins", "pomegranite seeds", "more vibes than you'd expect", "a heavy ghost field", "a light ghost field", "quadruple rainbows", "silkwater rain", "acid storms"]>;
                temperature: z.ZodEnum<["freezing", "cold", "chilly", "temperate", "pretty much normal", "room temp", "a tad humid", "temporal temps", "unfathomably nice", "perfect", "no temperature", "warm", "hot", "sweltering"]>;
                effects: z.ZodArray<z.ZodObject<{
                    system: z.ZodString;
                    effect: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    system: string;
                    effect: string;
                }, {
                    system: string;
                    effect: string;
                }>, "many">;
                isCold: z.ZodBoolean;
                isHot: z.ZodBoolean;
                isGhostly: z.ZodBoolean;
            }, "strip", z.ZodTypeAny, {
                conditions: "blue lightning" | "starfall" | "full skies" | "no sky" | "moths... lots of moths" | "cloudfall" | "ducks" | "a full moon" | "ten full moons" | "sunshine from a star long since forgotten" | "dogs" | "cats" | "literally just rain" | "moonbeams" | "sunbeams" | "auroras" | "ghost showers" | "red lightning" | "purple lightning" | "a bloodmoon" | "twelve angry men" | "reverse showers" | "pumpkins" | "pomegranite seeds" | "more vibes than you'd expect" | "a heavy ghost field" | "a light ghost field" | "quadruple rainbows" | "silkwater rain" | "acid storms";
                temperature: "freezing" | "cold" | "chilly" | "temperate" | "pretty much normal" | "room temp" | "a tad humid" | "temporal temps" | "unfathomably nice" | "perfect" | "no temperature" | "warm" | "hot" | "sweltering";
                effects: {
                    system: string;
                    effect: string;
                }[];
                isCold: boolean;
                isHot: boolean;
                isGhostly: boolean;
            }, {
                conditions: "blue lightning" | "starfall" | "full skies" | "no sky" | "moths... lots of moths" | "cloudfall" | "ducks" | "a full moon" | "ten full moons" | "sunshine from a star long since forgotten" | "dogs" | "cats" | "literally just rain" | "moonbeams" | "sunbeams" | "auroras" | "ghost showers" | "red lightning" | "purple lightning" | "a bloodmoon" | "twelve angry men" | "reverse showers" | "pumpkins" | "pomegranite seeds" | "more vibes than you'd expect" | "a heavy ghost field" | "a light ghost field" | "quadruple rainbows" | "silkwater rain" | "acid storms";
                temperature: "freezing" | "cold" | "chilly" | "temperate" | "pretty much normal" | "room temp" | "a tad humid" | "temporal temps" | "unfathomably nice" | "perfect" | "no temperature" | "warm" | "hot" | "sweltering";
                effects: {
                    system: string;
                    effect: string;
                }[];
                isCold: boolean;
                isHot: boolean;
                isGhostly: boolean;
            }>;
            forecast: z.ZodArray<z.ZodObject<{
                conditions: z.ZodEnum<["blue lightning", "starfall", "full skies", "no sky", "moths... lots of moths", "cloudfall", "ducks", "a full moon", "ten full moons", "sunshine from a star long since forgotten", "dogs", "cats", "literally just rain", "moonbeams", "sunbeams", "auroras", "ghost showers", "red lightning", "purple lightning", "a bloodmoon", "twelve angry men", "reverse showers", "pumpkins", "pomegranite seeds", "more vibes than you'd expect", "a heavy ghost field", "a light ghost field", "quadruple rainbows", "silkwater rain", "acid storms"]>;
                temperature: z.ZodEnum<["freezing", "cold", "chilly", "temperate", "pretty much normal", "room temp", "a tad humid", "temporal temps", "unfathomably nice", "perfect", "no temperature", "warm", "hot", "sweltering"]>;
                effects: z.ZodArray<z.ZodObject<{
                    system: z.ZodString;
                    effect: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    system: string;
                    effect: string;
                }, {
                    system: string;
                    effect: string;
                }>, "many">;
                isCold: z.ZodBoolean;
                isHot: z.ZodBoolean;
                isGhostly: z.ZodBoolean;
            }, "strip", z.ZodTypeAny, {
                conditions: "blue lightning" | "starfall" | "full skies" | "no sky" | "moths... lots of moths" | "cloudfall" | "ducks" | "a full moon" | "ten full moons" | "sunshine from a star long since forgotten" | "dogs" | "cats" | "literally just rain" | "moonbeams" | "sunbeams" | "auroras" | "ghost showers" | "red lightning" | "purple lightning" | "a bloodmoon" | "twelve angry men" | "reverse showers" | "pumpkins" | "pomegranite seeds" | "more vibes than you'd expect" | "a heavy ghost field" | "a light ghost field" | "quadruple rainbows" | "silkwater rain" | "acid storms";
                temperature: "freezing" | "cold" | "chilly" | "temperate" | "pretty much normal" | "room temp" | "a tad humid" | "temporal temps" | "unfathomably nice" | "perfect" | "no temperature" | "warm" | "hot" | "sweltering";
                effects: {
                    system: string;
                    effect: string;
                }[];
                isCold: boolean;
                isHot: boolean;
                isGhostly: boolean;
            }, {
                conditions: "blue lightning" | "starfall" | "full skies" | "no sky" | "moths... lots of moths" | "cloudfall" | "ducks" | "a full moon" | "ten full moons" | "sunshine from a star long since forgotten" | "dogs" | "cats" | "literally just rain" | "moonbeams" | "sunbeams" | "auroras" | "ghost showers" | "red lightning" | "purple lightning" | "a bloodmoon" | "twelve angry men" | "reverse showers" | "pumpkins" | "pomegranite seeds" | "more vibes than you'd expect" | "a heavy ghost field" | "a light ghost field" | "quadruple rainbows" | "silkwater rain" | "acid storms";
                temperature: "freezing" | "cold" | "chilly" | "temperate" | "pretty much normal" | "room temp" | "a tad humid" | "temporal temps" | "unfathomably nice" | "perfect" | "no temperature" | "warm" | "hot" | "sweltering";
                effects: {
                    system: string;
                    effect: string;
                }[];
                isCold: boolean;
                isHot: boolean;
                isGhostly: boolean;
            }>, "many">;
        }, "strip", z.ZodTypeAny, {
            current: {
                conditions: "blue lightning" | "starfall" | "full skies" | "no sky" | "moths... lots of moths" | "cloudfall" | "ducks" | "a full moon" | "ten full moons" | "sunshine from a star long since forgotten" | "dogs" | "cats" | "literally just rain" | "moonbeams" | "sunbeams" | "auroras" | "ghost showers" | "red lightning" | "purple lightning" | "a bloodmoon" | "twelve angry men" | "reverse showers" | "pumpkins" | "pomegranite seeds" | "more vibes than you'd expect" | "a heavy ghost field" | "a light ghost field" | "quadruple rainbows" | "silkwater rain" | "acid storms";
                temperature: "freezing" | "cold" | "chilly" | "temperate" | "pretty much normal" | "room temp" | "a tad humid" | "temporal temps" | "unfathomably nice" | "perfect" | "no temperature" | "warm" | "hot" | "sweltering";
                effects: {
                    system: string;
                    effect: string;
                }[];
                isCold: boolean;
                isHot: boolean;
                isGhostly: boolean;
            };
            forecast: {
                conditions: "blue lightning" | "starfall" | "full skies" | "no sky" | "moths... lots of moths" | "cloudfall" | "ducks" | "a full moon" | "ten full moons" | "sunshine from a star long since forgotten" | "dogs" | "cats" | "literally just rain" | "moonbeams" | "sunbeams" | "auroras" | "ghost showers" | "red lightning" | "purple lightning" | "a bloodmoon" | "twelve angry men" | "reverse showers" | "pumpkins" | "pomegranite seeds" | "more vibes than you'd expect" | "a heavy ghost field" | "a light ghost field" | "quadruple rainbows" | "silkwater rain" | "acid storms";
                temperature: "freezing" | "cold" | "chilly" | "temperate" | "pretty much normal" | "room temp" | "a tad humid" | "temporal temps" | "unfathomably nice" | "perfect" | "no temperature" | "warm" | "hot" | "sweltering";
                effects: {
                    system: string;
                    effect: string;
                }[];
                isCold: boolean;
                isHot: boolean;
                isGhostly: boolean;
            }[];
        }, {
            current: {
                conditions: "blue lightning" | "starfall" | "full skies" | "no sky" | "moths... lots of moths" | "cloudfall" | "ducks" | "a full moon" | "ten full moons" | "sunshine from a star long since forgotten" | "dogs" | "cats" | "literally just rain" | "moonbeams" | "sunbeams" | "auroras" | "ghost showers" | "red lightning" | "purple lightning" | "a bloodmoon" | "twelve angry men" | "reverse showers" | "pumpkins" | "pomegranite seeds" | "more vibes than you'd expect" | "a heavy ghost field" | "a light ghost field" | "quadruple rainbows" | "silkwater rain" | "acid storms";
                temperature: "freezing" | "cold" | "chilly" | "temperate" | "pretty much normal" | "room temp" | "a tad humid" | "temporal temps" | "unfathomably nice" | "perfect" | "no temperature" | "warm" | "hot" | "sweltering";
                effects: {
                    system: string;
                    effect: string;
                }[];
                isCold: boolean;
                isHot: boolean;
                isGhostly: boolean;
            };
            forecast: {
                conditions: "blue lightning" | "starfall" | "full skies" | "no sky" | "moths... lots of moths" | "cloudfall" | "ducks" | "a full moon" | "ten full moons" | "sunshine from a star long since forgotten" | "dogs" | "cats" | "literally just rain" | "moonbeams" | "sunbeams" | "auroras" | "ghost showers" | "red lightning" | "purple lightning" | "a bloodmoon" | "twelve angry men" | "reverse showers" | "pumpkins" | "pomegranite seeds" | "more vibes than you'd expect" | "a heavy ghost field" | "a light ghost field" | "quadruple rainbows" | "silkwater rain" | "acid storms";
                temperature: "freezing" | "cold" | "chilly" | "temperate" | "pretty much normal" | "room temp" | "a tad humid" | "temporal temps" | "unfathomably nice" | "perfect" | "no temperature" | "warm" | "hot" | "sweltering";
                effects: {
                    system: string;
                    effect: string;
                }[];
                isCold: boolean;
                isHot: boolean;
                isGhostly: boolean;
            }[];
        }>;
        time: z.ZodObject<{
            ticksSinceEpoch: z.ZodNumber;
            daysSinceEpoch: z.ZodNumber;
        }, "strip", z.ZodTypeAny, {
            ticksSinceEpoch: number;
            daysSinceEpoch: number;
        }, {
            ticksSinceEpoch: number;
            daysSinceEpoch: number;
        }>;
    }, "strip", z.ZodTypeAny, {
        weather: {
            current: {
                conditions: "blue lightning" | "starfall" | "full skies" | "no sky" | "moths... lots of moths" | "cloudfall" | "ducks" | "a full moon" | "ten full moons" | "sunshine from a star long since forgotten" | "dogs" | "cats" | "literally just rain" | "moonbeams" | "sunbeams" | "auroras" | "ghost showers" | "red lightning" | "purple lightning" | "a bloodmoon" | "twelve angry men" | "reverse showers" | "pumpkins" | "pomegranite seeds" | "more vibes than you'd expect" | "a heavy ghost field" | "a light ghost field" | "quadruple rainbows" | "silkwater rain" | "acid storms";
                temperature: "freezing" | "cold" | "chilly" | "temperate" | "pretty much normal" | "room temp" | "a tad humid" | "temporal temps" | "unfathomably nice" | "perfect" | "no temperature" | "warm" | "hot" | "sweltering";
                effects: {
                    system: string;
                    effect: string;
                }[];
                isCold: boolean;
                isHot: boolean;
                isGhostly: boolean;
            };
            forecast: {
                conditions: "blue lightning" | "starfall" | "full skies" | "no sky" | "moths... lots of moths" | "cloudfall" | "ducks" | "a full moon" | "ten full moons" | "sunshine from a star long since forgotten" | "dogs" | "cats" | "literally just rain" | "moonbeams" | "sunbeams" | "auroras" | "ghost showers" | "red lightning" | "purple lightning" | "a bloodmoon" | "twelve angry men" | "reverse showers" | "pumpkins" | "pomegranite seeds" | "more vibes than you'd expect" | "a heavy ghost field" | "a light ghost field" | "quadruple rainbows" | "silkwater rain" | "acid storms";
                temperature: "freezing" | "cold" | "chilly" | "temperate" | "pretty much normal" | "room temp" | "a tad humid" | "temporal temps" | "unfathomably nice" | "perfect" | "no temperature" | "warm" | "hot" | "sweltering";
                effects: {
                    system: string;
                    effect: string;
                }[];
                isCold: boolean;
                isHot: boolean;
                isGhostly: boolean;
            }[];
        };
        time: {
            ticksSinceEpoch: number;
            daysSinceEpoch: number;
        };
    }, {
        weather: {
            current: {
                conditions: "blue lightning" | "starfall" | "full skies" | "no sky" | "moths... lots of moths" | "cloudfall" | "ducks" | "a full moon" | "ten full moons" | "sunshine from a star long since forgotten" | "dogs" | "cats" | "literally just rain" | "moonbeams" | "sunbeams" | "auroras" | "ghost showers" | "red lightning" | "purple lightning" | "a bloodmoon" | "twelve angry men" | "reverse showers" | "pumpkins" | "pomegranite seeds" | "more vibes than you'd expect" | "a heavy ghost field" | "a light ghost field" | "quadruple rainbows" | "silkwater rain" | "acid storms";
                temperature: "freezing" | "cold" | "chilly" | "temperate" | "pretty much normal" | "room temp" | "a tad humid" | "temporal temps" | "unfathomably nice" | "perfect" | "no temperature" | "warm" | "hot" | "sweltering";
                effects: {
                    system: string;
                    effect: string;
                }[];
                isCold: boolean;
                isHot: boolean;
                isGhostly: boolean;
            };
            forecast: {
                conditions: "blue lightning" | "starfall" | "full skies" | "no sky" | "moths... lots of moths" | "cloudfall" | "ducks" | "a full moon" | "ten full moons" | "sunshine from a star long since forgotten" | "dogs" | "cats" | "literally just rain" | "moonbeams" | "sunbeams" | "auroras" | "ghost showers" | "red lightning" | "purple lightning" | "a bloodmoon" | "twelve angry men" | "reverse showers" | "pumpkins" | "pomegranite seeds" | "more vibes than you'd expect" | "a heavy ghost field" | "a light ghost field" | "quadruple rainbows" | "silkwater rain" | "acid storms";
                temperature: "freezing" | "cold" | "chilly" | "temperate" | "pretty much normal" | "room temp" | "a tad humid" | "temporal temps" | "unfathomably nice" | "perfect" | "no temperature" | "warm" | "hot" | "sweltering";
                effects: {
                    system: string;
                    effect: string;
                }[];
                isCold: boolean;
                isHot: boolean;
                isGhostly: boolean;
            }[];
        };
        time: {
            ticksSinceEpoch: number;
            daysSinceEpoch: number;
        };
    }>;
}, "strip", z.ZodTypeAny, {
    camper: Readonly<{
        color: (string & z.BRAND<"ColorString">) | null;
        allowPings: boolean;
        syncDiscordDisplayName: boolean;
        tagline: (string & z.BRAND<"TaglineString">) | null;
        handle: string & z.BRAND<"CamperHandle">;
        pronouns: (string & z.BRAND<"PronounString">) | null;
        id: number;
        name: string & z.BRAND<"CamperDisplayName">;
        avatarUrl: (string & z.BRAND<"URLString">) | null;
        websiteUrl: (string & z.BRAND<"URLString">) | null;
        createdAt: string & z.BRAND<"TimestampString">;
        lastInteraction: string & z.BRAND<"TimestampString">;
        role: import("./core").CamperAccessLevel;
    }>;
    sheet: {
        camperId: number;
        sheetId: number;
        resources: {
            conduits: number;
            silkwater: number;
        };
        inventory: {
            value: number;
            name: string;
            slug: "silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed";
            description: string;
            camperId: number;
            itemId: number;
            flavorText: string;
            icon: string;
            category: "recipe" | "redeemable" | "cosmetic" | "container" | "seed" | "flower" | "consumable" | "card" | "food" | "relic" | "scroll" | "concoction" | "component";
            categoryTitle: string;
            preserveAfterUsing: boolean;
            canBeUsed: boolean;
            canUseInBotany: boolean;
            rarity: "relic" | "common" | "uncommon" | "rare";
            relatedConcoction?: "fourthDimensionalPlantFood" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "joyfultilizer" | "maxJoyfultilizer" | "quantumSeed" | "solidLiquidWanderingIce" | undefined;
        }[];
        badges: ("minecrafter" | "trial1complete" | "trial1Exalted" | "trial2complete" | "trial2Exalted" | "lodgeLaunch" | "botanyPropagator" | "botanyGreenThumb" | "botanyGrowTogether" | "visitedSkyCafe" | "sparkleFoot" | "stellarvibe2022" | "stellarvibe2024" | "stellarvibe2024Max" | "thunderstruck" | "selfthunderstruck" | "potluckParticipant" | "potluckHero" | "sousChef" | "starboarded" | "seeds100" | "seeds500" | "seeds1000" | "waterOther100" | "waterOther1000" | "waterOther10000" | "waterOther100000" | "fruitHarvest" | "trophyThistleHarvest")[];
        flowers: {
            id: number;
            name: string;
            slug: "astralDaisy" | "voidIvy" | "crystalOrchid" | "bloodLily" | "obsidianRose" | "rainbowLotus" | "dragonleaf" | "wanderingIce" | "lightningLotus" | "smoulderingRose" | "stardustBlossom" | "celestialBulb" | "celestialBoonflower" | "astralMangoTree" | "spectralPapayaTree" | "ritualPumpkin" | "acidBlossom" | "trophyThistle" | "joyroot" | "joyblossom" | "joybrushTangle";
            description: string;
            isReady: boolean;
            icon: string;
            ownerId: number;
            plantedAt: number;
            waterLevel: number;
            waterMissing: number;
            waterRate: number;
            ticksRemaining: number;
            isGrowing: boolean;
            isWaterable: boolean;
            isDead: boolean;
        }[];
        concoctions: {
            id: number;
            slug: "fourthDimensionalPlantFood" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "joyfultilizer" | "maxJoyfultilizer" | "quantumSeed" | "solidLiquidWanderingIce";
            camperId: number;
            turnsBrewing: number;
            state: string;
            recipe: {
                slug: "fourthDimensionalPlantFood" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "joyfultilizer" | "maxJoyfultilizer" | "quantumSeed" | "solidLiquidWanderingIce";
                title: string;
                description: string;
                image: string;
                brewTime: number;
                brewTimeLeniency: number;
                ingredients: ["silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed", number][];
                result: "silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed";
            };
            isReady: boolean;
            autoStop: boolean;
        }[];
        recipes: {
            slug: "fourthDimensionalPlantFood" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "joyfultilizer" | "maxJoyfultilizer" | "quantumSeed" | "solidLiquidWanderingIce";
            title: string;
            description: string;
            image: string;
            brewTime: number;
            brewTimeLeniency: number;
            ingredients: ["silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed", number][];
            result: "silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed";
        }[];
    };
    world: {
        weather: {
            current: {
                conditions: "blue lightning" | "starfall" | "full skies" | "no sky" | "moths... lots of moths" | "cloudfall" | "ducks" | "a full moon" | "ten full moons" | "sunshine from a star long since forgotten" | "dogs" | "cats" | "literally just rain" | "moonbeams" | "sunbeams" | "auroras" | "ghost showers" | "red lightning" | "purple lightning" | "a bloodmoon" | "twelve angry men" | "reverse showers" | "pumpkins" | "pomegranite seeds" | "more vibes than you'd expect" | "a heavy ghost field" | "a light ghost field" | "quadruple rainbows" | "silkwater rain" | "acid storms";
                temperature: "freezing" | "cold" | "chilly" | "temperate" | "pretty much normal" | "room temp" | "a tad humid" | "temporal temps" | "unfathomably nice" | "perfect" | "no temperature" | "warm" | "hot" | "sweltering";
                effects: {
                    system: string;
                    effect: string;
                }[];
                isCold: boolean;
                isHot: boolean;
                isGhostly: boolean;
            };
            forecast: {
                conditions: "blue lightning" | "starfall" | "full skies" | "no sky" | "moths... lots of moths" | "cloudfall" | "ducks" | "a full moon" | "ten full moons" | "sunshine from a star long since forgotten" | "dogs" | "cats" | "literally just rain" | "moonbeams" | "sunbeams" | "auroras" | "ghost showers" | "red lightning" | "purple lightning" | "a bloodmoon" | "twelve angry men" | "reverse showers" | "pumpkins" | "pomegranite seeds" | "more vibes than you'd expect" | "a heavy ghost field" | "a light ghost field" | "quadruple rainbows" | "silkwater rain" | "acid storms";
                temperature: "freezing" | "cold" | "chilly" | "temperate" | "pretty much normal" | "room temp" | "a tad humid" | "temporal temps" | "unfathomably nice" | "perfect" | "no temperature" | "warm" | "hot" | "sweltering";
                effects: {
                    system: string;
                    effect: string;
                }[];
                isCold: boolean;
                isHot: boolean;
                isGhostly: boolean;
            }[];
        };
        time: {
            ticksSinceEpoch: number;
            daysSinceEpoch: number;
        };
    };
}, {
    camper: Readonly<{
        color: string | null;
        allowPings: boolean;
        syncDiscordDisplayName: boolean;
        tagline: string | null;
        handle: string;
        pronouns: string | null;
        id: number;
        name: string;
        avatarUrl: string | null;
        websiteUrl: string | null;
        createdAt: string;
        lastInteraction: string;
        role: import("./core").CamperAccessLevel;
    }>;
    sheet: {
        camperId: number;
        sheetId: number;
        resources: {
            conduits: number;
            silkwater: number;
        };
        inventory: {
            value: number;
            name: string;
            slug: "silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed";
            description: string;
            camperId: number;
            itemId: number;
            flavorText: string;
            icon: string;
            category: "recipe" | "redeemable" | "cosmetic" | "container" | "seed" | "flower" | "consumable" | "card" | "food" | "relic" | "scroll" | "concoction" | "component";
            categoryTitle: string;
            preserveAfterUsing: boolean;
            canBeUsed: boolean;
            canUseInBotany: boolean;
            rarity: "relic" | "common" | "uncommon" | "rare";
            relatedConcoction?: "fourthDimensionalPlantFood" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "joyfultilizer" | "maxJoyfultilizer" | "quantumSeed" | "solidLiquidWanderingIce" | undefined;
        }[];
        badges: ("minecrafter" | "trial1complete" | "trial1Exalted" | "trial2complete" | "trial2Exalted" | "lodgeLaunch" | "botanyPropagator" | "botanyGreenThumb" | "botanyGrowTogether" | "visitedSkyCafe" | "sparkleFoot" | "stellarvibe2022" | "stellarvibe2024" | "stellarvibe2024Max" | "thunderstruck" | "selfthunderstruck" | "potluckParticipant" | "potluckHero" | "sousChef" | "starboarded" | "seeds100" | "seeds500" | "seeds1000" | "waterOther100" | "waterOther1000" | "waterOther10000" | "waterOther100000" | "fruitHarvest" | "trophyThistleHarvest")[];
        flowers: {
            id: number;
            name: string;
            slug: "astralDaisy" | "voidIvy" | "crystalOrchid" | "bloodLily" | "obsidianRose" | "rainbowLotus" | "dragonleaf" | "wanderingIce" | "lightningLotus" | "smoulderingRose" | "stardustBlossom" | "celestialBulb" | "celestialBoonflower" | "astralMangoTree" | "spectralPapayaTree" | "ritualPumpkin" | "acidBlossom" | "trophyThistle" | "joyroot" | "joyblossom" | "joybrushTangle";
            description: string;
            isReady: boolean;
            icon: string;
            ownerId: number;
            plantedAt: number;
            waterLevel: number;
            waterMissing: number;
            waterRate: number;
            ticksRemaining: number;
            isGrowing: boolean;
            isWaterable: boolean;
            isDead: boolean;
        }[];
        concoctions: {
            id: number;
            slug: "fourthDimensionalPlantFood" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "joyfultilizer" | "maxJoyfultilizer" | "quantumSeed" | "solidLiquidWanderingIce";
            camperId: number;
            turnsBrewing: number;
            state: string;
            recipe: {
                slug: "fourthDimensionalPlantFood" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "joyfultilizer" | "maxJoyfultilizer" | "quantumSeed" | "solidLiquidWanderingIce";
                title: string;
                description: string;
                image: string;
                brewTime: number;
                brewTimeLeniency: number;
                ingredients: ["silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed", number][];
                result: "silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed";
            };
            isReady: boolean;
            autoStop: boolean;
        }[];
        recipes: {
            slug: "fourthDimensionalPlantFood" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "joyfultilizer" | "maxJoyfultilizer" | "quantumSeed" | "solidLiquidWanderingIce";
            title: string;
            description: string;
            image: string;
            brewTime: number;
            brewTimeLeniency: number;
            ingredients: ["silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed", number][];
            result: "silkwaterJug" | "silkwaterJugLarge" | "cracklingRainmeter" | "swirlingStormwrangler" | "fourthDimensionalPlantFood" | "tcGen1Beeatrice" | "tcGen1Campfire" | "tcGen1Chisel" | "tcGen1Cloudsailor" | "tcGen1Lodge" | "tcGen1Murmus" | "tcGen1MurmusFoil" | "tcGen1Giant" | "tcGen1LettersInFlight" | "tcGen1SkyCafe" | "tcGen1UnknownLunar" | "tcGen1UnknownSolar" | "tcGen1SecretSauce" | "tcGen1GillroyFoil" | "tcGen2DapperInPurple" | "tcGen2DefinitelyFits" | "tcGen2KnowsHowItWorks" | "tcGen2Casual" | "tcGen2Arcwild" | "tcGen2Mysthull" | "tcGen2Lelatoll" | "tcGen2Skyhook" | "tcGen2Goldspire" | "tcGen2DukePepperbottom" | "tcGen2StudioFoil" | "randomScrap" | "mermaidScale" | "timerootBark" | "spritzBottle" | "livingIcicle" | "stardustBag" | "flaskSmall" | "harvestedAstralDaisy" | "harvestedVoidIvy" | "harvestedCrystalOrchid" | "harvestedBloodLily" | "harvestedRainbowLotus" | "harvestedDragonleaf" | "harvestedAcidBlossom" | "harvestedLightningLotus" | "recipeLiquidWanderingIce" | "recipeSolidLiquidWanderingIce" | "recipeLightningInABottle" | "recipeSoulWater" | "recipeSilkwaterMist" | "recipeQuantumSeed" | "recipeFourthDimensionalPlantFood" | "recipeBlankPlaceholder" | "liquidWanderingIce" | "soulWater" | "silkwaterMist" | "lightningInABottle" | "crystalGeode" | "treasureChest" | "leafPile" | "fallenStar" | "frozenTreasureChest" | "heartShapedBox" | "shippingCrate" | "giantsGift" | "seedPouch" | "tcBoosterPackGen1Common" | "tcBoosterPackGen1Uncommon" | "tcBoosterPackGen1Part2" | "tcBoosterPackGen1Full" | "tcBoosterPackGen2Drop1" | "cosmicPinwheel" | "discardedJacket" | "trident" | "goldLeaf" | "doubloon" | "harvestedObsidianRose" | "harvestedSmoulderingRose" | "harvestedRitualPumpkin" | "harvestedTrophyThistle" | "astralMango" | "spectralPapaya" | "mysticMorel" | "otherworldlyOnion" | "bansheeBerry" | "secretSauce" | "cosmicSocks" | "compositionNotebook" | "shatteredSpyglassLens" | "shatteredSpyglassBody" | "shatteredSpyglassEyepiece" | "restoredSpyglass" | "netheriteVoucher" | "fatefulLoom" | "bullhorn" | "fleetingFeather" | "celestialStone" | "stellarvibePresentSmall2023" | "stellarvibePresentMedium2023" | "stellarvibePresentSmallGlowing2023" | "stellarvibePresentMediumGlowing2023" | "stellarvibePresent2024" | "stellarvibePresentGlowing2024" | "stellarvibePresent2024Max" | "stellarvibePresent2024GlowingMax" | "stellarvibePresentSmall" | "stellarvibePresentSmallGlowing" | "stellarvibePresentMedium" | "stellarvibePresentMediumGlowing" | "stellarvibePresentLarge" | "stellarvibePresentLargeGlowing" | "joyfultilizer" | "maxJoyfultilizer" | "joyrootSeed" | "recipeJoyfultilizer" | "recipeMaxJoyfultilizer" | "scrollOfCultivation" | "scrollOfGreaterCultivation" | "quantumSeed" | "mundaneSeed" | "voidIvySeed" | "crystalOrchidSeed" | "bloodLilySeed" | "obsidianRoseSeed" | "rainbowLotusSeed" | "dragonleafSeed" | "smoulderingRoseSeed" | "wanderingIceSeed" | "stardustBlossomSeed" | "celestialBulbSeed" | "celestialBoonflowerSeed" | "astralMangoTreeSeed" | "spectralPapayaTreeSeed" | "ritualPumpkinSeed" | "trophyThistleSeed" | "acidBlossomSeed";
        }[];
    };
    world: {
        weather: {
            current: {
                conditions: "blue lightning" | "starfall" | "full skies" | "no sky" | "moths... lots of moths" | "cloudfall" | "ducks" | "a full moon" | "ten full moons" | "sunshine from a star long since forgotten" | "dogs" | "cats" | "literally just rain" | "moonbeams" | "sunbeams" | "auroras" | "ghost showers" | "red lightning" | "purple lightning" | "a bloodmoon" | "twelve angry men" | "reverse showers" | "pumpkins" | "pomegranite seeds" | "more vibes than you'd expect" | "a heavy ghost field" | "a light ghost field" | "quadruple rainbows" | "silkwater rain" | "acid storms";
                temperature: "freezing" | "cold" | "chilly" | "temperate" | "pretty much normal" | "room temp" | "a tad humid" | "temporal temps" | "unfathomably nice" | "perfect" | "no temperature" | "warm" | "hot" | "sweltering";
                effects: {
                    system: string;
                    effect: string;
                }[];
                isCold: boolean;
                isHot: boolean;
                isGhostly: boolean;
            };
            forecast: {
                conditions: "blue lightning" | "starfall" | "full skies" | "no sky" | "moths... lots of moths" | "cloudfall" | "ducks" | "a full moon" | "ten full moons" | "sunshine from a star long since forgotten" | "dogs" | "cats" | "literally just rain" | "moonbeams" | "sunbeams" | "auroras" | "ghost showers" | "red lightning" | "purple lightning" | "a bloodmoon" | "twelve angry men" | "reverse showers" | "pumpkins" | "pomegranite seeds" | "more vibes than you'd expect" | "a heavy ghost field" | "a light ghost field" | "quadruple rainbows" | "silkwater rain" | "acid storms";
                temperature: "freezing" | "cold" | "chilly" | "temperate" | "pretty much normal" | "room temp" | "a tad humid" | "temporal temps" | "unfathomably nice" | "perfect" | "no temperature" | "warm" | "hot" | "sweltering";
                effects: {
                    system: string;
                    effect: string;
                }[];
                isCold: boolean;
                isHot: boolean;
                isGhostly: boolean;
            }[];
        };
        time: {
            ticksSinceEpoch: number;
            daysSinceEpoch: number;
        };
    };
}>;
export type LodgeCommonPayload = z.infer<typeof LodgeCommonPayloadSchema>;
export declare const LodgeConnectedAccountsSchema: z.ZodObject<{
    mastodon: z.ZodNullable<z.ZodString>;
    twitch: z.ZodNullable<z.ZodReadonly<z.ZodObject<{
        twitchIdentityId: z.ZodNumber;
        twitchId: z.ZodString;
        camper: z.ZodNullable<z.ZodObject<{
            id: z.ZodNumber;
            name: z.ZodBranded<z.ZodString, "CamperDisplayName">;
            handle: z.ZodBranded<z.ZodString, "CamperHandle">;
            color: z.ZodNullable<z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">>;
            pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
            avatarUrl: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
        }, "strip", z.ZodTypeAny, {
            color: (string & z.BRAND<"ColorString">) | null;
            handle: string & z.BRAND<"CamperHandle">;
            pronouns: (string & z.BRAND<"PronounString">) | null;
            id: number;
            name: string & z.BRAND<"CamperDisplayName">;
            avatarUrl: (string & z.BRAND<"URLString">) | null;
        }, {
            color: string | null;
            handle: string;
            pronouns: string | null;
            id: number;
            name: string;
            avatarUrl: string | null;
        }>>;
        twitchHandle: z.ZodString;
        twitchDisplayName: z.ZodString;
        twitchNameColor: z.ZodString;
        twitchChannelURL: z.ZodString;
        info: z.ZodObject<{
            name: z.ZodString;
            color: z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">;
            pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
            avatarURL: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
        }, "strip", z.ZodTypeAny, {
            color: string & z.BRAND<"ColorString">;
            pronouns: (string & z.BRAND<"PronounString">) | null;
            name: string;
            avatarURL: (string & z.BRAND<"URLString">) | null;
        }, {
            color: string;
            pronouns: string | null;
            name: string;
            avatarURL: string | null;
        }>;
    }, "strip", z.ZodTypeAny, {
        camper: {
            color: (string & z.BRAND<"ColorString">) | null;
            handle: string & z.BRAND<"CamperHandle">;
            pronouns: (string & z.BRAND<"PronounString">) | null;
            id: number;
            name: string & z.BRAND<"CamperDisplayName">;
            avatarUrl: (string & z.BRAND<"URLString">) | null;
        } | null;
        twitchIdentityId: number;
        twitchId: string;
        twitchHandle: string;
        twitchDisplayName: string;
        twitchNameColor: string;
        twitchChannelURL: string;
        info: {
            color: string & z.BRAND<"ColorString">;
            pronouns: (string & z.BRAND<"PronounString">) | null;
            name: string;
            avatarURL: (string & z.BRAND<"URLString">) | null;
        };
    }, {
        camper: {
            color: string | null;
            handle: string;
            pronouns: string | null;
            id: number;
            name: string;
            avatarUrl: string | null;
        } | null;
        twitchIdentityId: number;
        twitchId: string;
        twitchHandle: string;
        twitchDisplayName: string;
        twitchNameColor: string;
        twitchChannelURL: string;
        info: {
            color: string;
            pronouns: string | null;
            name: string;
            avatarURL: string | null;
        };
    }>>>;
    discord: z.ZodNullable<z.ZodObject<{
        camper: z.ZodObject<{
            id: z.ZodNumber;
            name: z.ZodBranded<z.ZodString, "CamperDisplayName">;
            handle: z.ZodBranded<z.ZodString, "CamperHandle">;
            color: z.ZodNullable<z.ZodBranded<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "ColorString">>;
            pronouns: z.ZodNullable<z.ZodBranded<z.ZodString, "PronounString">>;
            avatarUrl: z.ZodNullable<z.ZodBranded<z.ZodString, "URLString">>;
        }, "strip", z.ZodTypeAny, {
            color: (string & z.BRAND<"ColorString">) | null;
            handle: string & z.BRAND<"CamperHandle">;
            pronouns: (string & z.BRAND<"PronounString">) | null;
            id: number;
            name: string & z.BRAND<"CamperDisplayName">;
            avatarUrl: (string & z.BRAND<"URLString">) | null;
        }, {
            color: string | null;
            handle: string;
            pronouns: string | null;
            id: number;
            name: string;
            avatarUrl: string | null;
        }>;
        discordId: z.ZodString;
        discordUsername: z.ZodString;
        discordDisplayName: z.ZodString;
        discordAvatar: z.ZodBranded<z.ZodString, "URLString">;
    }, "strip", z.ZodTypeAny, {
        camper: {
            color: (string & z.BRAND<"ColorString">) | null;
            handle: string & z.BRAND<"CamperHandle">;
            pronouns: (string & z.BRAND<"PronounString">) | null;
            id: number;
            name: string & z.BRAND<"CamperDisplayName">;
            avatarUrl: (string & z.BRAND<"URLString">) | null;
        };
        discordId: string;
        discordUsername: string;
        discordDisplayName: string;
        discordAvatar: string & z.BRAND<"URLString">;
    }, {
        camper: {
            color: string | null;
            handle: string;
            pronouns: string | null;
            id: number;
            name: string;
            avatarUrl: string | null;
        };
        discordId: string;
        discordUsername: string;
        discordDisplayName: string;
        discordAvatar: string;
    }>>;
    prose: z.ZodNullable<z.ZodString>;
    mastoLink: z.ZodString;
}, "strip", z.ZodTypeAny, {
    prose: string | null;
    mastodon: string | null;
    twitch: Readonly<{
        camper: {
            color: (string & z.BRAND<"ColorString">) | null;
            handle: string & z.BRAND<"CamperHandle">;
            pronouns: (string & z.BRAND<"PronounString">) | null;
            id: number;
            name: string & z.BRAND<"CamperDisplayName">;
            avatarUrl: (string & z.BRAND<"URLString">) | null;
        } | null;
        twitchIdentityId: number;
        twitchId: string;
        twitchHandle: string;
        twitchDisplayName: string;
        twitchNameColor: string;
        twitchChannelURL: string;
        info: {
            color: string & z.BRAND<"ColorString">;
            pronouns: (string & z.BRAND<"PronounString">) | null;
            name: string;
            avatarURL: (string & z.BRAND<"URLString">) | null;
        };
    }> | null;
    discord: {
        camper: {
            color: (string & z.BRAND<"ColorString">) | null;
            handle: string & z.BRAND<"CamperHandle">;
            pronouns: (string & z.BRAND<"PronounString">) | null;
            id: number;
            name: string & z.BRAND<"CamperDisplayName">;
            avatarUrl: (string & z.BRAND<"URLString">) | null;
        };
        discordId: string;
        discordUsername: string;
        discordDisplayName: string;
        discordAvatar: string & z.BRAND<"URLString">;
    } | null;
    mastoLink: string;
}, {
    prose: string | null;
    mastodon: string | null;
    twitch: Readonly<{
        camper: {
            color: string | null;
            handle: string;
            pronouns: string | null;
            id: number;
            name: string;
            avatarUrl: string | null;
        } | null;
        twitchIdentityId: number;
        twitchId: string;
        twitchHandle: string;
        twitchDisplayName: string;
        twitchNameColor: string;
        twitchChannelURL: string;
        info: {
            color: string;
            pronouns: string | null;
            name: string;
            avatarURL: string | null;
        };
    }> | null;
    discord: {
        camper: {
            color: string | null;
            handle: string;
            pronouns: string | null;
            id: number;
            name: string;
            avatarUrl: string | null;
        };
        discordId: string;
        discordUsername: string;
        discordDisplayName: string;
        discordAvatar: string;
    } | null;
    mastoLink: string;
}>;
export type LodgeConnectedAccounts = z.infer<typeof LodgeConnectedAccountsSchema>;
export declare const EMPTY_LODGE_PROFILE: LodgeProfile;
